@@ -62,8 +62,7 @@ bool KPoPlugin::readInfo(KFileMetaInfo& metaInfo, uint)
 {
   PoInfo poInfo;
   QStringList wordList;
-  ConversionStatus status = PoInfo::info(metaInfo.path(), poInfo,
-					   wordList, false, false);
+  ConversionStatus status = PoInfo::info(metaInfo.path(), poInfo, wordList, false, false, false);
   if (status == OK) {
     KFileMetaInfoGroup group = appendGroup(metaInfo, "CatalogInfo");
 
