@@ -50,10 +50,10 @@
 #include <kmessagebox.h>
 #include <ktempfile.h>
 #include <kdebug.h>
+#include <kprocess.h>
 // project specific include files
 #include "svnhandler.h"
 
-
 SVNHandler::SVNHandler( const QString& poBaseDir, const QString& potBaseDir )
 {
   setPOBaseDir( poBaseDir );
@@ -126,18 +126,82 @@ SVNHandler::FileStatus SVNHandler::fstatus( const QString& filename ) const
 
   QFileInfo info( fn );
 
-  // check if '.svn/entries' exists and can be read
+  // check if '.svn/entries' exists.
   QFile entries( info.dir( true ).path( ) + "/.svn/entries" );
 
   if ( !entries.exists() )
     return NOT_IN_SVN;
-  
-  if ( !entries.open( IO_ReadOnly ) )
-    return ERROR_IN_WC;  // we already know that it is a repository
+
+  KProcess proc;
+  SVNOutputCollector out( &proc );
+
+  proc << "svn" << "status" << "-v" << "--xml" << info.absFilePath();
+
+  if( !proc.start( KProcess::Block, KProcess::Stdout ) )
+    return ERROR_IN_WC;
 
   QDomDocument doc;
   QString errorMsg;
   int errorLine, errorCol;
+  QDomNodeList nodelist;
+  QDomNode node;
+  QDomElement entry, wcStatus;
+
+  // Parse the output.
+  if ( !doc.setContent( out.output(), &errorMsg, &errorLine, &errorCol ) ) {
+    kdDebug(8109) << "Cannot parse \"svn status -v --xml\" output for"
+        << filename << endl << "Line: " << errorLine << " Column: "
+        << errorCol << " Error: " << errorMsg << endl;
+    goto no_status_xml;
+  }
+
+  // There should be only one "entry" element. If it doesn't exist, path
+  // isn't repo path at all.
+  nodelist = doc.elementsByTagName("entry");
+  if (nodelist.count() < 1)
+    return NOT_IN_SVN;
+
+  entry = nodelist.item(0).toElement();
+
+  // Shouldn't fail, but just in case there is some weird error.
+  if ( entry.attributeNode("path").value() != info.absFilePath() )
+    return ERROR_IN_WC;
+
+  for ( node = entry.firstChild(); !node.isNull(); node = node.nextSibling() ) {
+    if ( !node.isElement() )
+      continue;
+    if (node.toElement().tagName() == "wc-status")
+      break;
+  }
+
+  if ( node.isNull() )
+    return ERROR_IN_WC;
+
+  wcStatus = node.toElement();
+
+  if ( wcStatus.attributeNode("item").value() == "normal" )
+    return UP_TO_DATE;
+  if ( wcStatus.attributeNode("item").value() == "modified" )
+    return LOCALLY_MODIFIED;
+  if ( wcStatus.attributeNode("item").value() == "conflicted" )
+    return CONFLICT;
+  if ( wcStatus.attributeNode("item").value() == "unversioned" )
+    return NOT_IN_SVN;
+  // TODO Ignored entry should have separate return value probably.
+  if ( wcStatus.attributeNode("item").value() == "ignored" )
+    return NOT_IN_SVN;
+  if ( wcStatus.attributeNode("item").value() == "added" )
+    return LOCALLY_ADDED;
+  if ( wcStatus.attributeNode("item").value() == "deleted" )
+    return LOCALLY_REMOVED;
+  // TODO What to do with "missing", "incomplete", "replaced", "merged",
+  // "obstructed", "external"? Can these appear at all in our case?
+
+  return ERROR_IN_WC;
+
+no_status_xml:
+  if ( !entries.open( IO_ReadOnly ) )
+    return ERROR_IN_WC;  // we already know that it is a repository
 
   // Parse the entries file
   if ( !doc.setContent( &entries, &errorMsg, &errorLine, &errorCol ) ) {
@@ -439,6 +503,41 @@ bool SVNHandler::isConsideredModified( const FileStatus status ) const
   return status == LOCALLY_MODIFIED || status == NOT_IN_SVN;
 }
 
+SVNOutputCollector::SVNOutputCollector( KProcess* p )
+  : m_process(0)
+{
+  setProcess( p );
+}
+
+void SVNOutputCollector::setProcess( KProcess* p )
+{
+  if( m_process )
+    m_process->disconnect( this );
+
+  m_process = p;
+  if( p ) {
+    connect( p, SIGNAL(receivedStdout(KProcess*, char*, int)),
+             this, SLOT(slotGatherStdout(KProcess*, char*, int)) );
+    connect( p, SIGNAL(receivedStderr(KProcess*, char*, int)),
+             this, SLOT(slotGatherStderr(KProcess*, char*, int)) );
+  }
+
+  m_gatheredOutput.truncate( 0 );
+  m_stderrOutput.truncate( 0 );
+  m_stdoutOutput.truncate( 0 );
+}
+
+void SVNOutputCollector::slotGatherStderr( KProcess*, char* data, int len )
+{
+  m_gatheredOutput.append( QString::fromLocal8Bit( data, len ) );
+  m_stderrOutput.append( QString::fromLocal8Bit( data, len ) );
+}
+
+void SVNOutputCollector::slotGatherStdout( KProcess*, char* data, int len )
+{
+  m_gatheredOutput.append( QString::fromLocal8Bit( data, len ) );
+  m_stdoutOutput.append( QString::fromLocal8Bit( data, len ) );
+}
 
 #include "svnhandler.moc"
 
