@@ -20,8 +20,11 @@
 #include <qfile.h>
 #include <qdir.h>
 #include <qregexp.h>
+#include <qtextcodec.h>
+#include <qvaluelist.h>
 
 #include <kaction.h>
+#include <kcharsets.h>
 #include <kdebug.h>
 #include <kdirwatch.h>
 #include <kio/netaccess.h>
@@ -32,6 +35,7 @@
 #include "difference.h"
 #include "diffhunk.h"
 #include "diffmodel.h"
+#include "diffmodellist.h"
 #include "kompareprocess.h"
 #include "komparemodellist.h"
 #include "parser.h"
@@ -40,7 +44,7 @@
 
 using namespace Diff2;
 
-KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::Info* info, QObject* parent, const char* name )
+KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::Info& info, QObject* parent, const char* name )
 	: QObject( parent, name ),
 	m_diffProcess( 0 ),
 	m_diffSettings( diffSettings ),
@@ -49,7 +53,8 @@ KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::
 	m_selectedDifference( 0 ),
 	m_noOfModified( 0 ),
 	m_modelIndex( 0 ),
-	m_info( info )
+	m_info( info ),
+	m_textCodec( 0 )
 {
 	m_applyDifference    = new KAction( i18n("&Apply Difference"), "1rightarrow", Qt::Key_Space,
 	                                 this, SLOT(slotActionApplyDifference()),
@@ -72,13 +77,13 @@ KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::
 	m_previousDifference = new KAction( i18n("&Previous Difference"), "1uparrow", Qt::CTRL + Qt::Key_Up,
 	                                 this, SLOT(slotPreviousDifference()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_previous" );
-	m_previousDifference->setEnabled( false );
-	m_nextDifference  = new KAction( i18n("&Next Difference"), "1downarrow", Qt::CTRL + Qt::Key_Down,
+	m_nextDifference     = new KAction( i18n("&Next Difference"), "1downarrow", Qt::CTRL + Qt::Key_Down,
 	                                 this, SLOT(slotNextDifference()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_next" );
+	m_previousDifference->setEnabled( false );
 	m_nextDifference->setEnabled( false );
 
-	m_save            = KStdAction::save( this, SLOT(slotSaveDestination()), ((KomparePart*)parent)->actionCollection() );
+	m_save = KStdAction::save( this, SLOT(slotSaveDestination()), ((KomparePart*)parent)->actionCollection() );
 	m_save->setEnabled( false );
 
 	updateModelListActions();
@@ -114,7 +119,7 @@ bool KompareModelList::compare( const QString& source, const QString& destinatio
 
 	if ( sourceIsDirectory && destinationIsDirectory )
 	{
-		m_info->mode = Kompare::ComparingDirs;
+		m_info.mode = Kompare::ComparingDirs;
 		result = compareDirs( source, destination );
 	}
 	else if ( !sourceIsDirectory && !destinationIsDirectory )
@@ -135,30 +140,30 @@ bool KompareModelList::compare( const QString& source, const QString& destinatio
 		if ( !isDiff( sourceMimeType ) && isDiff( destinationMimeType ) )
 		{
 			kdDebug(8101) << "Blending destination into source..." << endl;
-			m_info->mode = Kompare::BlendingFile;
+			m_info.mode = Kompare::BlendingFile;
 			result = openFileAndDiff( source, destination );
 		}
 		else if ( isDiff( sourceMimeType ) && !isDiff( destinationMimeType ) )
 		{
 			kdDebug(8101) << "Blending source into destination..." << endl;
-			m_info->mode = Kompare::BlendingFile;
+			m_info.mode = Kompare::BlendingFile;
 			result = openFileAndDiff( destination, source );
 		}
 		else
 		{
 			kdDebug(8101) << "Comparing source with destination" << endl;
-			m_info->mode = Kompare::ComparingFiles;
+			m_info.mode = Kompare::ComparingFiles;
 			result = compareFiles( source, destination );
 		}
 	}
 	else if ( sourceIsDirectory && !destinationIsDirectory )
 	{
-		m_info->mode = Kompare::BlendingDir;
+		m_info.mode = Kompare::BlendingDir;
 		result = openDirAndDiff( source, destination );
 	}
 	else
 	{
-		m_info->mode = Kompare::BlendingDir;
+		m_info.mode = Kompare::BlendingDir;
 		result = openDirAndDiff( destination, source );
 	}
 
@@ -172,16 +177,17 @@ bool KompareModelList::compareFiles( const QString& source, const QString& desti
 
 	clear(); // Destroy the old models...
 
-	m_fileWatch = new KDirWatch( this, "filewatch" );
-	m_fileWatch->addFile( m_source );
-	m_fileWatch->addFile( m_destination );
+//	m_fileWatch = new KDirWatch( this, "filewatch" );
+//	m_fileWatch->addFile( m_source );
+//	m_fileWatch->addFile( m_destination );
 
-	connect( m_fileWatch, SIGNAL( dirty( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
-	connect( m_fileWatch, SIGNAL( created( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
-	connect( m_fileWatch, SIGNAL( deleted( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
+//	connect( m_fileWatch, SIGNAL( dirty( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
+//	connect( m_fileWatch, SIGNAL( created( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
+//	connect( m_fileWatch, SIGNAL( deleted( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
 
-	m_fileWatch->startScan();
+//	m_fileWatch->startScan();
 	m_diffProcess = new KompareProcess( m_diffSettings, Kompare::Custom, m_source, m_destination );
+	m_diffProcess->setEncoding( m_encoding );
 
 	connect( m_diffProcess, SIGNAL(diffHasFinished( bool )),
 	         this, SLOT(slotDiffProcessFinished( bool )) );
@@ -199,17 +205,18 @@ bool KompareModelList::compareDirs( const QString& source, const QString& destin
 
 	clear(); // Destroy the old models...
 
-	m_dirWatch = new KDirWatch( this, "dirwatch" );
+//	m_dirWatch = new KDirWatch( this, "dirwatch" );
 	// Watch files in the dirs and watch the dirs recursively
-	m_dirWatch->addDir( m_source, true, true );
-	m_dirWatch->addDir( m_destination, true, true );
+//	m_dirWatch->addDir( m_source, true, true );
+//	m_dirWatch->addDir( m_destination, true, true );
 
-	connect( m_dirWatch, SIGNAL( dirty  ( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
-	connect( m_dirWatch, SIGNAL( created( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
-	connect( m_dirWatch, SIGNAL( deleted( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
+//	connect( m_dirWatch, SIGNAL( dirty  ( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
+//	connect( m_dirWatch, SIGNAL( created( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
+//	connect( m_dirWatch, SIGNAL( deleted( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
 
-	m_dirWatch->startScan();
+//	m_dirWatch->startScan();
 	m_diffProcess = new KompareProcess( m_diffSettings, Kompare::Custom, m_source, m_destination );
+	m_diffProcess->setEncoding( m_encoding );
 
 	connect( m_diffProcess, SIGNAL(diffHasFinished( bool )),
 	         this, SLOT(slotDiffProcessFinished( bool )) );
@@ -226,7 +233,7 @@ bool KompareModelList::openFileAndDiff( const QString& file, const QString& diff
 
 	if ( parseDiffOutput( readFile( diff ) ) != 0 )
 	{
-		emit error( i18n( "No models or no differences, this file: %1, is not a valid diff file" ).arg(  diff ) );
+		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>" ).arg(  diff ) );
 		return false;
 	}
 
@@ -234,7 +241,7 @@ bool KompareModelList::openFileAndDiff( const QString& file, const QString& diff
 	if ( !blendOriginalIntoModelList( file ) )
 	{
 		kdDebug(8101) << "Oops cant blend original file into modellist : " << file << endl;
-		emit( i18n( "There were problems applying the diff (%1) to the file (%2)." ).arg( diff ).arg( file ) );
+		emit( i18n( "<qt>There were problems applying the diff <b>%1</b> to the file <b>%2</b>.</qt>" ).arg( diff ).arg( file ) );
 		return false;
 	}
 
@@ -250,7 +257,7 @@ bool KompareModelList::openDirAndDiff( const QString& dir, const QString& diff )
 
 	if ( parseDiffOutput( readFile( diff ) ) != 0 )
 	{
-		emit error( i18n( "No models or no differences, this file: %1, is not a valid diff file" ).arg( diff ) );
+		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>" ).arg( diff ) );
 		return false;
 	}
 
@@ -259,7 +266,7 @@ bool KompareModelList::openDirAndDiff( const QString& dir, const QString& diff )
 	{
 		// Trouble blending the original into the model
 		kdDebug(8101) << "Oops cant blend original dir into modellist : " << dir << endl;
-		emit error( i18n( "There were problems applying the diff (%1) to the folder (%2)." ).arg( diff ).arg( dir ) );
+		emit error( i18n( "<qt>There were problems applying the diff <b>%1</b> to the folder <b>%2</b>.</qt>" ).arg( diff ).arg( dir ) );
 		return false;
 	}
 
@@ -277,12 +284,10 @@ void KompareModelList::slotSaveDestination()
 	}
 }
 
-bool KompareModelList::saveDestination( const DiffModel* model_ )
+bool KompareModelList::saveDestination( DiffModel* model )
 {
 	kdDebug() << "KompareModelList::saveDestination: " << endl;
 
-	DiffModel* model = const_cast<DiffModel*>( model_ );
-
 	if( !model->isModified() )
 		return true;
 
@@ -298,50 +303,37 @@ bool KompareModelList::saveDestination( const DiffModel* model_ )
 	QTextStream* stream = temp->textStream();
 	QStringList list;
 
-	QPtrListIterator<DiffHunk> hunkIt( model->hunks() );
-	for( ; hunkIt.current(); ++hunkIt ) {
-		DiffHunk* hunk = hunkIt.current();
+	DiffHunkListConstIterator hunkIt = model->hunks()->begin();
+	DiffHunkListConstIterator hEnd   = model->hunks()->end();
 
-		QPtrListIterator<Difference> diffIt(hunk->differences());
+	for( ; hunkIt != hEnd; ++hunkIt )
+	{
+		DiffHunk* hunk = *hunkIt;
+
+		DifferenceListConstIterator diffIt = hunk->differences().begin();
+		DifferenceListConstIterator dEnd   = hunk->differences().end();
 
 		Difference* diff;
-		for( ; (diff = diffIt.current()); ++diffIt )
+		for( ; diffIt != dEnd; ++diffIt )
 		{
+			diff = *diffIt;
 			if( !diff->applied() )
 			{
-#if INLINE_DIFFERENCES
-				DifferenceStringConstIterator it = diff->destinationLines().begin();
-				DifferenceStringConstIterator end = diff->destinationLines().end();
-				for ( ; it != end; ++it )
+				DifferenceStringListConstIterator stringIt = diff->destinationLines().begin();
+				DifferenceStringListConstIterator sEnd     = diff->destinationLines().end();
+				for ( ; stringIt != sEnd; ++stringIt )
 				{
-					list.append( ( *it ).string() );
+					list.append( ( *stringIt )->string() );
 				}
-#else
-				QValueVector<QString>::ConstIterator it = diff->destinationLines().begin();
-				QValueVector<QString>::ConstIterator end = diff->destinationLines().end();
-				for ( ; it != end; ++it )
-				{
-					list.append( *it );
-				}
-#endif
 			}
 			else
 			{
-#if INLINE_DIFFERENCES
-				DifferenceStringConstIterator it = diff->sourceLines().begin();
-				DifferenceStringConstIterator end = diff->sourceLines().end();
-				for ( ; it != end; ++it )
+				DifferenceStringListConstIterator stringIt = diff->sourceLines().begin();
+				DifferenceStringListConstIterator sEnd = diff->sourceLines().end();
+				for ( ; stringIt != sEnd; ++stringIt )
 				{
-					list.append( ( *it ).string() );
+					list.append( ( *stringIt )->string() );
 				}
-#else
-				QValueVector<QString>::ConstIterator it = diff->sourceLines().begin();
-				QValueVector<QString>::ConstIterator end = diff->sourceLines().end();
-				for ( ; it != end; ++it )
-				{
-					list.append( *it );
-				}
-#endif
 			}
 		}
 	}
@@ -353,7 +345,7 @@ bool KompareModelList::saveDestination( const DiffModel* model_ )
 
 	temp->close();
 	if( temp->status() != 0 ) {
-		emit error( i18n( "Could not write to the temporary file." ) );
+		emit error( i18n( "<qt>Could not write to the temporary file <b>%1</b>, deleting it.</qt>" ).arg( temp->name() ) );
 		temp->unlink();
 		delete temp;
 		return false;
@@ -361,11 +353,20 @@ bool KompareModelList::saveDestination( const DiffModel* model_ )
 
 	bool result = false;
 
-	if ( m_info->mode == Kompare::ComparingDirs )
+	if ( m_info.mode == Kompare::ComparingDirs )
 	{
 		QString destination = model->destinationPath() + model->destinationFile();
 		kdDebug(8101) << "Tempfilename   : " << temp->name() << endl;
 		kdDebug(8101) << "DestinationURL : " << destination << endl;
+		KIO::UDSEntry entry;
+		if ( !KIO::NetAccess::stat( KURL( destination ).path(), entry, (QWidget*)parent() ) )
+		{
+			if ( !KIO::NetAccess::mkdir( KURL( destination ).path(), (QWidget*)parent() ) )
+			{
+				emit error( i18n( "<qt>Could not create destination directory <b>%1</b>.\nThe file has not been saved.</qt>" ) );
+				return false;
+			}
+		}
 		result = KIO::NetAccess::upload( temp->name(), KURL( destination ), (QWidget*)parent() );
 	}
 	else
@@ -377,11 +378,11 @@ bool KompareModelList::saveDestination( const DiffModel* model_ )
 
 	if ( !result )
 	{
-		emit error( i18n( "Could not upload the temporary file to the destination location %2. The temporary file is still available under: %1. You can manually copy it to the right place." ).arg( temp->name() ).arg( m_destination ) );
+		emit error( i18n( "<qt>Could not upload the temporary file to the destination location <b>%1</b>. The temporary file is still available under: <b>%2</b>. You can manually copy it to the right place.</qt>" ).arg( m_destination ).arg( temp->name() ) );
 	}
 	else
 	{
-		model->slotSetModified( false );
+		//model->slotSetModified( false );
 		temp->unlink();
 		delete temp;
 	}
@@ -394,15 +395,27 @@ bool KompareModelList::saveAll()
 	if ( !m_models )
 		return false;
 
-	QPtrListIterator<DiffModel> it( *m_models );
-	while ( it.current() )
+	DiffModelListIterator it  =  m_models->begin();
+	DiffModelListIterator end =  m_models->end();
+	for ( ; it != end; ++it )
 	{
-		if( !saveDestination( *it ) ) return false;
-		++it;
+		if( !saveDestination( *it ) )
+			return false;
 	}
 	return true;
 }
 
+void KompareModelList::setEncoding( const QString& encoding )
+{
+	m_encoding = encoding;
+	kdDebug() << "Encoding : " << encoding << endl;
+	m_textCodec = KGlobal::charsets()->codecForName( encoding.latin1() );
+	kdDebug() << "TextCodec: " << m_textCodec << endl;
+	if ( !m_textCodec )
+		m_textCodec = QTextCodec::codecForLocale();
+	kdDebug() << "TextCodec: " << m_textCodec << endl;
+}
+
 void KompareModelList::slotDiffProcessFinished( bool success )
 {
 	if ( success )
@@ -414,8 +427,11 @@ void KompareModelList::slotDiffProcessFinished( bool success )
 		}
 		else
 		{
-			if ( m_info->mode != Kompare::ShowingDiff )
-				blendOriginalIntoModelList( m_info->localSource );
+			if ( m_info.mode != Kompare::ShowingDiff )
+			{
+				kdDebug() << "Blend this crap please and dont gimme any conflicts..." << endl;
+				blendOriginalIntoModelList( m_info.localSource );
+			}
 			updateModelListActions();
 			show();
 		}
@@ -461,7 +477,8 @@ QStringList KompareModelList::split( const QString& fileContents )
 	QString contents = fileContents;
 	QStringList list;
 
-	int pos = 0, oldpos = 0;
+	int pos = 0;
+	unsigned int oldpos = 0;
 	// split that does not strip the split char
 #ifdef QT_OS_MAC
 	const char split = '\r';
@@ -482,7 +499,7 @@ QStringList KompareModelList::split( const QString& fileContents )
 	return list;
 }
 
-QString KompareModelList::readFile( const QString& fileName ) const
+QString KompareModelList::readFile( const QString& fileName )
 {
 	QStringList list;
 
@@ -490,6 +507,12 @@ QString KompareModelList::readFile( const QString& fileName ) const
 	file.open( IO_ReadOnly );
 
 	QTextStream stream( &file );
+	kdDebug() << "Codec = " << m_textCodec << endl;
+
+	if (  !m_textCodec )
+		m_textCodec = QTextCodec::codecForLocale();
+
+	stream.setCodec(  m_textCodec );
 
 	QString contents = stream.read();
 
@@ -525,6 +548,20 @@ bool KompareModelList::openDiff( const QString& diffFile )
 	return true;
 }
 
+QString KompareModelList::recreateDiff() const
+{
+	QString diff;
+
+	DiffModelListConstIterator modelIt = m_models->begin();
+	DiffModelListConstIterator mEnd    = m_models->end();
+
+	for ( ; modelIt != mEnd; ++modelIt )
+	{
+		diff += (*modelIt)->recreateDiff();
+	}
+	return diff;
+}
+
 bool KompareModelList::saveDiff( const QString& url, QString directory, DiffSettings* diffSettings )
 {
 	kdDebug() << "KompareModelList::saveDiff: " << endl;
@@ -541,12 +578,13 @@ bool KompareModelList::saveDiff( const QString& url, QString directory, DiffSett
 	}
 
 	m_diffProcess = new KompareProcess( diffSettings, Kompare::Custom, m_source, m_destination, directory );
+	m_diffProcess->setEncoding( m_encoding );
+
 	connect( m_diffProcess, SIGNAL(diffHasFinished( bool )),
 	         this, SLOT(slotWriteDiffOutput( bool )) );
 
 	emit status( Kompare::RunningDiff );
 	return m_diffProcess->start();
-
 }
 
 void KompareModelList::slotWriteDiffOutput( bool success )
@@ -590,7 +628,7 @@ void KompareModelList::slotSelectionChanged( const Diff2::DiffModel* model, cons
 //	kdDebug(8101) << kdBacktrace() << endl;
 
 	m_selectedModel = const_cast<DiffModel*>(model);
-	m_modelIndex = m_models->findRef( model );
+	m_modelIndex = m_models->findIndex( m_selectedModel );
 	kdDebug( 8101 ) << "m_modelIndex = " << m_modelIndex << endl;
 	m_selectedDifference = const_cast<Difference*>(diff);
 
@@ -632,6 +670,8 @@ void KompareModelList::slotSelectionChanged( const Diff2::Difference* diff )
 	}
 
 	emit setSelection( diff );
+	emit setStatusBarModelInfo( findModel( m_selectedModel ), m_selectedModel->findDifference( m_selectedDifference ), modelCount(), differenceCount(), m_selectedModel->appliedCount() );
+
 	updateModelListActions();
 }
 
@@ -675,7 +715,7 @@ DiffModel* KompareModelList::firstModel()
 	m_modelIndex = 0;
 	kdDebug( 8101 ) << "m_modelIndex = " << m_modelIndex << endl;
 
-	m_selectedModel = m_models->at( m_modelIndex );
+	m_selectedModel = m_models->first();
 
 	return m_selectedModel;
 }
@@ -686,7 +726,7 @@ DiffModel* KompareModelList::lastModel()
 	m_modelIndex = m_models->count() - 1;
 	kdDebug( 8101 ) << "m_modelIndex = " << m_modelIndex << endl;
 
-	m_selectedModel = m_models->at( m_modelIndex );
+	m_selectedModel = m_models->last();
 
 	return m_selectedModel;
 }
@@ -697,7 +737,7 @@ DiffModel* KompareModelList::prevModel()
 	if ( --m_modelIndex < m_models->count() )
 	{
 		kdDebug( 8101 ) << "m_modelIndex = " << m_modelIndex << endl;
-		m_selectedModel = m_models->at( m_modelIndex );
+		m_selectedModel = (*m_models)[ m_modelIndex ];
 	}
 	else
 	{
@@ -715,7 +755,7 @@ DiffModel* KompareModelList::nextModel()
 	if ( ++m_modelIndex < m_models->count() )
 	{
 		kdDebug( 8101 ) << "m_modelIndex = " << m_modelIndex << endl;
-		m_selectedModel = m_models->at( m_modelIndex );
+		m_selectedModel = (*m_models)[ m_modelIndex ];
 	}
 	else
 	{
@@ -738,7 +778,7 @@ void KompareModelList::slotPreviousDifference()
 		return;
 	}
 
-	kdDebug(8101) << "Fuck no previous difference... ok lets find the previous model..." << endl;
+	kdDebug(8101) << "**** no previous difference... ok lets find the previous model..." << endl;
 
 	if ( ( m_selectedModel = prevModel() ) != 0 )
 	{
@@ -751,7 +791,7 @@ void KompareModelList::slotPreviousDifference()
 	}
 
 
-	kdDebug(8101) << "Crap !!! No previous model, ok backup plan activated..." << endl;
+	kdDebug(8101) << "**** !!! No previous model, ok backup plan activated..." << endl;
 
 	// Backup plan
 	m_selectedModel = firstModel();
@@ -773,7 +813,7 @@ void KompareModelList::slotNextDifference()
 		return;
 	}
 
-	kdDebug(8101) << "Fuck no next difference... ok lets find the next model..." << endl;
+	kdDebug(8101) << "**** no next difference... ok lets find the next model..." << endl;
 
 	if ( ( m_selectedModel = nextModel() ) != 0 )
 	{
@@ -785,7 +825,7 @@ void KompareModelList::slotNextDifference()
 		return;
 	}
 
-	kdDebug(8101) << "Crap !!! No next model, ok backup plan activated..." << endl;
+	kdDebug(8101) << "**** !!! No next model, ok backup plan activated..." << endl;
 
 	// Backup plan
 	m_selectedModel = lastModel();
@@ -817,8 +857,8 @@ int KompareModelList::parseDiffOutput( const QString& diff )
 	Parser* parser = new Parser( this );
 	m_models = parser->parse( diffLines );
 
-	m_info->generator = parser->generator();
-	m_info->format    = parser->format();
+	m_info.generator = parser->generator();
+	m_info.format    = parser->format();
 
 	delete parser;
 
@@ -841,6 +881,7 @@ int KompareModelList::parseDiffOutput( const QString& diff )
 
 bool KompareModelList::blendOriginalIntoModelList( const QString& localURL )
 {
+	kdDebug() << "Hurrah we are blending..." << endl;
 	QFileInfo fi( localURL );
 
 	bool result = false;
@@ -848,16 +889,15 @@ bool KompareModelList::blendOriginalIntoModelList( const QString& localURL )
 
 	QString fileContents;
 
-	DiffModelList* models = m_models;
-	m_models = new DiffModelList();
-
 	if ( fi.isDir() )
 	{ // is a dir
+		kdDebug() << "Blend Dir" << endl;
 //		QDir dir( localURL, QString::null, QDir::Name|QDir::DirsFirst, QDir::All );
-		QPtrListIterator<DiffModel> it( *models );
-		for ( ; it.current() != 0; ++it )
+		DiffModelListIterator modelIt = m_models->begin();
+		DiffModelListIterator mEnd    = m_models->end();
+		for ( ; modelIt != mEnd; ++modelIt )
 		{
-			model = (*it);
+			model = *modelIt;
 			kdDebug(8101) << "Model : " << model << endl;
 			QString filename = model->sourcePath() + model->sourceFile();
 			if ( !filename.startsWith( localURL ) )
@@ -877,17 +917,18 @@ bool KompareModelList::blendOriginalIntoModelList( const QString& localURL )
 				result = blendFile( model, fileContents );
 			}
 		}
+		kdDebug() << "End of Blend Dir" << endl;
 	}
 	else if ( fi.isFile() )
 	{ // is a file
+		kdDebug() << "Blend File" << endl;
 		kdDebug(8101) << "Reading from: " << localURL << endl;
 		fileContents = readFile( localURL );
 
-		result = blendFile( models->at( 0 ), fileContents );
+		result = blendFile( (*m_models)[ 0 ], fileContents );
+		kdDebug() << "End of Blend File" << endl;
 	}
 
-	delete models; // Hope it does not delete the models, just the container
-
 	return result;
 }
 
@@ -895,203 +936,217 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 {
 	if ( !model )
 	{
-		kdDebug() << "Crap model is null :(" << endl;
+		kdDebug() << "**** model is null :(" << endl;
 		return false;
 	}
 
-	Difference* newDiff;
-	DiffModel* newModel = new DiffModel();
-	connect( newModel, SIGNAL( setModified( bool ) ), this, SLOT( slotSetModified( bool ) ) );
-	// We don't want a full copy so dont use newModel = new DiffModel( model );
-	*newModel = *model;
+	model->setBlended( true );
 
 	int srcLineNo = 1, destLineNo = 1;
 
-	DiffHunk* newHunk = new DiffHunk( srcLineNo, destLineNo );
-
-	newModel->addHunk( newHunk );
-
 	QStringList lines = split( fileContents );
 
-	QStringList::ConstIterator it  = lines.begin();
-	QStringList::ConstIterator end = lines.end();
+	QStringList::ConstIterator linesIt = lines.begin();
+	QStringList::ConstIterator lEnd    = lines.end();
 
-	QPtrList<Difference> diffList = model->allDifferences();
-	Difference* diff;
+	DiffHunkList* hunks = model->hunks();
+	kdDebug(8101) << "Hunks in hunklist: " << hunks->count() << endl;
+	DiffHunkListIterator hunkIt = hunks->begin();
 
-	diffList.first();
+	DiffHunk*   newHunk = 0;
+	Difference* newDiff = 0;
 
-	while ( ( diff = diffList.current() ) )
+	// FIXME: this approach is not very good, we should first check if the hunk applies cleanly
+	// and without offset and if not use that new linenumber with offset to compare against
+	// This will only work for files we just diffed with kompare but not for blending where
+	// file(s) to patch has/have potentially changed
+
+	for ( ; hunkIt != hunks->end(); ++hunkIt )
 	{
-		// Check if there are lines in the original file before the difference
-		// that are not yet in the diff. If so create new Context diff
-		if ( srcLineNo < diff->sourceLineNumber() )
+		// Do we need to insert a new hunk before this one ?
+		DiffHunk* hunk = *hunkIt;
+		if ( srcLineNo < hunk->sourceLineNumber() )
 		{
-			newDiff = new Difference( srcLineNo, destLineNo );
+			newHunk = new DiffHunk( srcLineNo, destLineNo, "", DiffHunk::AddedByBlend );
+
+			hunks->insert( hunkIt, newHunk );
+
+			newDiff = new Difference( srcLineNo, destLineNo,
+			              Difference::Unchanged );
+
 			newHunk->add( newDiff );
-			while ( srcLineNo < diff->sourceLineNumber() && it != end )
+
+			while ( srcLineNo < hunk->sourceLineNumber() && linesIt != lEnd )
 			{
-//				kdDebug(8101) << "SourceLine = " << srcLineNo << ": " << *it << endl;
-				newDiff->addSourceLine( *it );
-				newDiff->addDestinationLine( *it );
+				newDiff->addSourceLine( *linesIt );
+				newDiff->addDestinationLine( *linesIt );
 				srcLineNo++;
 				destLineNo++;
-				++it;
+				++linesIt;
 			}
 		}
-		// Now i've got to add that diff
-		bool conflict = false;
-		switch ( diff->type() )
+
+		// Now we add the linecount difference for the hunk that follows
+		int size = hunk->sourceLineCount();
+
+		for ( int i = 0; i < size; ++i )
 		{
-		case Difference::Unchanged:
-			kdDebug(8101) << "Unchanged" << endl;
-			for ( int i = 0; i < diff->sourceLineCount(); i++ )
-			{
-#if INLINE_DIFFERENCES
-				if ( it != end && *it != diff->sourceLineAt( i )->string() )
-#else
-				if ( it != end && *it != diff->sourceLineAt( i ) )
-#endif
-				{
-					kdDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *it << endl;
-#if INLINE_DIFFERENCES
-					kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
-#else
-					kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i ) << endl;
-#endif
-					conflict = true;
-					break;
-				}
-				kdDebug(8101) << "SourceLine = " << srcLineNo << ": " << *it << endl;
-#if INLINE_DIFFERENCES
-				kdDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
-#else
-				kdDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i ) << endl;
-#endif
-				srcLineNo++;
-				destLineNo++;
-				++it;
-			}
-
-			if ( !conflict )
-			{
-				diffList.take();
-				newHunk->add( diff );
-			}
-			else
-			{
-				// FIXME: Leave that diff out for now
-				// We'll have to do all sorts of nice things to get this working properly
-				// Like trying offsets and or fuzzy matching or check for tabs that were converted into spaces by diff
-				kdDebug(8101) << "Unchanged: Wow, conflict... what should we do now ???" << endl;
-				diffList.next();
-			}
-			break;
-		case Difference::Change:
-			kdDebug(8101) << "Change" << endl;
-			for ( int i = 0; i < diff->sourceLineCount(); i++ )
-			{
-#if INLINE_DIFFERENCES
-				if ( it != lines.end() && *it != diff->sourceLineAt( i )->string() )
-#else
-				if ( it != lines.end() && *it != diff->sourceLineAt( i ) )
-#endif
-				{
-					kdDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *it << endl;
-#if INLINE_DIFFERENCES
-					kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
-#else
-					kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i ) << endl;
-#endif
-					conflict = true;
-					break;
-				}
-				srcLineNo++;
-				destLineNo++;
-				++it;
-			}
-
-			destLineNo += diff->destinationLineCount();
-
-			if ( !conflict )
-			{
-				diffList.take();
-				newHunk->add( diff );
-				newModel->addDiff( diff );
-			}
-			else
-			{
-				// FIXME: Leave that diff out for now
-				// We'll have to do all sorts of nice things to get this working properly
-				// Like trying offsets and or fuzzy matching
-				kdDebug(8101) << "Change: Wow, conflict... what should we do now ???" << endl;
-				diffList.next();
-			}
-			break;
-		case Difference::Insert:
-			kdDebug(8101) << "Insert" << endl;
-			destLineNo += diff->destinationLineCount();
-			diffList.take();
-			newHunk->add( diff );
-			newModel->addDiff( diff );
-			break;
-		case Difference::Delete:
-			kdDebug(8101) << "Delete" << endl;
-			kdDebug(8101) << "Number of lines in Delete: " << diff->sourceLineCount() << endl;
-			for ( int i = 0; i < diff->sourceLineCount(); i++ )
-			{
-#if INLINE_DIFFERENCES
-				if ( it != end && *it != diff->sourceLineAt( i )->string() )
-#else
-				if ( it != end && *it != diff->sourceLineAt( i ) )
-#endif
-				{
-					kdDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *it << endl;
-#if INLINE_DIFFERENCES
-					kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
-#else
-					kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i ) << endl;
-#endif
-					conflict = true;
-					break;
-				}
-
-//				kdDebug(8101) << "SourceLine = " << srcLineNo << ": " << *it << endl;
-//				kdDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
-				srcLineNo++;
-				++it;
-			}
-
-			if ( !conflict )
-			{
-				diffList.take();
-				newHunk->add( diff );
-				newModel->addDiff( diff );
-			}
-			else
-			{
-				// FIXME: Leave that diff out for now
-				// We'll have to do all sorts of nice things to get this working properly
-				// Like trying offsets and or fuzzy matching
-				kdDebug(8101) << "Delete: Wow, conflict... what should we do now ???" << endl;
-				diffList.next();
-			}
-			break;
+			++linesIt;
 		}
+
+		srcLineNo += size;
+		destLineNo += (*hunkIt)->destinationLineCount();
 	}
 
-	if ( it != end )
+	if ( linesIt != lEnd )
 	{
+		newHunk = new DiffHunk( srcLineNo, destLineNo, "", DiffHunk::AddedByBlend );
+
+		model->addHunk( newHunk );
+
 		newDiff = new Difference( srcLineNo, destLineNo, Difference::Unchanged );
+
 		newHunk->add( newDiff );
 
-		while ( it != end )
+		while ( linesIt != lEnd )
 		{
-			newDiff->addSourceLine( *it );
-			newDiff->addDestinationLine( *it );
-			++it;
+			newDiff->addSourceLine( *linesIt );
+			newDiff->addDestinationLine( *linesIt );
+			++linesIt;
 		}
 	}
+#if 0
+		DifferenceList hunkDiffList   = (*hunkIt)->differences();
+		DifferenceListIterator diffIt = hunkDiffList.begin();
+		DifferenceListIterator dEnd   = hunkDiffList.end();
+		kdDebug() << "Number of differences in hunkDiffList = " << diffList.count() << endl;
+
+		DifferenceListIterator tempIt;
+		Difference* diff;
+
+		for ( ; diffIt != dEnd; ++diffIt )
+		{
+			diff = *diffIt;
+			kdDebug() << "*(Diff it) = " << diff << endl;
+			// Check if there are lines in the original file before the difference
+			// that are not yet in the diff. If so create new Unchanged diff
+			if ( srcLineNo < diff->sourceLineNumber() )
+			{
+				newDiff = new Difference( srcLineNo, destLineNo,
+				              Difference::Unchanged | Difference::AddedByBlend );
+				newHunk->add( newDiff );
+				while ( srcLineNo < diff->sourceLineNumber() && linesIt != lEnd )
+				{
+//					kdDebug(8101) << "SourceLine = " << srcLineNo << ": " << *linesIt << endl;
+					newDiff->addSourceLine( *linesIt );
+					newDiff->addDestinationLine( *linesIt );
+					srcLineNo++;
+					destLineNo++;
+					++linesIt;
+				}
+			}
+			// Now i've got to add that diff
+			switch ( diff->type() )
+			{
+			case Difference::Unchanged:
+				kdDebug(8101) << "Unchanged" << endl;
+				for ( int i = 0; i < diff->sourceLineCount(); i++ )
+				{
+					if ( linesIt != lEnd && *linesIt != diff->sourceLineAt( i )->string() )
+					{
+						kdDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt << endl;
+						kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+
+						// Do conflict resolution (well sort of)
+						diff->sourceLineAt( i )->setConflictString( *linesIt );
+						diff->setConflict( true );
+					}
+//					kdDebug(8101) << "SourceLine = " << srcLineNo << ": " << *linesIt << endl;
+//					kdDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+					srcLineNo++;
+					destLineNo++;
+					++linesIt;
+				}
+
+				tempIt = diffIt;
+				--diffIt;
+				diffList.remove( tempIt );
+				newHunk->add( diff );
+
+				break;
+			case Difference::Change:
+				kdDebug(8101) << "Change" << endl;
+
+				//QStringListConstIterator saveIt = linesIt;
+
+				for ( int i = 0; i < diff->sourceLineCount(); i++ )
+				{
+					if ( linesIt != lEnd && *linesIt != diff->sourceLineAt( i )->string() )
+					{
+						kdDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt << endl;
+						kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+
+						// Do conflict resolution (well sort of)
+						diff->sourceLineAt( i )->setConflictString( *linesIt );
+						diff->setConflict( true );
+					}
+					srcLineNo++;
+					destLineNo++;
+					++linesIt;
+				}
+
+				destLineNo += diff->destinationLineCount();
+
+				tempIt = diffIt;
+				--diffIt;
+				diffList.remove( tempIt );
+				newHunk->add( diff );
+				newModel->addDiff( diff );
+
+				break;
+			case Difference::Insert:
+				kdDebug(8101) << "Insert" << endl;
+				destLineNo += diff->destinationLineCount();
+				tempIt = diffIt;
+				--diffIt;
+				diffList.remove( tempIt );
+				newHunk->add( diff );
+				newModel->addDiff( diff );
+				break;
+			case Difference::Delete:
+				kdDebug(8101) << "Delete" << endl;
+				kdDebug(8101) << "Number of lines in Delete: " << diff->sourceLineCount() << endl;
+				for ( int i = 0; i < diff->sourceLineCount(); i++ )
+				{
+					if ( linesIt != lEnd && *linesIt != diff->sourceLineAt( i )->string() )
+					{
+						kdDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt << endl;
+						kdDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+
+						// Do conflict resolution (well sort of)
+						diff->sourceLineAt( i )->setConflictString( *linesIt );
+						diff->setConflict( true );
+					}
+
+//					kdDebug(8101) << "SourceLine = " << srcLineNo << ": " << *it << endl;
+//					kdDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+					srcLineNo++;
+					++linesIt;
+				}
+
+				tempIt = diffIt;
+				--diffIt;
+				diffList.remove( tempIt );
+				newHunk->add( diff );
+				newModel->addDiff( diff );
+				break;
+			default:
+				kdDebug(8101) << "****, some diff type we dont know about ???" << endl;
+			}
+		}
+	}
+#endif
+
 /*
 	diffList = newModel->differences();
 
@@ -1103,11 +1158,6 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 	}
 */
 
-	disconnect( model, SIGNAL( setModified( bool ) ), this, SLOT( slotSetModified( bool ) ) );
-	m_models->remove( model );
-	delete model;
-	m_models->inSort( newModel );
-
 	m_selectedModel = firstModel();
 
 	m_selectedDifference = m_selectedModel->firstDifference();
@@ -1117,6 +1167,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 
 void KompareModelList::show()
 {
+	kdDebug() << "KompareModelList::Show Number of models = " << m_models->count() << endl;
 	emit modelsChanged( m_models );
 	emit setSelection( m_selectedModel, m_selectedDifference );
 }
@@ -1133,9 +1184,9 @@ void KompareModelList::swap()
 {
 	QString source = m_source;
 	QString destination = m_destination;
-	if ( m_info->mode == Kompare::ComparingFiles )
+	if ( m_info.mode == Kompare::ComparingFiles )
 		compareFiles( destination, source );
-	else if ( m_info->mode == Kompare::ComparingDirs )
+	else if ( m_info.mode == Kompare::ComparingDirs )
 		compareDirs( destination, source );
 }
 
@@ -1177,7 +1228,7 @@ void KompareModelList::slotSetModified( bool modified )
 
 	if ( m_noOfModified < 0 )
 	{
-		kdDebug(8101) << "Wow something is fucked up..." << endl;
+		kdDebug(8101) << "Wow something is ****ed up..." << endl;
 	}
 	else if ( m_noOfModified == 0 )
 	{
@@ -1195,10 +1246,10 @@ bool KompareModelList::setSelectedModel( DiffModel* model )
 
 	if ( model != m_selectedModel )
 	{
-		if ( m_models->findRef( model ) == -1 )
+		if ( m_models->findIndex( model ) == -1 )
 			return false;
 		kdDebug(8101) << "m_selectedModel (was) = " << m_selectedModel << endl;
-		m_modelIndex = m_models->findRef( model );
+		m_modelIndex = m_models->findIndex( model );
 		kdDebug(8101) << "m_selectedModel (is)  = " << m_selectedModel << endl;
 		m_selectedModel = model;
 	}
