@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2004-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include <algorithm>
@@ -322,7 +322,7 @@ void AlignToolBar::sortWidgetList(UMLWidgetList &widgetList, Compare comp) {
 /* ------ private slots ------ */
 
 void AlignToolBar::slotButtonChanged(int btn) {
-    UMLView* view = UMLApp::app()->getDocument()->getCurrentView();
+    UMLView* view = UMLApp::app()->getCurrentView();
     UMLWidgetList widgetList;
     UMLWidget* widget;
 
@@ -378,11 +378,8 @@ void AlignToolBar::slotButtonChanged(int btn) {
     } else {
         KMessageBox::messageBox(0, KMessageBox::Information,
                                 i18n("For alignment you have to select at least 2 objects like classes or actors. You can not align associations."),
-                                i18n("Information"), i18n("&OK"), QString("")
-#if KDE_IS_VERSION(3,2,0)
-                                , "showAlignInformation"
-#endif
-                               );
+                                i18n("Information"), i18n("&OK"), QString(""),
+                                "showAlignInformation");
     } // if (widgetList.count() > 1)
 
     return;
