@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -52,14 +52,14 @@ UMLAssociation::UMLAssociation( Association_Type type /* = Uml::at_Unknown */)
 // destructor
 UMLAssociation::~UMLAssociation( ) {
     if (m_pRole[A] == NULL) {
-        kdError() << "UMLAssociation destructor: m_pRole[A] is NULL already"
+        kError() << "UMLAssociation destructor: m_pRole[A] is NULL already"
         << endl;
     } else {
         delete m_pRole[A];
         m_pRole[A] = NULL;
     }
     if (m_pRole[B] == NULL) {
-        kdError() << "UMLAssociation destructor: m_pRole[B] is NULL already"
+        kError() << "UMLAssociation destructor: m_pRole[B] is NULL already"
         << endl;
     } else {
         delete m_pRole[B];
@@ -109,14 +109,14 @@ QString UMLAssociation::toString ( ) const
     if(m_pRole[A])
     {
         string += m_pRole[A]->getObject()->getName();
-        string += ":";
+        string += ':';
         string += m_pRole[A]->getName();
     }
-    string += ":" + typeAsString(m_AssocType) + ":";
+    string += ':' + typeAsString(m_AssocType) + ':';
     if(m_pRole[B])
     {
         string += m_pRole[B]->getObject( )->getName();
-        string += ":";
+        string += ':';
         string += m_pRole[B]->getName();
     }
     return string;
@@ -153,8 +153,7 @@ bool UMLAssociation::resolveRef() {
                 (objA && objA->getBaseType() == Uml::ot_Interface ||
                  objB && objB->getBaseType() == Uml::ot_Interface))
             m_AssocType = Uml::at_Realization;
-        UMLDoc *doc = UMLApp::app()->getDocument();
-        doc->addAssocToConcepts(this);
+        m_pUMLPackage->addAssocToConcepts(this);
         return true;
     }
     return false;
@@ -214,9 +213,15 @@ bool UMLAssociation::load( QDomElement & element ) {
             obj[r] = doc->findObjectById(STR2ID(roleIdStr));
             Uml::Role_Type role = (Uml::Role_Type)r;
             if (obj[r] == NULL) {
-                getUMLRole(role)->setSecondaryId(roleIdStr);  // defer to resolveRef()
+                m_pRole[role]->setSecondaryId(roleIdStr);  // defer to resolveRef()
             } else {
-                getUMLRole(role)->setObject(obj[r]);
+                m_pRole[role]->setObject(obj[r]);
+                if (m_pUMLPackage == NULL) {
+                    Uml::Model_Type mt = Model_Utils::convert_OT_MT(obj[r]->getBaseType());
+                    m_pUMLPackage = doc->getRootFolder(mt);
+                    kDebug() << "UMLAssociation::load(assoctype " << m_AssocType
+                        << "): setting model type " << mt << endl;
+                }
             }
         }
         if (obj[A] == NULL || obj[B] == NULL) {
@@ -242,7 +247,7 @@ bool UMLAssociation::load( QDomElement & element ) {
                         idStr = tmpElem.attribute( "xmi.idref", "" );
                 }
                 if (idStr.isEmpty()) {
-                    kdError() << "UMLAssociation::load (type " << m_AssocType
+                    kError() << "UMLAssociation::load (type " << m_AssocType
                         << ", id " << ID2STR(getID()) << "): "
                         << "xmi id not given for " << tag << endl;
                     continue;
@@ -278,7 +283,7 @@ bool UMLAssociation::load( QDomElement & element ) {
         if (!tagEq(tag, "Association.connection") &&
                 !tagEq(tag, "Namespace.ownedElement") &&
                 !tagEq(tag, "Namespace.contents")) {
-            kdWarning() << "UMLAssociation::load: "
+            kWarning() << "UMLAssociation::load: "
             << "unknown child node " << tag << endl;
             continue;
         }
@@ -288,13 +293,13 @@ bool UMLAssociation::load( QDomElement & element ) {
             node = node.nextSibling();
         tempElement = node.toElement();
         if (tempElement.isNull()) {
-            kdWarning() << "UML:Association : element (A) is Null" << endl;
+            kWarning() << "UML:Association : element (A) is Null" << endl;
             return false;
         }
         tag = tempElement.tagName();
         if (!tagEq(tag, "AssociationEndRole") &&
                 !tagEq(tag, "AssociationEnd")) {
-            kdWarning() << "UMLAssociation::load: "
+            kWarning() << "UMLAssociation::load: "
             << "unknown child (A) tag " << tag << endl;
             return false;
         }
@@ -306,19 +311,25 @@ bool UMLAssociation::load( QDomElement & element ) {
             node = node.nextSibling();
         tempElement = node.toElement();
         if (tempElement.isNull()) {
-            kdWarning() << "UML:Association : element (B) is Null" << endl;
+            kWarning() << "UML:Association : element (B) is Null" << endl;
             return false;
         }
         tag = tempElement.tagName();
         if (!tagEq(tag, "AssociationEndRole") &&
                 !tagEq(tag, "AssociationEnd")) {
-            kdWarning() << "UMLAssociation::load: "
+            kWarning() << "UMLAssociation::load: "
             << "unknown child (B) tag " << tag << endl;
             return false;
         }
         if (! getUMLRole(B)->loadFromXMI(tempElement))
             return false;
 
+        if (m_pUMLPackage == NULL) {
+            Uml::Model_Type mt = Model_Utils::convert_OT_MT(getObject(B)->getBaseType());
+            m_pUMLPackage = doc->getRootFolder(mt);
+            kDebug() << "UMLAssociation::load: setting model type " << mt << endl;
+        }
+
         // setting the association type:
         //
         // In the old days, we could just record this on the association,
@@ -329,15 +340,12 @@ bool UMLAssociation::load( QDomElement & element ) {
         // is not complete, so we need to finish the analysis here.
 
         // find self-associations
-        if(getAssocType() == Uml::at_Association && getObjectId(A) == getObjectId(B))
+        if (m_AssocType == Uml::at_Association && getObjectId(A) == getObjectId(B))
             m_AssocType = Uml::at_Association_Self;
 
         // fall-back default type
-        if(getAssocType() == Uml::at_Unknown)
-        {
+        if (m_AssocType == Uml::at_Unknown) {
             m_AssocType = Uml::at_Association;
-            kdDebug() << "load can't determine association type, setting to 'plain' association"
-            << endl;
         }
 
         return true;
@@ -377,7 +385,7 @@ bool UMLAssociation::load( QDomElement & element ) {
     } else {
         int assocTypeNum = assocTypeStr.toInt();
         if (assocTypeNum < (int)atypeFirst || assocTypeNum > (int)atypeLast) {
-            kdWarning() << "bad assoctype of UML:Association "
+            kWarning() << "bad assoctype of UML:Association "
             << ID2STR(getID()) << endl;
             return false;
         }
@@ -446,11 +454,11 @@ Uml::IDType UMLAssociation::getObjectId(Role_Type role) {
     if (o == NULL) {
         QString auxID = roleObj->getSecondaryId();
         if (auxID.isEmpty()) {
-            kdError() << "UMLAssociation::getObjectId(" << role
+            kError() << "UMLAssociation::getObjectId(" << role
             << "): getObject returns NULL" << endl;
             return Uml::id_None;
         } else {
-            kdDebug() << "UMLAssociation::getObjectId(" << role
+            kDebug() << "UMLAssociation::getObjectId(" << role
             << "): using secondary ID " << auxID << endl;
             return STR2ID(auxID);
         }
@@ -503,7 +511,7 @@ void UMLAssociation::setAssocType(Uml::Association_Type assocType) {
         // In this case we need to auto-set the multiplicity/rolenames
         // of the roles
 #ifdef VERBOSE_DEBUGGING
-        kdDebug() << " A new uni-association has been created." << endl;
+        kDebug() << " A new uni-association has been created." << endl;
 #endif
     }
     emit modified();
