@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef ASSOCIATIONWIDGET_H
@@ -245,6 +242,11 @@ public:
      */
     bool contains(UMLWidget* widget);
 
+    /**
+     * Returns true if this AssociationWidget represents a collaboration message.
+     */
+    bool isCollaboration();
+
     /**
      * Gets the association's type.
      *
