@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -23,9 +23,11 @@
 #include "dialogs/umlattributedialog.h"
 #include "object_factory.h"
 
-UMLAttribute::UMLAttribute( const UMLObject *parent, QString Name, Uml::IDType id,
-                            Uml::Visibility s, QString type, QString iv )
-        : UMLClassifierListItem(parent, Name, id) {
+UMLAttribute::UMLAttribute( const UMLObject *parent,
+                            const QString& name, Uml::IDType id,
+                            Uml::Visibility s,
+                            const QString& type, const QString& iv )
+        : UMLClassifierListItem(parent, name, id) {
     m_InitialValue = iv;
     m_BaseType = Uml::ot_Attribute;
     m_Vis = s;
@@ -73,7 +75,7 @@ QString UMLAttribute::toString(Uml::Signature_Type sig) {
     QString s;
 
     if(sig == Uml::st_ShowSig || sig == Uml::st_NoSig) {
-        s = m_Vis.toString(true) + " ";
+        s = m_Vis.toString(true) + ' ';
     }
 
     if(sig == Uml::st_ShowSig || sig == Uml::st_SigNoVis) {
@@ -86,7 +88,7 @@ QString UMLAttribute::toString(Uml::Signature_Type sig) {
         }
         UMLClassifier *ownParent = dynamic_cast<UMLClassifier*>(owningObject);
         if (ownParent == NULL) {
-            kdError() << "UMLAttribute::toString: parent "
+            kError() << "UMLAttribute::toString: parent "
             << owningObject->getName()
             << " is not a UMLClassifier" << endl;
             return "";
@@ -126,7 +128,7 @@ QString UMLAttribute::getFullyQualifiedName(QString separator,
     }
     UMLClassifier *ownParent = dynamic_cast<UMLClassifier*>(owningObject);
     if (ownParent == NULL) {
-        kdError() << "UMLAttribute::getFullyQualifiedName(" << m_Name
+        kError() << "UMLAttribute::getFullyQualifiedName(" << m_Name
         << "): parent " << owningObject->getName()
         << " is not a UMLClassifier" << endl;
         return "";
@@ -180,7 +182,7 @@ UMLObject* UMLAttribute::clone() const
 void UMLAttribute::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
     QDomElement attributeElement = UMLObject::save("UML:Attribute", qDoc);
     if (m_pSecondary == NULL) {
-        kdDebug() << "UMLAttribute::saveToXMI(" << m_Name
+        kDebug() << "UMLAttribute::saveToXMI(" << m_Name
         << "): m_pSecondary is NULL, m_SecondaryId is '"
         << m_SecondaryId << "'" << endl;
     } else {
@@ -226,7 +228,7 @@ bool UMLAttribute::load( QDomElement & element ) {
             break;
         }
         if (m_SecondaryId.isEmpty()) {
-            kdDebug() << "UMLAttribute::load(" << m_Name << "): "
+            kDebug() << "UMLAttribute::load(" << m_Name << "): "
             << "cannot find type." << endl;
         }
     }
@@ -238,7 +240,7 @@ bool UMLAttribute::load( QDomElement & element ) {
     return true;
 }
 
-bool UMLAttribute::showPropertiesDialogue(QWidget* parent) {
+bool UMLAttribute::showPropertiesDialog(QWidget* parent) {
     UMLAttributeDialog dialog(parent, this);
     return dialog.exec();
 }
