@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef ATTRIBUTE_H
@@ -36,8 +36,10 @@ public:
      * @param type      The type of this UMLAttribute.
      * @param iv        The initial value of the attribute.
      */
-    UMLAttribute(const UMLObject *parent, QString name, Uml::IDType id = Uml::id_None,
-             Uml::Visibility s = Uml::Visibility::Private, QString type = "int", QString iv = 0);
+    UMLAttribute(const UMLObject *parent, const QString& name,
+                 Uml::IDType id = Uml::id_None,
+                 Uml::Visibility s = Uml::Visibility::Private,
+                 const QString& type = "int", const QString& iv = 0);
 
     /**
      * Sets up an attribute.
@@ -104,7 +106,7 @@ public:
     /**
      * Display the properties configuration dialog for the attribute.
      */
-    virtual bool showPropertiesDialogue(QWidget* parent);
+    virtual bool showPropertiesDialog(QWidget* parent);
 
     void setParmKind (Uml::Parameter_Direction pk);
     Uml::Parameter_Direction getParmKind () const;
