@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 #include <kdebug.h>
 #include <qdom.h>
@@ -20,6 +17,7 @@
 #include "../umldoc.h"
 #include "../umlview.h"
 #include "../umlobject.h"
+#include "../folder.h"
 #include "../classifier.h"
 #include "../umlwidget.h"
 #include "../umllistview.h"
@@ -313,7 +311,7 @@ bool UMLDrag::decodeClip1(const QMimeSource* mimeSource, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if( !domDoc.setContent(xmiClip, false, &error, &line) ) {
-        kdWarning() << "Can't set content:" << error << " Line:" << line << endl;
+        kWarning() << "Can't set content:" << error << " Line:" << line << endl;
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -347,13 +345,13 @@ bool UMLDrag::decodeClip1(const QMimeSource* mimeSource, UMLObjectList& objects,
         pObject = Object_Factory::makeObjectFromXMI(type);
 
         if( !pObject ) {
-            kdWarning() << "UMLDrag::decodeClip1: Given wrong type of umlobject to create: "
+            kWarning() << "UMLDrag::decodeClip1: Given wrong type of umlobject to create: "
             << type << endl;
             return false;
         }
         pObject->setInPaste( true );
         if( !pObject->loadFromXMI( element ) ) {
-            kdWarning() << "UMLDrag::decodeClip1: failed to load object of type "
+            kWarning() << "UMLDrag::decodeClip1: failed to load object of type "
             << type << " from XMI" << endl;
             delete pObject;
             return false;
@@ -371,7 +369,8 @@ bool UMLDrag::decodeClip1(const QMimeSource* mimeSource, UMLObjectList& objects,
                 return false;
             }
             Uml::Object_Type type = pObject->getBaseType();
-            QString newName = Model_Utils::uniqObjectName(type, pObject->getName());
+            QString newName = Model_Utils::uniqObjectName(type, pObject->getUMLPackage(),
+                                                                pObject->getName());
             pObject->setName(newName);
             /****************************************************************/
 
@@ -387,7 +386,7 @@ bool UMLDrag::decodeClip1(const QMimeSource* mimeSource, UMLObjectList& objects,
     QDomNode listItems = listItemNode.firstChild();
     QDomElement listItemElement = listItems.toElement();
     if ( listItemElement.isNull() ) {
-        kdWarning() << "no listitems in XMI clip" << endl;
+        kWarning() << "no listitems in XMI clip" << endl;
         return false;
     }
     UMLListViewItem *currentItem = (UMLListViewItem*)listView->currentItem();
@@ -407,7 +406,7 @@ bool UMLDrag::decodeClip1(const QMimeSource* mimeSource, UMLObjectList& objects,
             Uml::IDType newID = idchanges->findNewID(oldID);
             UMLListViewItem *shouldNotExist = listView->findItem(newID);
             if (shouldNotExist) {
-                kdDebug() << "UMLDrag::decodeClip1: new list view item "
+                kDebug() << "UMLDrag::decodeClip1: new list view item "
                 << ID2STR(newID) << " already exists" << endl;
                 listItems = listItems.nextSibling();
                 listItemElement = listItems.toElement();
@@ -415,16 +414,16 @@ bool UMLDrag::decodeClip1(const QMimeSource* mimeSource, UMLObjectList& objects,
             }
             UMLObject *newObj = doc->findObjectById(newID);
             if (newObj) {
-                kdDebug() << "UMLDrag::decodeClip1: adjusting lvitem(" << ID2STR(oldID)
+                kDebug() << "UMLDrag::decodeClip1: adjusting lvitem(" << ID2STR(oldID)
                 << ") to new UMLObject(" << ID2STR(newID) << ")" << endl;
                 itemData->setUMLObject(newObj);
                 itemData->setText(newObj->getName());
                 if (! listView->loadChildrenFromXMI(itemData, listItemElement)) {
-                    kdError() << "UMLDrag::decodeClip1: listView->loadChildrenFromXMI() failed"
+                    kError() << "UMLDrag::decodeClip1: listView->loadChildrenFromXMI() failed"
                     << endl;
                 }
             } else {
-                kdDebug() << "UMLDrag::decodeClip1: no UMLObject found for lvitem "
+                kDebug() << "UMLDrag::decodeClip1: no UMLObject found for lvitem "
                 << ID2STR(newID) << endl;
             }
         }
@@ -450,7 +449,7 @@ bool UMLDrag::decodeClip2(const QMimeSource* mimeSource, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if( !domDoc.setContent(xmiClip, false, &error, &line) ) {
-        kdWarning() << "Can't set content:" << error << " Line:" << line << endl;
+        kWarning() << "Can't set content:" << error << " Line:" << line << endl;
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -478,11 +477,11 @@ bool UMLDrag::decodeClip2(const QMimeSource* mimeSource, UMLObjectList& objects,
             pObject = Object_Factory::makeObjectFromXMI(type);
 
             if( !pObject ) {
-                kdWarning() << "Given wrong type of umlobject to create:" << type << endl;
+                kWarning() << "Given wrong type of umlobject to create:" << type << endl;
                 return false;
             }
             if( !pObject->loadFromXMI(element) ) {
-                kdWarning() << "failed to load object from XMI" << endl;
+                kWarning() << "failed to load object from XMI" << endl;
                 return false;
             }
             objects.append(pObject);
@@ -496,11 +495,23 @@ bool UMLDrag::decodeClip2(const QMimeSource* mimeSource, UMLObjectList& objects,
     QDomNode diagramNode = umlviewsNode.firstChild();
     QDomElement diagramElement = diagramNode.toElement();
     if ( diagramElement.isNull() ) {
-        kdWarning() << "no diagrams in XMI clip" << endl;
+        kWarning() << "no diagrams in XMI clip" << endl;
         return false;
     }
+    UMLListView *listView = UMLApp::app()->getListView();
     while ( !diagramElement.isNull() ) {
-        UMLView* view = new UMLView();
+        QString type = diagramElement.attribute("type", "0");
+        Uml::Diagram_Type dt = (Uml::Diagram_Type)type.toInt();
+        UMLListViewItem *parent = listView->findFolderForDiagram(dt);
+        if (parent == NULL)
+            return false;
+        UMLObject *po = parent->getUMLObject();
+        if (po == NULL || po->getBaseType() != Uml::ot_Folder) {
+            kError() << "UMLDrag::decodeClip2: bad parent for view" << endl;
+            return false;
+        }
+        UMLFolder *f = static_cast<UMLFolder*>(po);
+        UMLView* view = new UMLView(f);
         view->loadFromXMI(diagramElement);
         diagrams.append(view);
         diagramNode = diagramNode.nextSibling();
@@ -512,10 +523,9 @@ bool UMLDrag::decodeClip2(const QMimeSource* mimeSource, UMLObjectList& objects,
     QDomNode listItems = listItemNode.firstChild();
     QDomElement listItemElement = listItems.toElement();
     if ( listItemElement.isNull() ) {
-        kdWarning() << "no listitems in XMI clip" << endl;
+        kWarning() << "no listitems in XMI clip" << endl;
         return false;
     }
-    UMLListView *listView = UMLApp::app()->getListView();
     UMLListViewItem *currentItem = (UMLListViewItem*)listView->currentItem();
     while ( !listItemElement.isNull() ) {
         UMLListViewItem* itemData;
@@ -550,7 +560,7 @@ bool UMLDrag::getClip3TypeAndID(const QMimeSource* mimeSource,
     int line;
     QDomDocument domDoc;
     if( !domDoc.setContent(xmiClip, false, &error, &line) ) {
-        kdWarning() << "getClip3Type: Can't set content:" << error << " Line:" << line << endl;
+        kWarning() << "getClip3Type: Can't set content:" << error << " Line:" << line << endl;
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -567,18 +577,18 @@ bool UMLDrag::getClip3TypeAndID(const QMimeSource* mimeSource,
     QDomNode listItems = listItemNode.firstChild();
     QDomElement listItemElement = listItems.toElement();
     if ( listItemElement.isNull() ) {
-        kdWarning() << "getClip3Type: no listitems in XMI clip" << endl;
+        kWarning() << "getClip3Type: no listitems in XMI clip" << endl;
         return false;
     }
     while ( !listItemElement.isNull() ) {
         QString typeStr = listItemElement.attribute( "type", "-1" );
         if (typeStr == "-1") {
-            kdDebug() << "getClip3Type: bad type" << endl;
+            kDebug() << "getClip3Type: bad type" << endl;
             return false;
         }
         QString idStr = listItemElement.attribute( "id", "-1" );
         if (idStr == "-1") {
-            kdDebug() << "getClip3Type: bad id" << endl;
+            kDebug() << "getClip3Type: bad id" << endl;
             return false;
         }
         LvTypeAndID * pData = new LvTypeAndID;
@@ -608,7 +618,7 @@ bool UMLDrag::decodeClip3(const QMimeSource* mimeSource,
     int line;
     QDomDocument domDoc;
     if( !domDoc.setContent(xmiClip, false, &error, &line) ) {
-        kdWarning() << "Can't set content:" << error << " Line:" << line << endl;
+        kWarning() << "Can't set content:" << error << " Line:" << line << endl;
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -626,7 +636,7 @@ bool UMLDrag::decodeClip3(const QMimeSource* mimeSource,
     QDomNode listItems = listItemNode.firstChild();
     QDomElement listItemElement = listItems.toElement();
     if ( listItemElement.isNull() ) {
-        kdWarning() << "no listitems in XMI clip" << endl;
+        kWarning() << "no listitems in XMI clip" << endl;
         return false;
     }
     while ( !listItemElement.isNull() ) {
@@ -634,7 +644,7 @@ bool UMLDrag::decodeClip3(const QMimeSource* mimeSource,
         // UMLListViewItem instance.
         QString type = listItemElement.attribute( "type", "-1" );
         if (type == "-1") {
-            kdDebug() << "Pech gehabt" << endl;
+            kDebug() << "Pech gehabt" << endl;
             continue;
         }
         Uml::ListView_Type t = (Uml::ListView_Type)(type.toInt());
@@ -668,7 +678,7 @@ bool UMLDrag::decodeClip4(const QMimeSource* mimeSource, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if( !domDoc.setContent(xmiClip, false, &error, &line) ) {
-        kdWarning() << "Can't set content:" << error << " Line:" << line << endl;
+        kWarning() << "Can't set content:" << error << " Line:" << line << endl;
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -696,11 +706,11 @@ bool UMLDrag::decodeClip4(const QMimeSource* mimeSource, UMLObjectList& objects,
         pObject = Object_Factory::makeObjectFromXMI(type);
 
         if ( !pObject ) {
-            kdWarning() << "Given wrong type of umlobject to create: " << type << endl;
+            kWarning() << "Given wrong type of umlobject to create: " << type << endl;
             return false;
         }
         if ( !pObject->loadFromXMI( element ) ) {
-            kdWarning() << "failed to load object from XMI" << endl;
+            kWarning() << "failed to load object from XMI" << endl;
             return false;
         }
         objects.append(pObject);
@@ -712,11 +722,12 @@ bool UMLDrag::decodeClip4(const QMimeSource* mimeSource, UMLObjectList& objects,
     QDomNode widgetNode = widgetsNode.firstChild();
     QDomElement widgetElement = widgetNode.toElement();
     if ( widgetElement.isNull() ) {
-        kdWarning() << "no widgets in XMI clip" << endl;
+        kWarning() << "no widgets in XMI clip" << endl;
         return false;
     }
+    UMLView *view = UMLApp::app()->getCurrentView();
     while ( !widgetElement.isNull() ) {
-        UMLWidget* widget = doc->getCurrentView()->loadWidgetFromXMI(widgetElement);
+        UMLWidget* widget = view->loadWidgetFromXMI(widgetElement);
         widgets.append(widget);
         widgetNode = widgetNode.nextSibling();
         widgetElement = widgetNode.toElement();
@@ -727,7 +738,6 @@ bool UMLDrag::decodeClip4(const QMimeSource* mimeSource, UMLObjectList& objects,
     QDomNode associationWidgetNode = associationWidgetsNode.firstChild();
     QDomElement associationWidgetElement = associationWidgetNode.toElement();
     while ( !associationWidgetElement.isNull() ) {
-        UMLView *view = UMLApp::app()->getCurrentView();
         AssociationWidget* associationWidget = new AssociationWidget(view);
         if (associationWidget->loadFromXMI(associationWidgetElement, widgets))
             associations.append(associationWidget);
@@ -776,7 +786,7 @@ bool UMLDrag::decodeClip5(const QMimeSource* mimeSource, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if( !domDoc.setContent(xmiClip, false, &error, &line) ) {
-        kdWarning() << "Can't set content:" << error << " Line:" << line << endl;
+        kWarning() << "Can't set content:" << error << " Line:" << line << endl;
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -800,11 +810,11 @@ bool UMLDrag::decodeClip5(const QMimeSource* mimeSource, UMLObjectList& objects,
         QString type = element.tagName();
         UMLClassifierListItem *pObject = newParent->makeChildObject(type);
         if( !pObject ) {
-            kdWarning() << "Given wrong type of umlobject to create:" << type << endl;
+            kWarning() << "Given wrong type of umlobject to create:" << type << endl;
             return false;
         }
         if( !pObject->loadFromXMI( element ) ) {
-            kdWarning() << "failed to load object from XMI" << endl;
+            kWarning() << "failed to load object from XMI" << endl;
             return false;
         }
         pObject->resolveRef();
@@ -818,7 +828,7 @@ bool UMLDrag::decodeClip5(const QMimeSource* mimeSource, UMLObjectList& objects,
         QDomNode listItems = listItemNode.firstChild();
         QDomElement listItemElement = listItems.toElement();
         if ( listItemElement.isNull() ) {
-                kdWarning() << "no listitems in XMI clip" << endl;
+                kWarning() << "no listitems in XMI clip" << endl;
                 return false;
         }
         UMLListView *listView = UMLApp::app()->getListView();
