@@ -3,7 +3,7 @@
  *                           -------------------                           *
  *  Based on javawriter.cpp by Luis De la Parra Blum                       *
  *  copyright            : (C) 2002 by Oliver Kellogg                      *
- *    (C) 2003-2006 Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>  *
+ *    (C) 2003-2006 Umbrello UML Modeller Authors <uml-devel@uml.sf.net>   *
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,12 +23,13 @@
 #include <qtextstream.h>
 
 #include "../umldoc.h"
+#include "../uml.h"
 #include "../classifier.h"
 #include "../enum.h"
 #include "../classifierlistitem.h"
 #include "../umlclassifierlistitemlist.h"
 #include "../umltemplatelist.h"
-#include "../package.h"
+#include "../folder.h"
 #include "../association.h"
 #include "../attribute.h"
 #include "../operation.h"
@@ -57,7 +58,7 @@ bool AdaWriter::isOOClass(UMLClassifier *c) {
     if (ot == Uml::ot_Enum)
         return false;
     if (ot != Uml::ot_Class) {
-        kdDebug() << "AdaWriter::isOOClass: unknown object type " << ot << endl;
+        kDebug() << "AdaWriter::isOOClass: unknown object type " << ot << endl;
         return false;
     }
     QString stype = c->getStereotype();
@@ -69,25 +70,29 @@ bool AdaWriter::isOOClass(UMLClassifier *c) {
     return true;
 }
 
-QString AdaWriter::qualifiedName(UMLClassifier *c, bool withType, bool byValue) {
-    UMLPackage *umlPkg = c->getUMLPackage();
-    QString className = cleanName(c->getName());
+QString AdaWriter::qualifiedName(UMLPackage *p, bool withType, bool byValue) {
+    UMLPackage *umlPkg = p->getUMLPackage();
+    QString className = cleanName(p->getName());
     QString retval;
 
+    if (umlPkg == UMLApp::app()->getDocument()->getRootFolder(Uml::mt_Logical))
+        umlPkg = NULL;
+
+    UMLClassifier *c = dynamic_cast<UMLClassifier*>(p);
     if (umlPkg == NULL) {
         retval = className;
-        if (! isOOClass(c))
+        if (c == NULL || !isOOClass(c))
             retval.append(defaultPackageSuffix);
     } else {
         retval = umlPkg->getFullyQualifiedName(".");
-        if (isOOClass(c)) {
+        if (c && isOOClass(c)) {
             retval.append(".");
             retval.append(className);
         }
     }
     if (! withType)
         return retval;
-    if (isOOClass(c)) {
+    if (c && isOOClass(c)) {
         retval.append(".Object");
         if (! byValue)
             retval.append("_Ptr");
@@ -120,7 +125,7 @@ void AdaWriter::computeAssocTypeAndRole
 
 void AdaWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kdDebug() << "Cannot write class of NULL concept!" << endl;
+        kDebug() << "Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -155,10 +160,10 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     }
 
     // Import referenced classes.
-    UMLClassifierList imports;
+    UMLPackageList imports;
     findObjectsRelated(c, imports);
     if (imports.count()) {
-        for (UMLClassifier *con = imports.first(); con; con = imports.next()) {
+        for (UMLPackage *con = imports.first(); con; con = imports.next()) {
             if (con->getBaseType() != Uml::ot_Datatype)
                 ada << "with " << qualifiedName(con) << "; " << m_endl;
         }
@@ -180,7 +185,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
                 // Check whether it's a data type.
                 UMLClassifier *typeObj = t->getType();
                 if (typeObj == NULL) {
-                    kdError() << "AdaWriter::writeClass(template_param "
+                    kError() << "AdaWriter::writeClass(template_param "
                     << typeName << "): typeObj is NULL" << endl;
                     ada << getIndent() << "type " << formalName << " is new " << typeName
                     << " with private;  -- CHECK: codegen error"
@@ -464,7 +469,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
 
 
 void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comment) {
-    UMLAttributeList *atl = op->getParmList();
+    UMLAttributeList atl = op->getParmList();
     QString rettype = op->getTypeName();
     bool use_procedure = (rettype.isEmpty() || rettype == "void");
 
@@ -476,17 +481,17 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
     else
         ada << "function ";
     ada << cleanName(op->getName()) << " ";
-    if (! (op->getStatic() && atl->count() == 0))
+    if (! (op->getStatic() && atl.count() == 0))
         ada << "(";
     if (! op->getStatic()) {
         ada << "Self : access Object";
-        if (atl->count())
+        if (atl.count())
             ada << ";" << m_endl;
     }
-    if (atl->count()) {
+    if (atl.count()) {
         uint i = 0;
         m_indentLevel++;
-        for (UMLAttribute *at = atl->first(); at; at = atl->next()) {
+        for (UMLAttribute *at = atl.first(); at; at = atl.next()) {
             ada << getIndent();
             if (is_comment)
                 ada << "-- ";
@@ -501,12 +506,12 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
             ada << at->getTypeName();
             if (! at->getInitialValue().isEmpty())
                 ada << " := " << at->getInitialValue();
-            if (++i < atl->count()) //FIXME gcc warning
+            if (++i < atl.count()) //FIXME gcc warning
                 ada << ";" << m_endl;
         }
         m_indentLevel--;
     }
-    if (! (op->getStatic() && atl->count() == 0))
+    if (! (op->getStatic() && atl.count() == 0))
         ada << ")";
     if (! use_procedure)
         ada << " return " << rettype;
@@ -526,6 +531,7 @@ QStringList AdaWriter::defaultDatatypes() {
     l.append("Long_Integer");
     l.append("Float");
     l.append("Long_Float");
+    l.append("Duration");
     l.append("String");
     return l;
 }
