@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   (C) 2004  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>       *
+ *   (C) 2004  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>        *
  ***************************************************************************/
 
 #ifndef CODEGEN_UTILS_H
@@ -13,17 +13,22 @@
 
 #include <qstringlist.h>
 
-namespace Umbrello {
+namespace Codegen_Utils {
 
-	/**
-	 * Add C++ primitives as datatypes
-	 */
-	void createCppDatatypes();
+/**
+ * Return list of C++ datatypes
+ */
+QStringList cppDatatypes();
 
-	/**
-	 * Get list of C++ reserved keywords
-	 */
-	const QStringList reservedCppKeywords();
+/**
+ * Get list of C++ reserved keywords
+ */
+const QStringList reservedCppKeywords();
+
+/**
+ * Add C++ stereotypes
+ */
+void createCppStereotypes();
 
 }
 
