@@ -1,20 +1,19 @@
 /***************************************************************************
-                          cppwriter.cpp  -  description
-    This is the "old" code generator that does not support code editing
-    in the Modeller but uses significantly less file space because the
-    source code is not replicated in the XMI file.
-                             -------------------
-    copyright       : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-         (C) 2004  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
-***************************************************************************/
-
-/***************************************************************************
- *                                                                       *
+ *                        cppwriter.cpp  -  description                    *
+ *  This is the "old" code generator that does not support code editing    *
+ *  in the Modeller but uses significantly less file space because the     *
+ *  source code is not replicated in the XMI file.                         *
+ *                                                                         *
+ *  copyright       : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov     *
+ *  (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>    *
+ *                                                                         *
+ ***************************************************************************
+ *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
- *                                                                       *
+ *                                                                         *
  ***************************************************************************/
 
 // own header
@@ -58,7 +57,7 @@ CppWriter::CppWriter()
     // %VECTOR_TYPENAME%, which is as definition above.
     VECTOR_METHOD_APPEND = "%VARNAME%.push_back(add_object);"; // for std::vector
     VECTOR_METHOD_REMOVE = "int i, size = %VARNAME%.size();\nfor ( i = 0; i < size; i++) {\n\t%ITEMCLASS% item = %VARNAME%.at(i);\n\tif(item == remove_object) {\n\t\tvector<%ITEMCLASS%>::iterator it = %VARNAME%.begin() + i;\n\t\t%VARNAME%.erase(it);\n\t\treturn;\n\t}\n }"; // for std::vector
-    VECTOR_METHOD_INIT = ""; // nothing to be done
+    VECTOR_METHOD_INIT = QString(); // nothing to be done
     /*
         VECTOR_METHOD_APPEND = "%VARNAME%.append(&add_object);"; // Qt lib implementation
         VECTOR_METHOD_REMOVE = "%VARNAME%.removeRef(&remove_object);"; // Qt lib implementation
@@ -93,7 +92,7 @@ void CppWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kdDebug() << "Cannot write class of NULL concept!\n";
+        kDebug() << "Cannot write class of NULL concept!\n";
         return;
     }
 
@@ -552,8 +551,6 @@ void CppWriter::writeAttributeDecls (Uml::Visibility visibility, bool writeStati
 
     }
 
-    return;
-
 }
 
 void CppWriter::writeHeaderAttributeAccessorMethods (Uml::Visibility visibility, bool writeStatic, QTextStream &stream )
@@ -585,9 +582,16 @@ void CppWriter::writeHeaderAttributeAccessorMethods (Uml::Visibility visibility,
         break;
     }
 
+    // switch to public
+    if (visibility != Uml::Visibility::Public)
+        stream << "public:" << m_endl << m_endl;
+
     // write accessor methods for attribs we found
     writeAttributeMethods(list, visibility, true, false, INLINE_ATTRIBUTE_METHODS, stream);
 
+    // switch back to previous vis.
+    if (visibility != Uml::Visibility::Public)
+        stream << visibility.toString() << ":" << m_endl << m_endl;
 }
 
 // this is for writing *source* or *header* file attribute methods
@@ -625,7 +629,7 @@ void CppWriter::writeAttributeMethods(UMLAttributeList *attribs,
         // force capitalizing the field name, this is silly,
         // from what I can tell, this IS the default behavior for
         // cleanName. I dunno why its not working -b.t.
-        methodBaseName.stripWhiteSpace();
+        methodBaseName = methodBaseName.stripWhiteSpace();
         methodBaseName.replace(0,1,methodBaseName.at(0).upper());
 
         writeSingleAttributeAccessorMethods(at->getTypeName(), varName,
@@ -635,7 +639,7 @@ void CppWriter::writeAttributeMethods(UMLAttributeList *attribs,
 
 }
 
-void CppWriter::writeComment(QString comment, QString myIndent, QTextStream &cpp)
+void CppWriter::writeComment(const QString &comment, const QString &myIndent, QTextStream &cpp)
 {
     // in the case we have several line comment..
     // NOTE: this part of the method has the problem of adopting UNIX newline,
@@ -815,11 +819,11 @@ void CppWriter::writeAssociationMethods (UMLAssociationList associations,
     }
 }
 
-void CppWriter::writeAssociationRoleMethod (QString fieldClassName,
+void CppWriter::writeAssociationRoleMethod (const QString &fieldClassName,
         bool isHeaderMethod,
         bool writeMethodBody,
-        QString roleName, QString multi,
-        QString description, Uml::Changeability_Type change,
+        const QString &roleName, const QString &multi,
+        const QString &description, Uml::Changeability_Type change,
         QTextStream &stream)
 {
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
@@ -836,31 +840,32 @@ void CppWriter::writeAssociationRoleMethod (QString fieldClassName,
     }
 }
 
-void CppWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QString fieldVarName,
-        QString fieldName, QString description,
+void CppWriter::writeVectorAttributeAccessorMethods (
+        const QString &fieldClassName, const QString &fieldVarName,
+        const QString &fieldName, const QString &description,
         Uml::Changeability_Type changeType,
         bool isHeaderMethod,
         bool writeMethodBody,
         QTextStream &stream)
 {
 
-    fieldClassName = fixTypeName(fieldClassName);
-    fieldName = capitalizeFirstLetter(fieldName);
+    QString className = fixTypeName(fieldClassName);
+    QString fldName = capitalizeFirstLetter(fieldName);
     QString indent = getIndent();
 
     // ONLY IF changeability is NOT Frozen
     if (changeType != Uml::chg_Frozen)
     {
-        writeDocumentation("Add a " + fieldName + " object to the " + fieldVarName + " List",description,"",stream);
+        writeDocumentation("Add a " + fldName + " object to the " + fieldVarName + " List",description,"",stream);
         stream << indent << "void ";
         if(!isHeaderMethod)
             stream << m_classifierInfo->className << "::";
-        stream << "add" << fieldName << " ( " << fieldClassName << " add_object )";
+        stream << "add" << fldName << " ( " << className << " add_object )";
         if (writeMethodBody) {
             QString method = VECTOR_METHOD_APPEND;
             method.replace(QRegExp("%VARNAME%"),fieldVarName);
             method.replace(QRegExp("%VECTORTYPENAME%"), VECTOR_TYPENAME);
-            method.replace(QRegExp("%ITEMCLASS%"),fieldClassName);
+            method.replace(QRegExp("%ITEMCLASS%"),className);
             stream << indent << " {" << m_endl;
             m_indentLevel++;
             printTextAsSeparateLinesWithIndent(method,getIndent(),stream);
@@ -873,16 +878,17 @@ void CppWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QSt
     // ONLY IF changeability is Changeable
     if (changeType == Uml::chg_Changeable)
     {
-        writeDocumentation("Remove a " + fieldName + " object from " + fieldVarName + " List",description,"",stream);
+        writeDocumentation("Remove a " + fldName + " object from " + fieldVarName + " List",
+                           description, "", stream);
         stream << indent << "void ";
         if(!isHeaderMethod)
             stream << m_classifierInfo->className << "::";
-        stream << "remove" << fieldName << " ( " << fieldClassName << " remove_object )";
+        stream << "remove" << fldName << " ( " << className << " remove_object )";
         if (writeMethodBody) {
             QString method = VECTOR_METHOD_REMOVE;
             method.replace(QRegExp("%VARNAME%"),fieldVarName);
             method.replace(QRegExp("%VECTORTYPENAME%"), VECTOR_TYPENAME);
-            method.replace(QRegExp("%ITEMCLASS%"),fieldClassName);
+            method.replace(QRegExp("%ITEMCLASS%"),className);
             stream << indent << " {" << m_endl;
             m_indentLevel++;
             printTextAsSeparateLinesWithIndent(method,getIndent(),stream);
@@ -893,12 +899,15 @@ void CppWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QSt
     }
 
     // always allow getting the list of stuff
-    QString returnVarName = VECTOR_TYPENAME + "<" + fieldClassName + ">";
-    writeDocumentation("Get the list of " + fieldName + " objects held by " + fieldVarName,description,"@return " + returnVarName + " list of " + fieldName + " objects held by " + fieldVarName,stream);
+    QString returnVarName = VECTOR_TYPENAME + '<' + className + '>';
+    writeDocumentation("Get the list of " + fldName + " objects held by " + fieldVarName,
+                       description,
+                       "@return " + returnVarName + " list of " + fldName + " objects held by " + fieldVarName,
+                       stream);
     stream << indent << returnVarName << " ";
     if(!isHeaderMethod)
         stream << m_classifierInfo->className << "::";
-    stream << "get" << fieldName << "List ( )";
+    stream << "get" << fldName << "List ( )";
     if(writeMethodBody) {
         stream << indent << " {" << m_endl;
         m_indentLevel++;
@@ -911,8 +920,9 @@ void CppWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QSt
 }
 
 
-void CppWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QString fieldVarName,
-        QString fieldName, QString description,
+void CppWriter::writeSingleAttributeAccessorMethods(
+        const QString &fieldClassName, const QString& fieldVarName,
+        const QString &fieldName, const QString &description,
         Uml::Changeability_Type change,
         bool isHeaderMethod,
         bool isStatic,
@@ -924,8 +934,8 @@ void CppWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QStr
     if(!isHeaderMethod && !writeMethodBody)
         return;
 
-    fieldClassName = fixTypeName(fieldClassName);
-    fieldName = capitalizeFirstLetter(fieldName);
+    QString className = fixTypeName(fieldClassName);
+    QString fldName = capitalizeFirstLetter(fieldName);
     QString indent = getIndent();
 
     // set method
@@ -934,7 +944,7 @@ void CppWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QStr
         stream << indent << "void ";
         if(!isHeaderMethod)
             stream << m_classifierInfo->className << "::";
-        stream << "set" << fieldName << " ( " << fieldClassName << " new_var )";
+        stream << "set" << fldName << " ( " << className << " new_var )";
 
         if(writeMethodBody) {
             stream << indent << " {" << m_endl;
@@ -951,10 +961,10 @@ void CppWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QStr
 
     // get method
     writeDocumentation("Get the value of " + fieldVarName,description,"@return the value of " + fieldVarName,stream);
-    stream << indent << fieldClassName << " ";
+    stream << indent << className << " ";
     if(!isHeaderMethod)
         stream << m_classifierInfo->className << "::";
-    stream << "get" << fieldName << " ( )";
+    stream << "get" << fldName << " ( )";
 
     if(writeMethodBody) {
         stream << indent << " {" << m_endl;
@@ -1028,7 +1038,7 @@ void CppWriter::writeInitAttibuteMethod (QTextStream &stream)
             }
         }
         // Now initialize the association related fields (e.g. vectors)
-        if (VECTOR_METHOD_INIT != "") {
+        if (!VECTOR_METHOD_INIT.isEmpty()) {
             QStringList::Iterator it;
             for( it = VectorFieldVariables.begin(); it != VectorFieldVariables.end(); ++it ) {
                 QString fieldVarName = *it;
@@ -1039,7 +1049,7 @@ void CppWriter::writeInitAttibuteMethod (QTextStream &stream)
             }
         }
 
-        if (OBJECT_METHOD_INIT != "") {
+        if (!OBJECT_METHOD_INIT.isEmpty()) {
             QStringList::Iterator it;
             for( it = ObjectFieldVariables.begin(); it != ObjectFieldVariables.end(); ++it ) {
                 QString fieldVarName = *it;
@@ -1097,11 +1107,12 @@ void CppWriter::writeConstructorMethods(QTextStream &stream)
 
 // IF the type is "string" we need to declare it as
 // the Java Object "String" (there is no string primative in Java).
-QString CppWriter::fixTypeName(QString string)
+QString CppWriter::fixTypeName(const QString &string)
 {
     if (string.isEmpty())
         return "void";
-    string.replace(QRegExp("^string$"), STRING_TYPENAME);
+    if (string == "string")
+        return STRING_TYPENAME;
     return string;
 }
 
@@ -1138,12 +1149,12 @@ void CppWriter::writeOperations(UMLOperationList &oplist, bool isHeaderMethod, Q
     // generate method decl for each operation given
     for (UMLOperation *op = oplist.first(); op; op = oplist.next()) {
 
-        QString returnStr = "";  // buffer for documentation
-        QString methodReturnType = "";
-        UMLAttributeList *atl = op->getParmList();  // method parameters
+        QString returnStr;  // buffer for documentation
+        QString methodReturnType;
+        UMLAttributeList atl = op->getParmList();  // method parameters
 
         if (op->isConstructorOperation()) {
-            if (WRITE_EMPTY_CONSTRUCTOR && atl->count() == 0)
+            if (WRITE_EMPTY_CONSTRUCTOR && atl.count() == 0)
                 continue;  // it's already been written, see writeConstructor{Decls,Methods}
         } else if (op->isDestructorOperation()) {
             if (WRITE_EMPTY_DESTRUCTOR)
@@ -1151,7 +1162,7 @@ void CppWriter::writeOperations(UMLOperationList &oplist, bool isHeaderMethod, Q
         } else {
             methodReturnType = fixTypeName(op->getTypeName());
             if(methodReturnType != "void")
-                returnStr += "@return " + methodReturnType + "\n";
+                returnStr += "@return " + methodReturnType + '\n';
         }
 
         QString str;
@@ -1167,7 +1178,7 @@ void CppWriter::writeOperations(UMLOperationList &oplist, bool isHeaderMethod, Q
             str += "static ";
 
         // returntype of method
-        str += methodReturnType + " ";
+        str += methodReturnType + ' ';
 
         if (!isHeaderMethod)
             str += className + "::";
@@ -1176,16 +1187,16 @@ void CppWriter::writeOperations(UMLOperationList &oplist, bool isHeaderMethod, Q
 
         // generate parameters
         uint j = 0;
-        for (UMLAttribute *at = atl->first(); at; at = atl->next(), j++) {
+        for (UMLAttribute *at = atl.first(); at; at = atl.next(), j++) {
             QString typeName = fixTypeName(at->getTypeName());
             QString atName = cleanName(at->getName());
-            str += typeName + " " + atName;
+            str += typeName + ' ' + atName;
             const QString initVal = at->getInitialValue();
             if (! initVal.isEmpty())
                 str += " = " + initVal;
-            if (j < atl->count() - 1)
+            if (j < atl.count() - 1)
                 str += ", ";
-            returnStr += "@param  " + atName + " " + at->getDoc() + "\n";
+            returnStr += "@param  " + atName + ' ' + at->getDoc() + '\n';
         }
         str += " )";
 
@@ -1194,9 +1205,9 @@ void CppWriter::writeOperations(UMLOperationList &oplist, bool isHeaderMethod, Q
 
         // method body : only gets IF its not in a header
         if (isHeaderMethod && !INLINE_OPERATION_METHODS)
-            str +=";"; // terminate now
+            str += ';'; // terminate now
         else
-            str +=getIndent() + " {\n\n" + getIndent() + "}"; // empty method body
+            str +=getIndent() + " {\n\n" + getIndent() + '}'; // empty method body
 
         // write it out
         writeDocumentation("", op->getDoc(), returnStr, cpp);
@@ -1235,16 +1246,17 @@ void CppWriter::printAssociationIncludeDecl (UMLAssociationList list, Uml::IDTyp
     }
 }
 
-QString CppWriter::fixInitialStringDeclValue(QString value, QString type)
+QString CppWriter::fixInitialStringDeclValue(const QString &value, const QString &type)
 {
+    QString val = value;
     // check for strings only
-    if (!value.isEmpty() && type == STRING_TYPENAME) {
-        if (!value.startsWith("\""))
-            value.prepend("\"");
-        if (!value.endsWith("\""))
-            value.append("\"");
+    if (!val.isEmpty() && type == STRING_TYPENAME) {
+        if (!val.startsWith("\""))
+            val.prepend("\"");
+        if (!val.endsWith("\""))
+            val.append("\"");
     }
-    return value;
+    return val;
 }
 
 // methods like this _shouldn't_ be needed IF we properly did things thruought the code.
@@ -1253,13 +1265,12 @@ QString CppWriter::getUMLObjectName(UMLObject *obj)
     return(obj!=0)?obj->getName():QString("NULL");
 }
 
-QString CppWriter::capitalizeFirstLetter(QString string)
+QString CppWriter::capitalizeFirstLetter(const QString &string)
 {
     // we could lowercase everything tostart and then capitalize? Nah, it would
     // screw up formatting like getMyRadicalVariable() to getMyradicalvariable(). Bah.
     QChar firstChar = string.at(0);
-    string.replace( 0, 1, firstChar.upper());
-    return string;
+    return firstChar + string.mid(1);
 }
 
 void CppWriter::writeBlankLine(QTextStream &stream)
@@ -1267,7 +1278,7 @@ void CppWriter::writeBlankLine(QTextStream &stream)
     stream << m_endl;
 }
 
-void CppWriter::printTextAsSeparateLinesWithIndent (QString text, QString indent, QTextStream &stream)
+void CppWriter::printTextAsSeparateLinesWithIndent (const QString &text, const QString &indent, QTextStream &stream)
 {
     if(text.isEmpty())
         return;
