@@ -5,7 +5,7 @@
     source code is not replicated in the XMI file.
                              -------------------
     copyright            : (C) 2003 Brian Thomas
-         (C) 2004  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+         (C) 2004  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,7 +40,7 @@ public:
     /**
      * Constructor, initialises a couple of variables
      */
-    CppWriter(UMLDoc* parent = 0, const char* name = 0);
+    CppWriter();
 
     /**
      * Destructor, empty
@@ -53,22 +53,15 @@ public:
      */
     virtual void writeClass(UMLClassifier *c);
 
-    /**
-     * checks whether type is "CppWriter"
-     *
-     * @param type
-     */
-    virtual bool isType (QString & type);
-
     /**
      * returns "C++"
      */
-    virtual QString getLanguage();
+    virtual Uml::Programming_Language getLanguage();
 
     /**
      * Add C++ primitives as datatypes
      */
-    void createDefaultDatatypes();
+    QStringList defaultDatatypes();
 
     /**
      * get list of reserved keywords
@@ -175,15 +168,17 @@ private:
      * writeVectorAttributeAccessorMethods() on the association
      * role
      */
-    void writeAssociationRoleMethod(QString fieldClassName, bool isHeaderMethod, bool writeMethodBody, QString roleName, QString multi,
-                                    QString description, Uml::Changeability_Type change,
+    void writeAssociationRoleMethod(const QString &fieldClassName, bool isHeaderMethod, bool writeMethodBody,
+                                    const QString &roleName, const QString &multi,
+                                    const QString &description, Uml::Changeability_Type change,
                                     QTextStream &stream);
 
     /**
      * Writes getFoo() and setFoo() accessor methods for the attribute
      */
-    void writeSingleAttributeAccessorMethods(QString fieldClassName, QString fieldVarName,
-            QString fieldName, QString description,
+    void writeSingleAttributeAccessorMethods(
+            const QString &fieldClassName, const QString &Name,
+            const QString &fieldName, const QString &description,
             Uml::Changeability_Type change,
             bool isHeaderMethod,
             bool isStatic, bool writeMethodBody, QTextStream &cpp);
@@ -191,8 +186,9 @@ private:
     /**
      * Writes addFoo() and removeFoo() accessor methods for the Vector attribute
      */
-    void writeVectorAttributeAccessorMethods(QString fieldClassName, QString fieldVarName,
-            QString fieldName, QString description,
+    void writeVectorAttributeAccessorMethods(
+            const QString &fieldClassName, const QString &fieldVarName,
+            const QString &fieldName, const QString &description,
             Uml::Changeability_Type change,
             bool isHeaderMethod,
             bool writeMethodBody,
@@ -201,7 +197,7 @@ private:
     /**
      * Writes a // style comment
      */
-    void writeComment(QString text, QString indent, QTextStream &cpp);
+    void writeComment(const QString &text, const QString &indent, QTextStream &cpp);
 
     /**
      * Writes a documentation comment
@@ -223,7 +219,8 @@ private:
      * utility method to break up a block of text, which has embedded newline chars,
      * and print them to a stream as separate lines of text, indented as directed.
      */
-    void printTextAsSeparateLinesWithIndent (QString text, QString indent, QTextStream &stream);
+    void printTextAsSeparateLinesWithIndent (const QString &text, const QString &indent,
+                                             QTextStream &stream);
 
     /**
      * Intellegently print out header include/forward decl. for associated classes.
@@ -248,17 +245,17 @@ private:
     /**
      * Raises the case of the first letter in the given string
      */
-    QString capitalizeFirstLetter(QString string);
+    QString capitalizeFirstLetter(const QString &string);
 
     /**
      * Replaces `string' with STRING_TYPENAME.
      */
-    QString fixTypeName(QString string);
+    QString fixTypeName(const QString &string);
 
     /**
      * check that initial values of strings have quotes around them
      */
-    QString fixInitialStringDeclValue(QString value, QString type);
+    QString fixInitialStringDeclValue(const QString &value, const QString &type);
 
     /**
      * Determine what the variable name of this attribute should be.
