@@ -1,6 +1,6 @@
 /***************************************************************************
  *  copyright (C) 2003-2005                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -72,7 +72,7 @@ void IDLWriter::computeAssocTypeAndRole
             // at the "wrong" side.
             // Returning roleName = QString::null tells caller to
             // skip this association at this side.
-            roleName = QString::null;
+            roleName = QString();
             return;
         }
         IAmRoleA = false;
@@ -102,7 +102,7 @@ void IDLWriter::computeAssocTypeAndRole
 
 void IDLWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kdDebug() << "Cannot write class of NULL concept!" << endl;
+        kDebug() << "Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -135,10 +135,10 @@ void IDLWriter::writeClass(UMLClassifier *c) {
     }
 
     // Write includes.
-    UMLClassifierList includes;
+    UMLPackageList includes;
     findObjectsRelated(c, includes);
     if (includes.count()) {
-        for (UMLClassifier *conc = includes.first(); conc; conc = includes.next()) {
+        for (UMLPackage *conc = includes.first(); conc; conc = includes.next()) {
             if (conc->getBaseType() == Uml::ot_Datatype)
                 continue;
             QString incName = findFileName(conc, ".idl");
@@ -189,12 +189,12 @@ void IDLWriter::writeClass(UMLClassifier *c) {
     if (! isOOClass(c)) {
         QString stype = c->getStereotype();
         if (stype == "CORBAConstant") {
-            kdError() << "The stereotype " << stype << " cannot be applied to "
+            kError() << "The stereotype " << stype << " cannot be applied to "
             << c->getName() << ", but only to attributes." << endl;
             return;
         }
         if (!isClass) {
-            kdError() << "The stereotype " << stype
+            kError() << "The stereotype " << stype
             << " cannot be applied to " << c->getName()
             << ", but only to classes." << endl;
             return;
@@ -387,18 +387,20 @@ void IDLWriter::writeClass(UMLClassifier *c) {
 
 
 void IDLWriter::writeOperation(UMLOperation *op, QTextStream &idl, bool is_comment) {
-    UMLAttributeList *atl = op->getParmList();
+    UMLAttributeList atl = op->getParmList();
     QString rettype = op->getTypeName();
 
+    if (rettype.isEmpty())
+        rettype = "void";
     idl << getIndent();
     if (is_comment)
         idl << "// ";
     idl << rettype << " " << cleanName(op->getName()) << " (";
-    if (atl->count()) {
+    if (atl.count()) {
         idl << m_endl;
         m_indentLevel++;
         uint i = 0;
-        for (UMLAttribute *at = atl->first(); at; at = atl->next()) {
+        for (UMLAttribute *at = atl.first(); at; at = atl.next()) {
             idl << getIndent();
             if (is_comment)
                 idl << "// ";
@@ -410,7 +412,7 @@ void IDLWriter::writeOperation(UMLOperation *op, QTextStream &idl, bool is_comme
             else
                 idl << "in ";
             idl << at->getTypeName() << " " << cleanName(at->getName());
-            if (++i < atl->count())
+            if (++i < atl.count())
                 idl << "," << m_endl;
         }
         m_indentLevel--;
