@@ -5,7 +5,7 @@
     source code is not replicated in the XMI file.
                              -------------------
     copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
 ***************************************************************************/
 
 /***************************************************************************
@@ -46,7 +46,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kdDebug()<<"Cannot write class of NULL concept!\n";
+        kDebug()<<"Cannot write class of NULL concept!\n";
         return;
     }
 
@@ -151,9 +151,9 @@ void JavaWriter::writeClass(UMLClassifier *c)
     }
 
     //only import classes in a different package as this class
-    UMLClassifierList imports;
+    UMLPackageList imports;
     findObjectsRelated(c,imports);
-    for (UMLClassifier *con = imports.first(); con; con = imports.next()) {
+    for (UMLPackage *con = imports.first(); con; con = imports.next()) {
         if (con->getBaseType() == Uml::ot_Datatype)
             continue;
         QString pkg = con->getPackage();
@@ -372,7 +372,8 @@ void JavaWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility
 
 }
 
-void JavaWriter::writeComment(QString comment, QString myIndent, QTextStream &java, bool javaDocStyle)
+void JavaWriter::writeComment(const QString &comment, const QString &myIndent,
+                              QTextStream &java, bool javaDocStyle)
 {
     // in the case we have several line comment..
     // NOTE: this part of the method has the problem of adopting UNIX newline,
@@ -640,12 +641,14 @@ void JavaWriter::writeConstructor(UMLClassifier *c, QTextStream &java)
 // IF the type is "string" we need to declare it as
 // the Java Object "String" (there is no string primative in Java).
 // Same thing again for "bool" to "boolean"
-QString JavaWriter::fixTypeName(QString string)
+QString JavaWriter::fixTypeName(const QString& string)
 {
     if (string.isEmpty())
         return "void";
-    string.replace(QRegExp("^string$"),"String");
-    string.replace(QRegExp("^bool$"),"boolean");
+    if (string == "string")
+        return "String";
+    if (string == "bool")
+        return "boolean";
     return string;
 }
 
@@ -720,7 +723,7 @@ void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
 
 void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
     UMLOperation *op;
-    UMLAttributeList *atl;
+    UMLAttributeList atl;
     UMLAttribute *at;
     int i,j;
     QString str;
@@ -738,22 +741,22 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
 
         str = ""; // reset for next method
         str += ((op->getAbstract() || isInterface) ? "abstract ":"");
-        str += scopeToJavaDecl(op->getVisibility()) + " ";
+        str += scopeToJavaDecl(op->getVisibility()) + ' ';
         str += (op->getStatic() ? "static ":"");
-        str += methodReturnType + " " +cleanName(op->getName()) + "( ";
+        str += methodReturnType + ' ' +cleanName(op->getName()) + "( ";
 
         atl = op->getParmList();
-        i= atl->count();
+        i= atl.count();
         j=0;
-        for( at = atl->first(); at ;at = atl->next(),j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             QString typeName = fixTypeName(at->getTypeName());
             QString atName = cleanName(at->getName());
-            str += typeName + " " + atName +
+            str += typeName + ' ' + atName +
                    (!(at->getInitialValue().isEmpty()) ?
                     (QString(" = ")+at->getInitialValue()) :
                     QString(""))
                    + ((j < i-1)?", ":"");
-            returnStr += "@param        "+atName+" "+at->getDoc()+"\n";
+            returnStr += "@param        "+atName+' '+at->getDoc()+"\n";
         }
         str+= " )";
 
