@@ -35,7 +35,7 @@ void JSWriter::writeClass(UMLClassifier *c)
 {
     if(!c)
     {
-        kdDebug()<<"Cannot write class of NULL concept!" << endl;
+        kDebug()<<"Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -75,10 +75,9 @@ void JSWriter::writeClass(UMLClassifier *c)
 
 
     //write includes
-    UMLClassifierList includes;
+    UMLPackageList includes;
     findObjectsRelated(c,includes);
-    UMLClassifier *conc;
-    for(conc = includes.first(); conc ;conc = includes.next())
+    for (UMLPackage *conc = includes.first(); conc; conc = includes.next())
     {
         QString headerName = findFileName(conc, ".js");
         if ( !headerName.isEmpty() )
@@ -199,22 +198,21 @@ void JSWriter::writeClass(UMLClassifier *c)
 void JSWriter::writeOperations(QString classname, UMLOperationList *opList, QTextStream &js)
 {
     UMLOperation *op;
-    UMLAttributeList *atl;
     UMLAttribute *at;
 
     for(op = opList->first(); op; op = opList->next())
     {
-        atl = op -> getParmList();
+        UMLAttributeList atl = op->getParmList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        for(at = atl->first(); at ; at = atl -> next())
+        for (at = atl.first(); at; at = atl.next())
             writeDoc |= !at->getDoc().isEmpty();
 
         if( writeDoc )  //write method documentation
         {
             js << "/**" << m_endl << formatDoc(op->getDoc()," * ");
 
-            for(at = atl->first(); at ; at = atl -> next())  //write parameter documentation
+            for (at = atl.first(); at; at = atl.next())  //write parameter documentation
             {
                 if(forceDoc() || !at->getDoc().isEmpty())
                 {
@@ -227,9 +225,9 @@ void JSWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
 
         js << classname << ".prototype." << cleanName(op->getName()) << " function " << "(";
 
-        int i= atl->count();
+        int i = atl.count();
         int j=0;
-        for (at = atl->first(); at ;at = atl->next(),j++)
+        for (at = atl.first(); at ;at = atl.next(),j++)
         {
             js << cleanName(at->getName())
             << (!(at->getInitialValue().isEmpty()) ? (QString(" = ")+at->getInitialValue()) : QString(""))
