@@ -1,7 +1,7 @@
 /***************************************************************************
     begin                : Wed Jan 22 2003
     copyright            : (C) 2003 by David Hugh-Jones
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
     email                : hughjonesd@yahoo.co.uk
  ***************************************************************************/
 
@@ -42,18 +42,17 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
     return(false);
   }
 
-  UMLClassifierList includes;
+  UMLPackageList includes;
   findObjectsRelated(c,includes);
-  UMLClassifier *conc;
+  UMLPackage *conc;
   QString AV = "@";
   QString SV = "$";
   QString HV = "%";
   for(conc = includes.first(); conc ;conc = includes.next()) {
-    if (   (cleanName(conc->getName()) != AV)
-        && (cleanName(conc->getName()) != SV)
-        && (cleanName(conc->getName()) != HV)){
-      // ***TODO***
-      // Need to remove things like int, string, boolean etc...
+    if (conc->getBaseType() == Uml::ot_Datatype)
+        continue;
+    QString neatName = cleanName(conc->getName());
+    if (neatName != AV && neatName != SV && neatName != HV) {
       QString OtherPkgName =  conc->getPackage(".");
       OtherPkgName.replace(QRegExp("\\."),"::");
       QString OtherName = OtherPkgName + "::" + cleanName(conc->getName());
@@ -64,7 +63,7 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
       if(OtherName != ThisPkgName){
         Ret += "use ";
         Ret += OtherName;
-        Ret += ";";
+        Ret +=  ';';
         Ret += m_endl;
       }
     }
@@ -78,7 +77,7 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
       QString packageName =  obj->getPackage(".");
       packageName.replace(QRegExp("\\."),"::");
 
-      Ret += packageName + "::" + cleanName(obj->getName()) + " ";
+      Ret += packageName + "::" + cleanName(obj->getName()) + ' ';
     }
     Ret += ");" + m_endl;
   }
@@ -89,7 +88,7 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
 void PerlWriter::writeClass(UMLClassifier *c) {
 
   /*  if(!c) {
-      kdDebug()<<"Cannot write class of NULL concept!" << endl;
+      kDebug()<<"Cannot write class of NULL concept!" << endl;
       return;
       }
   */
@@ -130,7 +129,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     while (regEx.search(fragment) > -1) {
       newDir = regEx.cap(1);
       fragment.remove(0, (regEx.pos(2) + 2)); // get round strange minimal matching bug
-      existing->setPath(curDir + "/" + newDir);
+      existing->setPath(curDir + '/' + newDir);
       if (! existing->exists()) {
         existing->setPath(curDir);
         if (! existing->mkdir(newDir)) {
@@ -138,7 +137,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
           return;
         }
       }
-      curDir += "/" + newDir;
+      curDir += '/' + newDir;
     }
     fileName = fragment + ".pm";
   }
@@ -175,7 +174,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     str.replace(QRegExp("%package-name%"),ThisPkgName);
     if(str.find(QRegExp("%PACKAGE-DECLARE%"))){
       str.replace(QRegExp("%PACKAGE-DECLARE%"),
-                  "package " + ThisPkgName + ";"
+                  "package " + ThisPkgName + ';'
                   + m_endl + m_endl
                   + "#UML_MODELER_BEGIN_PERSONAL_VARS_" + classname
                   + m_endl + m_endl
@@ -334,17 +333,16 @@ void PerlWriter::writeOperations(UMLClassifier *c, QTextStream &perl) {
     perl << m_endl << m_endl;
 }
 
-void PerlWriter::writeOperations(QString /* classname */, UMLOperationList &opList, QTextStream &perl) {
+void PerlWriter::writeOperations(const QString &/* classname */, UMLOperationList &opList, QTextStream &perl) {
     UMLOperation *op;
-    UMLAttributeList *atl;
     UMLAttribute *at;
 
     for(op=opList.first(); op ; op=opList.next())
     {
-        atl = op -> getParmList();
+        UMLAttributeList atl = op->getParmList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        for(at = atl->first(); at ; at = atl -> next())
+        for (at = atl.first(); at ; at = atl.next())
             writeDoc |= !at->getDoc().isEmpty();
 
         if( writeDoc )  //write method documentation
@@ -354,7 +352,7 @@ void PerlWriter::writeOperations(QString /* classname */, UMLOperationList &opLi
 
             perl << "   Parameters :" << m_endl ;
           //write parameter documentation
-          for(at = atl->first(); at ; at = atl -> next()) {
+          for (at = atl.first(); at ; at = atl.next()) {
             if(forceDoc() || !at->getDoc().isEmpty()) {
               perl << "      "
                    << cleanName(at->getName()) << " : "
@@ -378,14 +376,14 @@ void PerlWriter::writeOperations(QString /* classname */, UMLOperationList &opLi
 
         bool bStartPrinted = false;
         //write parameters
-        for(at = atl->first(); at ; at = atl -> next()) {
-          if(!bStartPrinted){
-            bStartPrinted = true;
-            perl << "," << m_endl;
+        for (at = atl.first(); at; at = atl.next()) {
+          if (!bStartPrinted) {
+              bStartPrinted = true;
+              perl << "," << m_endl;
           }
           perl << "     $"<< cleanName(at->getName()) << ", # "
                << at->getTypeName() << " : " << at->getDoc() << m_endl;
-        } //  END for(at = atl->first(); at ; at = atl -> next())
+        }
 
         perl << "    ) = @_;" << m_endl;
 
