@@ -2,7 +2,7 @@
     begin               : Thu Oct 17 2002
     copyright           : (C) 2002 by Heiko Nardmann
     email               : h.nardmann@secunet.de
-      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
     php5 version by Thorsten Kunz (tk AT bytecrash DOT net)
  ***************************************************************************/
 
@@ -2996,7 +2996,7 @@ Php5Writer::~Php5Writer() {}
 
 void Php5Writer::writeClass(UMLClassifier *c) {
     if(!c) {
-        kdDebug()<<"Cannot write class of NULL concept!" << endl;
+        kDebug()<<"Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -3031,9 +3031,9 @@ void Php5Writer::writeClass(UMLClassifier *c) {
 
 
     //write includes
-    UMLClassifierList includes;
+    UMLPackageList includes;
     findObjectsRelated(c,includes);
-    UMLClassifier *conc;
+    UMLPackage *conc;
     for(conc = includes.first(); conc ;conc = includes.next()) {
         QString headerName = findFileName(conc, ".php");
         if (!headerName.isEmpty()) {
@@ -3085,7 +3085,7 @@ void Php5Writer::writeClass(UMLClassifier *c) {
             }
         }
     }
-    php<< m_endl << "{" << m_endl;
+    php << m_endl << '{' << m_endl;
 
     //associations
     if( forceSections() || !aggregations.isEmpty()) {
@@ -3096,12 +3096,12 @@ void Php5Writer::writeClass(UMLClassifier *c) {
             //which container to use.
             UMLObject *o = a->getObject(Uml::A);
             if (o == NULL) {
-                kdError() << "aggregation role A object is NULL" << endl;
+                kError() << "aggregation role A object is NULL" << endl;
                 continue;
             }
             QString typeName = cleanName(o->getName());
             if (a->getMulti(Uml::A).isEmpty())  {
-                php << m_indentation << "var $m_" << ";" << m_endl;
+                php << m_indentation << "var $m_" << ';' << m_endl;
             } else {
                 php << m_indentation << "var $m_" << "Vector = array();" << m_endl;
             }
@@ -3114,12 +3114,12 @@ void Php5Writer::writeClass(UMLClassifier *c) {
             // see comment on Aggregation about multiplicity...
             UMLObject *o = a->getObject(Uml::A);
             if (o == NULL) {
-                kdError() << "composition role A object is NULL" << endl;
+                kError() << "composition role A object is NULL" << endl;
                 continue;
             }
             QString typeName = cleanName(o->getName());
             if (a->getMulti(Uml::A).isEmpty())  {
-                php << m_indentation << "var $m_" << ";" << m_endl;
+                php << m_indentation << "var $m_" << ';' << m_endl;
             } else {
                 php << m_indentation << "var $m_" << "Vector = array();" << m_endl;
             }
@@ -3222,16 +3222,15 @@ void Php5Writer::writeOperations(UMLClassifier *c, QTextStream &php) {
 
 }
 
-void Php5Writer::writeOperations(QString /* classname */, UMLOperationList &opList, QTextStream &php, bool isInterface = false, bool generateErrorStub = false) {
-    UMLOperation *op;
-    UMLAttributeList *atl;
-    UMLAttribute *at;
-
-    for(op=opList.first(); op ; op=opList.next()) {
-        atl = op -> getParmList();
+void Php5Writer::writeOperations(const QString &/* classname */, UMLOperationList &opList,
+                                 QTextStream &php, bool isInterface /* = false */,
+                                 bool generateErrorStub /* = false */) {
+    for (UMLOperation *op=opList.first(); op ; op=opList.next()) {
+        UMLAttributeList atl = op->getParmList();
+        UMLAttribute *at;
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        for(at = atl->first(); at ; at = atl -> next())
+        for (at = atl.first(); at; at = atl.next())
             writeDoc |= !at->getDoc().isEmpty();
 
         if( writeDoc )  //write method documentation
@@ -3239,11 +3238,11 @@ void Php5Writer::writeOperations(QString /* classname */, UMLOperationList &opLi
             php <<m_indentation << "/**" << m_endl <<formatDoc(op->getDoc(),m_indentation + " * ");
             php << m_indentation << " *" << m_endl;
 
-            for(at = atl->first(); at ; at = atl -> next())  //write parameter documentation
+            for (at = atl.first(); at; at = atl.next())  //write parameter documentation
             {
                 if(forceDoc() || !at->getDoc().isEmpty()) {
-                    php <<m_indentation << " * @param " + at->getTypeName() + " " + cleanName(at->getName());
-                    php << " " + formatDoc(at->getDoc(),"") << m_endl;
+                    php <<m_indentation << " * @param " + at->getTypeName() + ' ' + cleanName(at->getName());
+                    php << ' ' + formatDoc(at->getDoc(),"") << m_endl;
                 }
             }//end for : write parameter documentation
             php << m_indentation << " * @return " << op->getTypeName() << m_endl;
@@ -3283,9 +3282,9 @@ void Php5Writer::writeOperations(QString /* classname */, UMLOperationList &opLi
         if (op->getStatic()) php << "static ";
         php << "function " << cleanName(op->getName()) << "(";
 
-        int i= atl->count();
+        int i= atl.count();
         int j=0;
-        for( at = atl->first(); at ;at = atl->next(),j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             php << " $" << cleanName(at->getName())
             << (!(at->getInitialValue().isEmpty()) ?
                 (QString(" = ")+at->getInitialValue()) :
@@ -3301,7 +3300,7 @@ void Php5Writer::writeOperations(QString /* classname */, UMLOperationList &opLi
             php << m_endl << m_indentation << "} // end of member function " + cleanName(op->getName()) + m_endl;
         }
         else {
-            php << ";" + m_endl;
+            php << ';' + m_endl;
         }
         php << m_endl;
     }//end for
