@@ -4,7 +4,7 @@
     begin                : Sat Dec 21 2002
     copyright            : Vincent Decorges
     email                : vincent.decorges@eivd.ch
-      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,7 +40,7 @@ PythonWriter::~PythonWriter() {}
 
 void PythonWriter::writeClass(UMLClassifier *c) {
     if(!c) {
-        kdDebug()<<"Cannot write class of NULL concept!" << endl;
+        kDebug()<<"Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -91,7 +91,7 @@ void PythonWriter::writeClass(UMLClassifier *c) {
     str = cleanName(c->getName()); 
     QString pkg = cleanName(c->getPackage());
     if (!pkg.isEmpty())
-        str.prepend(pkg + "."); 
+        str.prepend(pkg + '.'); 
     QStringList includesList  = QStringList(str); //save imported classes 
     int i = superclasses.count(); 
     for (UMLClassifier *classifier = superclasses.first(); 
@@ -99,15 +99,15 @@ void PythonWriter::writeClass(UMLClassifier *c) {
         str = cleanName(classifier->getName()); 
         pkg = cleanName(classifier->getPackage());
         if (!pkg.isEmpty()) 
-            str.prepend(pkg + "."); 
+            str.prepend(pkg + '.'); 
         includesList.append(str); 
         h << "from " + str + " import *" << m_endl; 
     } 
  
     //write includes and take namespaces into account
-    UMLClassifierList includes;
+    UMLPackageList includes;
     findObjectsRelated(c,includes);
-    UMLClassifier* conc;
+    UMLPackage* conc;
     for(conc = includes.first(); conc ;conc = includes.next()) {
         QString headerName = findFileName(conc, ".py");
         if ( !headerName.isEmpty() ) {
@@ -205,10 +205,9 @@ void PythonWriter::writeOperations(UMLClassifier *c,QTextStream &h) {
 
 }
 
-void PythonWriter::writeOperations(QString /*classname*/, UMLOperationList &opList,
+void PythonWriter::writeOperations(const QString& /*classname*/, UMLOperationList &opList,
                                    QTextStream &h, Access access) {
     UMLOperation *op;
-    UMLAttributeList *atl;
     UMLAttribute *at;
 
     QString sAccess;
@@ -228,16 +227,16 @@ void PythonWriter::writeOperations(QString /*classname*/, UMLOperationList &opLi
 
 
     for(op=opList.first(); op ; op=opList.next()) {
-        atl = op -> getParmList();
+        UMLAttributeList atl = op->getParmList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        for(at = atl->first(); at ; at = atl -> next())
+        for (at = atl.first(); at; at = atl.next())
             writeDoc |= !at->getDoc().isEmpty();
 
         h<< m_indentation << "def "<< sAccess + cleanName(op->getName()) << "(self";
 
         int j=0;
-        for( at = atl->first(); at ;at = atl->next(),j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             h << ", " << cleanName(at->getName())
             << (!(at->getInitialValue().isEmpty()) ?
                 (QString(" = ")+at->getInitialValue()) :
@@ -251,7 +250,7 @@ void PythonWriter::writeOperations(QString /*classname*/, UMLOperationList &opLi
             h<<m_indentation<<m_indentation<<"\"\"\""<<m_endl;
             h<<m_indentation<<m_indentation<<op->getDoc()<<m_endl<<m_endl;
 
-            for(at = atl->first(); at ; at = atl -> next())  //write parameter documentation
+            for (at = atl.first(); at; at = atl.next())  //write parameter documentation
             {
                 if(forceDoc() || !at->getDoc().isEmpty()) {
                     h<<m_indentation<<m_indentation<<"@param "<<at->getTypeName()<<
