@@ -13,8 +13,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   copyright (C) 2006-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 /**
@@ -33,7 +33,7 @@
 #include "rubyclassdeclarationblock.h"
 #include "rubycodeclassfielddeclarationblock.h"
 #include "rubycodeoperation.h"
-#include "../datatype.h"
+#include "../classifier.h"
 #include "../uml.h"
 
 // Constructors/Destructors
@@ -199,7 +199,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                     block->loadFromXMI(element);
                     if(!addTextBlock(block))
                     {
-                        kdError()<<"loadFromXMI : unable to add codeComment to :"<<this<<endl;
+                        kError()<<"loadFromXMI : unable to add codeComment to :"<<this<<endl;
                         block->deleteLater();
                     } else
                         loadCheckForChildrenOK= true;
@@ -212,7 +212,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                         TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                         if(!tb || !addTextBlock(tb))
                         {
-                            kdError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this<<endl;
+                            kError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this<<endl;
                             // DON'T delete
                         } else
                             loadCheckForChildrenOK= true;
@@ -223,7 +223,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                             block->loadFromXMI(element);
                             if(!addTextBlock(block))
                             {
-                                kdError()<<"loadFromXMI : unable to add codeBlock to :"<<this<<endl;
+                                kError()<<"loadFromXMI : unable to add codeBlock to :"<<this<<endl;
                                 block->deleteLater();
                             } else
                                 loadCheckForChildrenOK= true;
@@ -233,7 +233,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                                 block->loadFromXMI(element);
                                 if(!addTextBlock(block))
                                 {
-                                    kdError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this<<endl;
+                                    kError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this<<endl;
                                     block->deleteLater();
                                 } else
                                     loadCheckForChildrenOK= true;
@@ -246,7 +246,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                                         block->loadFromXMI(element);
                                         if(!addTextBlock(block))
                                         {
-                                            kdError()<<"Unable to add hierarchicalcodeBlock to:"<<this<<endl;
+                                            kError()<<"Unable to add hierarchicalcodeBlock to:"<<this<<endl;
                                             block->deleteLater();
                                         } else
                                             loadCheckForChildrenOK= true;
@@ -263,11 +263,11 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                                                     loadCheckForChildrenOK= true;
                                                 else
                                                 {
-                                                    kdError()<<"Unable to add codeoperation to:"<<this<<endl;
+                                                    kError()<<"Unable to add codeoperation to:"<<this<<endl;
                                                     block->deleteLater();
                                                 }
                                             } else
-                                                kdError()<<"Unable to find operation create codeoperation for:"<<this<<endl;
+                                                kError()<<"Unable to find operation create codeoperation for:"<<this<<endl;
                                         } else
                                             if( name == "rubyclassdeclarationblock" )
                                             {
@@ -275,7 +275,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                                                 block->loadFromXMI(element);
                                                 if(!addTextBlock(block))
                                                 {
-                                                    kdError()<<"Unable to add ruby code declaration block to:"<<this<<endl;
+                                                    kError()<<"Unable to add ruby code declaration block to:"<<this<<endl;
                                                     // DON'T delete.
                                                     // block->deleteLater();
                                                 } else
@@ -284,7 +284,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
                 // This last item is only needed for extreme debugging conditions
                 // (E.g. making new codeclassdocument loader)
                 // else
-                //        kdDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning"<<endl;
+                //        kDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning"<<endl;
 
                 node = element.nextSibling();
                 element = node.toElement();
@@ -301,13 +301,13 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & roo
         CodeDocument * test = dynamic_cast<CodeDocument*>(this);
         if(test)
         {
-            kdWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this<<endl;
+            kWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this<<endl;
         } else {
             HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(this);
             if(hb)
-                kdWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this<<endl;
+                kWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this<<endl;
             else
-                kdDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this<<endl;
+                kDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this<<endl;
         }
     }
 
