@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2006                                                    *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include <kdebug.h>
@@ -82,7 +82,7 @@ QString RubyCodeClassField::getInitialValue() {
         if (at) {
             return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
         } else {
-            kdError() << "RubyodeClassField::getInitialValue: parent object is not a UMLAttribute"
+            kError() << "RubyodeClassField::getInitialValue: parent object is not a UMLAttribute"
             << endl;
             return "";
         }
