@@ -87,10 +87,10 @@ void RubyCodeOperation::updateMethodDeclaration()
     QStringList commentedParams;
 
     // assemble parameters
-    UMLAttributeList * list = getParentOperation()->getParmList();
-    int nrofParam = list->count();
+    UMLAttributeList list = getParentOperation()->getParmList();
+    int nrofParam = list.count();
     int paramNum = 0;
-    for(UMLAttribute* parm = list->first(); parm; parm=list->next())
+    for(UMLAttribute* parm = list.first(); parm; parm = list.next())
     {
         QString paramName = RubyCodeGenerator::cppToRubyName(parm->getName());
         paramStr += paramName;
@@ -107,9 +107,9 @@ void RubyCodeOperation::updateMethodDeclaration()
     if (isInterface) {
         // Assume 'isInterface' means a module in Ruby, so
         // generate module methods
-        startText = "def "+ RubyClassName + "." + methodName + "(" + paramStr +")";
+        startText = "def "+ RubyClassName + '.' + methodName + '(' + paramStr +')';
     } else {
-        startText = "def "+ methodName + "(" + paramStr +")";
+        startText = "def "+ methodName + '(' + paramStr +')';
     }
 
     startText += "";
@@ -123,15 +123,15 @@ void RubyCodeOperation::updateMethodDeclaration()
 
     if (comment.isEmpty()) {
         if (getContentType() == CodeBlock::AutoGenerated) {
-            UMLAttributeList* parameters = o->getParmList();
-            for(UMLAttributeListIt iterator(*parameters); iterator.current(); ++iterator) {
+            UMLAttributeList parameters = o->getParmList();
+            for(UMLAttributeListIt iterator(parameters); iterator.current(); ++iterator) {
                 comment += endLine + "* _" + iterator.current()->getName() + "_ ";
-                comment += (" " + iterator.current()->getDoc().replace( QRegExp("[\\n\\r]+[\\t ]*"),
+                comment += (' ' + iterator.current()->getDoc().replace( QRegExp("[\\n\\r]+[\\t ]*"),
                                                                         endLine + "  " ) );
             }
             // add a returns statement too
             if(!returnType.isEmpty() && !QRegExp("^void\\s*$").exactMatch(returnType))
-                comment += endLine + "* _returns_ " + returnType + " ";
+                comment += endLine + "* _returns_ " + returnType + ' ';
             getComment()->setText(comment);
         }
     } else {
@@ -144,23 +144,23 @@ void RubyCodeOperation::updateMethodDeclaration()
         int pos = re_params.search(comment);
         while (pos != -1) {
             comment.replace( re_params.cap(0), 
-                            QString("@param _") + re_params.cap(1).lower() + re_params.cap(2) + "_" );
+                            QString("@param _") + re_params.cap(1).lower() + re_params.cap(2) + '_' );
             commentedParams.append(re_params.cap(1).lower() + re_params.cap(2));
     
             pos += re_params.matchedLength() + 3;
             pos = re_params.search(comment, pos);
         }
     
-        UMLAttributeList* parameters = o->getParmList();
-        for (UMLAttributeListIt iterator(*parameters); iterator.current(); ++iterator) {
+        UMLAttributeList parameters = o->getParmList();
+        for (UMLAttributeListIt iterator(parameters); iterator.current(); ++iterator) {
             // Only write an individual @param entry if one hasn't been found already
             // in the main doc comment
             if (commentedParams.contains(RubyCodeGenerator::cppToRubyName(iterator.current()->getName())) == 0) {
-                comment += (endLine + "@param _" + RubyCodeGenerator::cppToRubyName(iterator.current()->getName()) + "_");
+                comment += (endLine + "@param _" + RubyCodeGenerator::cppToRubyName(iterator.current()->getName()) + '_');
                 if (iterator.current()->getDoc().isEmpty()) {
-                    comment += (" " + RubyCodeGenerator::cppToRubyType(iterator.current()->getTypeName()));
+                    comment += (' ' + RubyCodeGenerator::cppToRubyType(iterator.current()->getTypeName()));
                 } else {
-                    comment += (" " + iterator.current()->getDoc().replace(QRegExp("[\\n\\r]+[\\t ]*"), endLine + "  "));
+                    comment += (' ' + iterator.current()->getDoc().replace(QRegExp("[\\n\\r]+[\\t ]*"), endLine + "  "));
                 }
             }
         }
@@ -173,7 +173,7 @@ void RubyCodeOperation::updateMethodDeclaration()
         // must be indented correctly. If they aren't a list
         // item starting with '*', then indent the text with
         // two spaces, '  ', to line up with the list item.
-        pos = comment.find(endLine + "*");
+        pos = comment.find(endLine + '*');
         if (pos != -1) {
             pos += endLine.length() + 1;
             pos = comment.find(endLine, pos);
