@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2005                                                     *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2005-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -21,10 +21,12 @@
 #include "../uml.h"
 #include "../umldoc.h"
 #include "../package.h"
+#include "../folder.h"
 #include "../classifier.h"
 #include "../enum.h"
 #include "../operation.h"
 #include "../attribute.h"
+#include "../association.h"
 
 AdaImport::AdaImport() : NativeImportBase("--") {
    initVars();
@@ -35,28 +37,80 @@ AdaImport::~AdaImport() {
 
 void AdaImport::initVars() {
     m_inGenericFormalPart = false;
+    m_classesDefinedInThisScope.clear();
+    m_renaming.clear();
 }
 
-void AdaImport::fillSource(QString word) {
+/// Split the line so that a string is returned as a single element of the list,
+/// when not in a string then split at white space.
+QStringList AdaImport::split(const QString& lin) {
+    QStringList list;
+    QString listElement;
+    bool inString = false;
+    bool seenSpace = false;
+    QString line = lin.stripWhiteSpace();
+    uint len = line.length();
+    for (uint i = 0; i < len; i++) {
+        const QChar& c = line[i];
+        if (inString) {
+            listElement += c;
+            if (c == '"') {
+                if (i < len - 1 && line[i + 1] == '"') {
+                    i++;     // escaped quotation mark
+                    continue;
+                }
+                list.append(listElement);
+                listElement = QString();
+                inString = false;
+            }
+        } else if (c == '"') {
+            inString = true;
+            if (!listElement.isEmpty())
+                list.append(listElement);
+            listElement = QString(c);
+            seenSpace = false;
+        } else if (c == '\'') {
+            if (i < len - 2 && line[i + 2] == '\'') {
+                // character constant
+                if (!listElement.isEmpty())
+                    list.append(listElement);
+                listElement = line.mid(i, 3);
+                i += 2;
+                list.append(listElement);
+                listElement = QString();
+                continue;
+            }
+            listElement += c;
+            seenSpace = false;
+        } else if (c.isSpace()) {
+            if (seenSpace)
+                continue;
+            seenSpace = true;
+            if (!listElement.isEmpty()) {
+                list.append(listElement);
+                listElement = QString();
+            }
+        } else {
+            listElement += c;
+            seenSpace = false;
+        }
+    }
+    if (!listElement.isEmpty())
+        list.append(listElement);
+    return list;
+}
+
+void AdaImport::fillSource(const QString& word) {
     QString lexeme;
     const uint len = word.length();
-    bool inString = false;
     for (uint i = 0; i < len; i++) {
         QChar c = word[i];
-        if (c == '"') {
-            lexeme += c;
-            if (inString) {
-                m_source.append(lexeme);
-                lexeme = QString::null;
-            }
-            inString = !inString;
-        } else if (inString ||
-                   c.isLetterOrNumber() || c == '_' || c == '.' || c == '#') {
+        if (c.isLetterOrNumber() || c == '_' || c == '.' || c == '#') {
             lexeme += c;
         } else {
             if (!lexeme.isEmpty()) {
                 m_source.append(lexeme);
-                lexeme = QString::null;
+                lexeme = QString();
             }
             if (c == ':' && word[i + 1] == '=') {
                 m_source.append(":=");
@@ -70,10 +124,52 @@ void AdaImport::fillSource(QString word) {
         m_source.append(lexeme);
 }
 
+QString AdaImport::expand(const QString& name) {
+    QRegExp pfxRegExp("^(\\w+)\\.");
+    pfxRegExp.setCaseSensitive(false);
+    int pos = pfxRegExp.search(name);
+    if (pos == -1)
+        return name;
+    QString result = name;
+    QString pfx = pfxRegExp.cap(1);
+    if (m_renaming.contains(pfx)) {
+        result.remove(pfxRegExp);
+        result.prepend(m_renaming[pfx] + '.');
+    }
+    return result;
+}
+
+void AdaImport::parseStems(const QStringList& stems) {
+    if (stems.isEmpty())
+        return;
+    QString base = stems.first();
+    uint i = 0;
+    while (1) {
+        QString filename = base + ".ads";
+        if (! m_parsedFiles.contains(filename)) {
+            // Save current m_source and m_srcIndex.
+            QStringList source(m_source);
+            uint srcIndex = m_srcIndex;
+            m_source.clear();
+            parseFile(filename);
+            // Restore m_source and m_srcIndex.
+            m_source = source;
+            m_srcIndex = srcIndex;
+            // Also reset m_currentAccess.
+            // CHECK: need to reset more stuff?
+            m_currentAccess = Uml::Visibility::Public;
+        }
+        if (++i >= stems.count())
+            break;
+        base += '-' + stems[i];
+    }
+}
+
 bool AdaImport::parseStmt() {
     const uint srcLength = m_source.count();
     const QString& keyword = m_source[m_srcIndex];
-    //kdDebug() << '"' << keyword << '"' << endl;
+    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    //kDebug() << '"' << keyword << '"' << endl;
     if (keyword == "with") {
         if (m_inGenericFormalPart) {
             // mapping of generic formal subprograms or packages is not yet implemented
@@ -90,28 +186,7 @@ bool AdaImport::parseStmt() {
                     break;
                 continue;
             }
-            QString base = prefix;
-            uint i = 0;
-            while (1) {
-                if (! m_parsedFiles.contains(base)) {
-                    m_parsedFiles.append(base);
-                    QString filename = base + ".ads";
-                    // Save current m_source and m_srcIndex.
-                    QStringList source(m_source);
-                    uint srcIndex = m_srcIndex;
-                    m_source.clear();
-                    parseFile(filename);
-                    // Restore m_source and m_srcIndex.
-                    m_source = source;
-                    m_srcIndex = srcIndex;
-                    // Also reset m_currentAccess.
-                    // CHECK: need to reset more stuff?
-                    m_currentAccess = Uml::Visibility::Public;
-                }
-                if (++i >= components.count())
-                    break;
-                base += '-' + components[i];
-            }
+            parseStems(components);
             if (advance() != ",")
                 break;
         }
@@ -123,39 +198,89 @@ bool AdaImport::parseStmt() {
     }
     if (keyword == "package") {
         const QString& name = advance();
-        UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Package,
-                        name, m_scope[m_scopeIndex], m_comment);
+        QStringList parentPkgs = QStringList::split(".", name.lower());
+        parentPkgs.pop_back();  // exclude the current package
+        parseStems(parentPkgs);
+        UMLObject *ns = NULL;
         if (advance() == "is") {
+            ns = Import_Utils::createUMLObject(Uml::ot_Package, name,
+                                               m_scope[m_scopeIndex], m_comment);
             if (m_source[m_srcIndex + 1] == "new") {
-                // generic package instantiation: TBD
+                m_srcIndex++;
+                QString pkgName = advance();
+                UMLObject *gp = Import_Utils::createUMLObject(Uml::ot_Package, pkgName,
+                                                              m_scope[m_scopeIndex]);
+                gp->setStereotype("generic");
+                // Add binding from instantiator to instantiatee
+                UMLAssociation *assoc = new UMLAssociation(Uml::at_Dependency, ns, gp);
+                assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
+                assoc->setStereotype("bind");
+                // Work around missing display of stereotype in AssociationWidget:
+                assoc->setName(assoc->getStereotype(true));
+                umldoc->addAssociation(assoc);
                 skipStmt();
             } else {
                 m_scope[++m_scopeIndex] = static_cast<UMLPackage*>(ns);
             }
-        } else if (m_source[m_srcIndex] != "renames") {
-            kdError() << "AdaImport::parseFile: unexpected: " << m_source[m_srcIndex] << endl;
+        } else if (m_source[m_srcIndex] == "renames") {
+            m_renaming[name] = advance();
+        } else {
+            kError() << "AdaImport::parseStmt: unexpected: " << m_source[m_srcIndex] << endl;
             skipStmt("is");
         }
         if (m_inGenericFormalPart) {
-            // handling of generic formal parameters: TBD
+            ns->setStereotype("generic");
             m_inGenericFormalPart = false;
         }
         return true;
     }
+    if (m_inGenericFormalPart)
+        return false;  // skip generic formal parameter (not yet implemented)
+    if (keyword == "subtype") {
+        QString name = advance();
+        advance();  // "is"
+        QString base = expand(advance());
+        base.remove("Standard.", false);
+        UMLObject *type = umldoc->findUMLObject(base, Uml::ot_UMLObject, m_scope[m_scopeIndex]);
+        if (type == NULL) {
+            type = Import_Utils::createUMLObject(Uml::ot_Datatype, base, m_scope[m_scopeIndex]);
+        }
+        UMLObject *subtype = Import_Utils::createUMLObject(type->getBaseType(), name,
+                                                           m_scope[m_scopeIndex], m_comment);
+        UMLAssociation *assoc = new UMLAssociation(Uml::at_Dependency, subtype, type);
+        assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
+        assoc->setStereotype("subtype");
+        // Work around missing display of stereotype in AssociationWidget:
+        assoc->setName(assoc->getStereotype(true));
+        umldoc->addAssociation(assoc);
+        skipStmt();
+        return true;
+    }
     if (keyword == "type") {
-        const QString& name = advance();
+        QString name = advance();
         if (advance() == "(") {
-            kdDebug() << "AdaImport::parseFile(" << name << "): "
+            kDebug() << "AdaImport::parseStmt(" << name << "): "
                 << "discriminant handling is not yet implemented" << endl;
-            skipStmt(")");
+            // @todo Find out how to map discriminated record to UML.
+            //       For now, we just create a pro forma empty record.
+            Import_Utils::createUMLObject(Uml::ot_Class, name, m_scope[m_scopeIndex],
+                                          m_comment, "record");
+            skipStmt("end");
+            if (m_source[++m_srcIndex] == "case")
+                m_srcIndex += 2;  // skip "case" ";"
+            // we are now positioned on "end"
+            m_srcIndex += 2;      // skip "end" "record"
+            // we are now positioned on ";"
+            return true;
         }
         if (m_source[m_srcIndex] == ";") {
             // forward declaration
-            // To Be Done
+            Import_Utils::createUMLObject(Uml::ot_Class, name, m_scope[m_scopeIndex],
+                                          m_comment);
             return true;
         }
         if (m_source[m_srcIndex] != "is") {
-            kdError() << "AdaImport::parseFile: expecting \"is\"" << endl;
+            kError() << "AdaImport::parseStmt: expecting \"is\"" << endl;
             return false;
         }
         if (advance() == "(") {
@@ -177,45 +302,47 @@ bool AdaImport::parseStmt() {
             m_srcIndex++;
         }
         if (m_source[m_srcIndex] == "tagged") {
-            UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Class,
-                            name, m_scope[m_scopeIndex], m_comment);
-            ns->setAbstract(m_isAbstract);
-            m_isAbstract = false;
-            m_comment = QString::null;
-            m_srcIndex++;
             isTaggedType = true;
+            m_srcIndex++;
         }
         if (m_source[m_srcIndex] == "limited") {
             m_srcIndex++;  // we can't (yet?) represent that
         }
         if (m_source[m_srcIndex] == "private" ||
+            m_source[m_srcIndex] == "record" ||
             (m_source[m_srcIndex] == "null" &&
              m_source[m_srcIndex+1] == "record")) {
-            skipStmt();
-            return true;
-        }
-        if (m_source[m_srcIndex] == "record") {
-            // If it's a tagged record then the class was already created
-            // above (see processing for "tagged".) Doesn't matter;
-            // in that case Import_Utils::createUMLObject() just returns
-            // the existing class instead of creating a new one.
             UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Class,
                             name, m_scope[m_scopeIndex], m_comment);
-            if (! isTaggedType)
+            ns->setAbstract(m_isAbstract);
+            m_isAbstract = false;
+            if (isTaggedType) {
+                if (! m_classesDefinedInThisScope.contains(ns))
+                    m_classesDefinedInThisScope.append(ns);
+            } else {
                 ns->setStereotype("record");
-            m_klass = static_cast<UMLClassifier*>(ns);
+            }
+            if (m_source[m_srcIndex] == "record")
+                m_klass = static_cast<UMLClassifier*>(ns);
+            else
+                skipStmt();
             return true;
         }
         if (m_source[m_srcIndex] == "new") {
-            QString base = advance();
-            UMLClassifier *parent = NULL;
-            if (advance() == "with") {
-                UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Class,
-                                base, NULL);
-                parent = static_cast<UMLClassifier*>(ns);
-                ns = Import_Utils::createUMLObject(Uml::ot_Class, name,
-                                       m_scope[m_scopeIndex], m_comment);
-                m_comment = QString::null;
+            QString base = expand(advance());
+            const bool isExtension = (advance() == "with");
+            Uml::Object_Type t;
+            if (isExtension || m_isAbstract) {
+                t = Uml::ot_Class;
+            } else {
+                base.remove("Standard.", false);
+                UMLObject *known = umldoc->findUMLObject(base, Uml::ot_UMLObject, m_scope[m_scopeIndex]);
+                t = (known ? known->getBaseType() : Uml::ot_Datatype);
+            }
+            UMLObject *ns = Import_Utils::createUMLObject(t, base, NULL);
+            UMLClassifier *parent = static_cast<UMLClassifier*>(ns);
+            ns = Import_Utils::createUMLObject(t, name, m_scope[m_scopeIndex], m_comment);
+            if (isExtension) {
                 QString nextLexeme = advance();
                 if (nextLexeme == "null" || nextLexeme == "record") {
                     UMLClassifier *klass = static_cast<UMLClassifier*>(ns);
@@ -223,10 +350,11 @@ bool AdaImport::parseStmt() {
                     if (nextLexeme == "record") {
                         // Set the m_klass for attributes.
                         m_klass = klass;
-                        return true;
                     }
                 }
             }
+            skipStmt();
+            return true;
         }
         // Datatypes: TO BE DONE
         return false;
@@ -238,21 +366,21 @@ bool AdaImport::parseStmt() {
     if (keyword == "end") {
         if (m_klass) {
             if (advance() != "record") {
-                kdError() << "end: expecting \"record\" at "
+                kError() << "end: expecting \"record\" at "
                           << m_source[m_srcIndex] << endl;
             }
             m_klass = NULL;
         } else if (m_scopeIndex) {
             if (advance() != ";") {
-                const QString& scopeName = m_scope[m_scopeIndex]->getName();
-                if (scopeName != m_source[m_srcIndex])
-                    kdError() << "end: expecting " << scopeName << ", found "
+                QString scopeName = m_scope[m_scopeIndex]->getFullyQualifiedName();
+                if (scopeName.lower() != m_source[m_srcIndex].lower())
+                    kError() << "end: expecting " << scopeName << ", found "
                               << m_source[m_srcIndex] << endl;
             }
             m_scopeIndex--;
             m_currentAccess = Uml::Visibility::Public;   // @todo make a stack for this
         } else {
-            kdError() << "importAda: too many \"end\"" << endl;
+            kError() << "importAda: too many \"end\"" << endl;
         }
         skipStmt();
         return true;
@@ -265,7 +393,7 @@ bool AdaImport::parseStmt() {
             // subprograms.
             // In order to map those, we would need to create a UML
             // class with stereotype <<utility>> for the Ada package.
-            kdDebug() << "ignoring parameterless " << keyword << " " << name << endl;
+            kDebug() << "ignoring parameterless " << keyword << " " << name << endl;
             skipStmt();
             return true;
         }
@@ -277,13 +405,13 @@ bool AdaImport::parseStmt() {
             uint parNameCount = 0;
             do {
                 if (parNameCount >= MAX_PARNAMES) {
-                    kdError() << "MAX_PARNAMES is exceeded at " << name << endl;
+                    kError() << "MAX_PARNAMES is exceeded at " << name << endl;
                     break;
                 }
                 parName[parNameCount++] = advance();
             } while (advance() == ",");
             if (m_source[m_srcIndex] != ":") {
-                kdError() << "importAda: expecting ':'" << endl;
+                kError() << "importAda: expecting ':'" << endl;
                 skipStmt();
                 break;
             }
@@ -309,26 +437,15 @@ bool AdaImport::parseStmt() {
             } else {
                 typeName = direction;  // In Ada, the default direction is "in"
             }
+            typeName.remove("Standard.", false);
+            typeName = expand(typeName);
             if (op == NULL) {
                 // In Ada, the first parameter indicates the class.
-                UMLDoc *umldoc = UMLApp::app()->getDocument();
-                UMLObject *type = umldoc->findUMLObject(typeName, Uml::ot_Class, m_scope[m_scopeIndex]);
-                if (type == NULL) {
-                    kdError() << "importAda: cannot find UML object for " << typeName << endl;
-                    skipStmt();
-                    break;
-                    /*** better:
-                    if (advance() == ";") {
-                        m_srcIndex++;
-                        continue;
-                    } else {
-                        break;
-                    }
-                     ****/
-                }
+                UMLObject *type = Import_Utils::createUMLObject(Uml::ot_Class, typeName, m_scope[m_scopeIndex]);
                 Uml::Object_Type t = type->getBaseType();
-                if (t != Uml::ot_Interface &&
-                    (t != Uml::ot_Class || type->getStereotype() == "record")) {
+                if ((t != Uml::ot_Interface &&
+                     (t != Uml::ot_Class || type->getStereotype() == "record")) ||
+                    !m_classesDefinedInThisScope.contains(type)) {
                     // Not an instance bound method - we cannot represent it.
                     skipStmt(")");
                     break;
@@ -352,11 +469,12 @@ bool AdaImport::parseStmt() {
         if (keyword == "function") {
             if (advance() != "return") {
                 if (klass)
-                    kdError() << "importAda: expecting \"return\" at function "
+                    kError() << "importAda: expecting \"return\" at function "
                         << name << endl;
                 return false;
             }
-            returnType = advance();
+            returnType = expand(advance());
+            returnType.remove("Standard.", false);
         }
         bool isAbstract = false;
         if (advance() == "is" && advance() == "abstract")
@@ -364,9 +482,6 @@ bool AdaImport::parseStmt() {
         if (klass != NULL && op != NULL)
             Import_Utils::insertMethod(klass, op, m_currentAccess, returnType,
                                        false, isAbstract, false, false, m_comment);
-        return true;
-    }
-    if (keyword == "subtype") {    // FIXMEnow: potentially important but not yet implemented
         skipStmt();
         return true;
     }
@@ -399,7 +514,7 @@ bool AdaImport::parseStmt() {
             if (advance() == "record")
                 skipStmt("end");
         } else {
-            kdError() << "importAda: expecting \"use\" at rep spec of "
+            kError() << "importAda: expecting \"use\" at rep spec of "
                       << typeName << endl;
         }
         skipStmt();
@@ -412,18 +527,18 @@ bool AdaImport::parseStmt() {
     }
     const QString& name = keyword;
     if (advance() != ":") {
-        kdError() << "adaImport: expecting \":\" at " << name << " "
+        kError() << "adaImport: expecting \":\" at " << name << " "
                   << m_source[m_srcIndex] << endl;
         skipStmt();
         return true;
     }
-    QString typeName = advance();
+    QString typeName = expand(advance());
     QString initialValue;
     if (advance() == ":=") {
         initialValue = advance();
         QString token;
         while ((token = advance()) != ";") {
-            initialValue.append(" " + token);
+            initialValue.append(' ' + token);
         }
     }
     UMLObject *o = Import_Utils::insertAttribute(m_klass, m_currentAccess, name,
