@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2005-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2005-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -27,7 +27,6 @@
 #include "../package.h"
 #include "../folder.h"
 #include "../enum.h"
-#include "../datatype.h"
 #include "../classifier.h"
 #include "../operation.h"
 #include "../attribute.h"
@@ -115,14 +114,15 @@ UMLObject* findUMLObject(QString name,
  */
 
 UMLObject *createUMLObject(Uml::Object_Type type,
-                                        QString name,
-                                        UMLPackage *parentPkg,
-                                        QString comment,
-                                        QString stereotype) {
+                           const QString& inName,
+                           UMLPackage *parentPkg,
+                           const QString& comment,
+                           const QString& stereotype) {
+    QString name = inName;
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
     if (parentPkg == NULL) {
-        // kdDebug() << "Import_Utils::createUMLObject(" << name
+        // kDebug() << "Import_Utils::createUMLObject(" << name
         //     << "): parentPkg is NULL, assuming Logical View" << endl;
         parentPkg = logicalView;
     }
@@ -153,6 +153,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             if (components.count() > 1) {
                 typeName = components.back();
                 components.pop_back();
+                Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
                 while ( components.count() ) {
                     QString scopeName = components.front();
                     components.pop_front();
@@ -162,12 +163,14 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                         continue;
                     }
                     int wantNamespace = KMessageBox::Yes;
-                    /* We know std and Qt are namespaces */
-                    if (scopeName != "std" && scopeName != "Qt") {
-                        wantNamespace = KMessageBox::questionYesNo(NULL,
+                    if (pl == Uml::pl_Cpp) {
+                        /* We know std and Qt are namespaces */
+                        if (scopeName != "std" && scopeName != "Qt") {
+                            wantNamespace = KMessageBox::questionYesNo(NULL,
                                         i18n("Is the scope %1 a namespace or a class?").arg(scopeName),
                                         i18n("C++ Import Requests Your Help"),
                                         i18n("Namespace"), i18n("Class"));
+                        }
                     }
                     Uml::Object_Type ot = (wantNamespace == KMessageBox::Yes ? Uml::ot_Package : Uml::ot_Class);
                     o = Object_Factory::createUMLObject(ot, scopeName, parentPkg);
@@ -182,8 +185,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             Uml::Object_Type t = type;
             if (type == Uml::ot_UMLObject || isAdorned)
                 t = Uml::ot_Class;
-            origType = Object_Factory::createUMLObject(t, typeName, parentPkg);
+            origType = Object_Factory::createUMLObject(t, typeName, parentPkg, false);
             bNewUMLObjectWasCreated = true;
+            bPutAtGlobalScope = false;
         }
         if (isConst || isAdorned) {
             // Create the full given type (including adornments.)
@@ -192,12 +196,12 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             o = Object_Factory::createUMLObject(Uml::ot_Datatype, name,
                                                 umldoc->getDatatypeFolder(),
                                                 false); //solicitNewName
-            UMLDatatype *dt = static_cast<UMLDatatype*>(o);
+            UMLClassifier *dt = static_cast<UMLClassifier*>(o);
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(origType);
             if (c)
                 dt->setOriginType(c);
             else
-                kdError() << "createUMLObject(" << name << "): "
+                kError() << "createUMLObject(" << name << "): "
                 << "origType " << typeName << " is not a UMLClassifier"
                 << endl;
             if (isRef || isPointer)
@@ -205,7 +209,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             /*
             if (isPointer) {
                 UMLObject *pointerDecl = Object_Factory::createUMLObject(Uml::ot_Datatype, type);
-                UMLDatatype *dt = static_cast<UMLDatatype*>(pointerDecl);
+                UMLClassifier *dt = static_cast<UMLClassifier*>(pointerDecl);
                 dt->setOriginType(classifier);
                 dt->setIsReference();
                 classifier = dt;
@@ -214,8 +218,11 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             o = origType;
         }
     } else if (parentPkg && !bPutAtGlobalScope) {
-        if (o->getUMLPackage())
-            o->getUMLPackage()->removeObject(o);
+        UMLPackage *existingPkg = o->getUMLPackage();
+        if (existingPkg == umldoc->getDatatypeFolder())
+            return o;
+        if (existingPkg)
+            existingPkg->removeObject(o);
         o->setUMLPackage(parentPkg);
         parentPkg->addObject(o);
     }
@@ -235,17 +242,20 @@ UMLOperation* makeOperation(UMLClassifier *parent, const QString &name) {
     return op;
 }
 
-UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope, QString name,
-                                        UMLClassifier *attrType, QString comment /* ="" */,
-                                        bool isStatic /* =false */) {
+UMLObject* insertAttribute(UMLClassifier *owner,
+                           Uml::Visibility scope,
+                           const QString& name,
+                           UMLClassifier *attrType,
+                           const QString& comment /* ="" */,
+                           bool isStatic /* =false */) {
     Uml::Object_Type ot = owner->getBaseType();
     Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
     if (! (ot == Uml::ot_Class || ot == Uml::ot_Interface && pl == Uml::pl_Java)) {
-        kdDebug() << "insertAttribute: Don't know what to do with "
+        kDebug() << "insertAttribute: Don't know what to do with "
         << owner->getName() << " (object type " << ot << ")" << endl;
         return NULL;
     }
-    UMLObject *o = owner->findChildObject(name);
+    UMLObject *o = owner->findChildObject(name, Uml::ot_Attribute);
     if (o) {
         return o;
     }
@@ -262,9 +272,11 @@ UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope, QString
     return attr;
 }
 
-UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope, QString name,
-                                        QString type, QString comment /* ="" */,
-                                        bool isStatic /* =false */) {
+UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope,
+                           const QString& name,
+                           const QString& type,
+                           const QString& comment /* ="" */,
+                           bool isStatic /* =false */) {
     UMLObject *attrType = owner->findTemplate(type);
     if (attrType == NULL) {
         bPutAtGlobalScope = true;
@@ -277,10 +289,10 @@ UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope, QString
 }
 
 void insertMethod(UMLClassifier *klass, UMLOperation *op,
-                               Uml::Visibility scope, QString type,
-                               bool isStatic, bool isAbstract, 
-                               bool isFriend, bool isConstructor,
-                               QString comment) {
+                  Uml::Visibility scope, const QString& type,
+                  bool isStatic, bool isAbstract, 
+                  bool isFriend, bool isConstructor,
+                  const QString& comment) {
     op->setVisibility(scope);
     if (!type.isEmpty()     // return type may be missing (constructor/destructor)
         && type != "void") {
@@ -317,7 +329,9 @@ void insertMethod(UMLClassifier *klass, UMLOperation *op,
     //setModified(true);
 }
 
-UMLAttribute* addMethodParameter(UMLOperation *method, QString type, QString name) {
+UMLAttribute* addMethodParameter(UMLOperation *method,
+                                 const QString& type,
+                                 const QString& name) {
     UMLClassifier *owner = static_cast<UMLClassifier*>(method->parent());
     UMLObject *typeObj = owner->findTemplate(type);
     if (typeObj == NULL) {
@@ -325,8 +339,7 @@ UMLAttribute* addMethodParameter(UMLOperation *method, QString type, QString nam
         typeObj = createUMLObject(Uml::ot_UMLObject, type, owner);
         bPutAtGlobalScope = false;
     }
-    UMLAttribute *attr = Object_Factory::createAttribute(method, name);
-    attr->setType(typeObj);
+    UMLAttribute *attr = Object_Factory::createAttribute(method, name, typeObj);
     method->addParm(attr);
     return attr;
 }
@@ -338,7 +351,7 @@ void addEnumLiteral(UMLEnum *enumType, const QString &literal) {
 void createGeneralization(UMLClassifier *child, UMLClassifier *parent) {
     // if the child is an interface, so is the parent.
     if (child->isInterface())
-        parent->setInterface(true);
+        parent->setBaseType(Uml::ot_Interface);
     Uml::Association_Type association = Uml::at_Generalization;
 
     if (parent->isInterface() && !child->isInterface()) {
@@ -349,6 +362,7 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent) {
     }
     UMLAssociation *assoc = new UMLAssociation(association, child, parent);
     UMLDoc *umldoc = UMLApp::app()->getDocument();
+    assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
     umldoc->addAssociation(assoc);
 }
 
@@ -367,13 +381,13 @@ QStringList includePathList() {
     return includePathList;
 }
 
-void addIncludePath(QString path) {
+void addIncludePath(const QString& path) {
     if (! incPathList.contains(path))
         incPathList.append(path);
 }
 
 
-bool isDatatype(QString name, UMLPackage *parentPkg) {
+bool isDatatype(const QString& name, UMLPackage *parentPkg) {
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     UMLObject * o = umldoc->findUMLObject(name, Uml::ot_Datatype, parentPkg);
     return (o!=NULL);
