@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006                                                     *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  copyright (C) 2006-2007                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
@@ -62,7 +62,7 @@ QString JavaImport::joinTypename(QString typeName) {
     return typeName;
 }
 
-void JavaImport::fillSource(QString word) {
+void JavaImport::fillSource(const QString& word) {
     QString lexeme;
     const uint len = word.length();
     for (uint i = 0; i < len; i++) {
@@ -72,7 +72,7 @@ void JavaImport::fillSource(QString word) {
         } else {
             if (!lexeme.isEmpty()) {
                 m_source.append(lexeme);
-                lexeme = QString::null;
+                lexeme = QString();
             }
             m_source.append(QString(c));
         }
@@ -82,7 +82,7 @@ void JavaImport::fillSource(QString word) {
 }
 
 
-///Spawn off an import of the specifed file
+///Spawn off an import of the specified file
 void JavaImport::spawnImport( QString file ) {
     // if the file is being parsed, don't bother
     //
@@ -109,7 +109,7 @@ UMLObject* findObject( QString name,   UMLPackage *parentPkg ) {
 
 ///Resolve the specified className 
 UMLObject* JavaImport::resolveClass (QString className) {
-    kdDebug() << "importJava trying to resolve " << className << endl; 
+    kDebug() << "importJava trying to resolve " << className << endl; 
     // keep track if we are dealing with an array
     //
     bool isArray = className.contains('[');
@@ -133,7 +133,7 @@ UMLObject* JavaImport::resolveClass (QString className) {
     // current class
     //
     QString myDir = file.join( "/" );
-    QString myFile = "/" + myDir + "/" + baseClassName + ".java";
+    QString myFile = '/' + myDir + '/' + baseClassName + ".java";
     if ( QFile::exists(myFile) ) {
         spawnImport( myFile );
         if ( isArray ) {
@@ -156,7 +156,7 @@ UMLObject* JavaImport::resolveClass (QString className) {
         file.pop_back();
     }
     // this is now the root of any further source imports
-    QString sourceRoot = "/" + file.join("/") + "/";
+    QString sourceRoot = '/' + file.join("/") + '/';
 
     for (QStringList::Iterator pathIt = m_imports.begin();
                                    pathIt != m_imports.end(); ++pathIt) {
@@ -167,7 +167,7 @@ UMLObject* JavaImport::resolveClass (QString className) {
             // check if the file we want is in this imported package
             // convert the org.test type package into a filename
             //
-            QString aFile = sourceRoot + split.join("/") + "/" + baseClassName + ".java";
+            QString aFile = sourceRoot + split.join("/") + '/' + baseClassName + ".java";
             if ( QFile::exists(aFile) ) {
                 spawnImport( aFile );
                 // we need to set the package for the class that will be resolved
@@ -197,7 +197,7 @@ UMLObject* JavaImport::resolveClass (QString className) {
 
 
 /// keep track of the current file being parsed and reset the list of imports
-void JavaImport::parseFile(QString filename) {
+void JavaImport::parseFile(const QString& filename) {
     m_currentFileName= filename;
     m_imports.clear();
     // default visibility is Impl, unless we are an interface, then it is 
@@ -212,7 +212,7 @@ void JavaImport::parseFile(QString filename) {
     s_parseDepth--;
     if ( s_parseDepth <= 0 ) {
         // if the user decides to clear things out and reparse, we need
-        // to honour the request, so reset things for next time.
+        // to honor the request, so reset things for next time.
         s_filesAlreadyParsed.clear();
         s_parseDepth = 0;
     }
@@ -224,7 +224,7 @@ void JavaImport::parseFile(QString filename) {
 bool JavaImport::parseStmt() {
     const uint srcLength = m_source.count();
     const QString& keyword = m_source[m_srcIndex];
-    //kdDebug() << '"' << keyword << '"' << endl;
+    //kDebug() << '"' << keyword << '"' << endl;
     if (keyword == "package") {
         m_currentPackage = advance();
         const QString& qualifiedName = m_currentPackage;
@@ -236,7 +236,7 @@ bool JavaImport::parseStmt() {
             m_scope[++m_scopeIndex] = static_cast<UMLPackage*>(ns);
         }
         if (advance() != ";") {
-            kdError() << "importJava: unexpected: " << m_source[m_srcIndex] << endl;
+            kError() << "importJava: unexpected: " << m_source[m_srcIndex] << endl;
             skipStmt();
         }
         return true;
@@ -252,7 +252,8 @@ bool JavaImport::parseStmt() {
         // The UMLObject found by createUMLObject might originally have been created as a
         // placeholder with a type of class but if is really an interface, then we need to
         // change it.
-        m_klass->setInterface(keyword == "interface");
+        Uml::Object_Type ot = (keyword == "interface" ? Uml::ot_Interface : Uml::ot_Class);
+        m_klass->setBaseType(ot);
         m_isAbstract = m_isStatic = false;
         // if no modifier is specified in an interface, then it means public
         if ( m_klass->isInterface() ) {
@@ -265,13 +266,13 @@ bool JavaImport::parseStmt() {
             // @todo implement all template arg syntax
             uint start = m_srcIndex;
             if (! skipToClosing('<')) {
-                kdError() << "importJava(" << name << "): template syntax error" << endl;
+                kError() << "importJava(" << name << "): template syntax error" << endl;
                 return false;
             }
             while (1) {
                 const QString arg = m_source[++start];
                 if (! arg.contains( QRegExp("^[A-Za-z_]") )) {
-                    kdDebug() << "importJava(" << name << "): cannot handle template syntax ("
+                    kDebug() << "importJava(" << name << "): cannot handle template syntax ("
                         << arg << ")" << endl;
                     break;
                 }
@@ -280,7 +281,7 @@ bool JavaImport::parseStmt() {
                 if (next == ">")
                     break;
                 if (next != ",") {
-                    kdDebug() << "importJava(" << name << "): can't handle template syntax ("
+                    kDebug() << "importJava(" << name << "): can't handle template syntax ("
                         << next << ")" << endl;
                     break;
                 }
@@ -295,7 +296,7 @@ bool JavaImport::parseStmt() {
             if ( parent ) {
                 Import_Utils::createGeneralization(m_klass, static_cast<UMLClassifier*>(parent));
             } else {
-                kdDebug() << "importJava parentClass " << baseName 
+                kDebug() << "importJava parentClass " << baseName 
                     << " is not resolveable. Creating placeholder" << endl;
                 Import_Utils::createGeneralization(m_klass, baseName);
             }
@@ -310,7 +311,7 @@ bool JavaImport::parseStmt() {
                 if ( interface ) {
                      Import_Utils::createGeneralization(m_klass, static_cast<UMLClassifier*>(interface));
                 } else {
-                    kdDebug() << "importJava implementing interface "<< baseName 
+                    kDebug() << "importJava implementing interface "<< baseName 
                         <<" is not resolvable. Creating placeholder" <<endl;
                     Import_Utils::createGeneralization(m_klass, baseName); 
                 }
@@ -319,7 +320,7 @@ bool JavaImport::parseStmt() {
             }
         }
         if (m_source[m_srcIndex] != "{") {
-            kdError() << "importJava: ignoring excess chars at " << name
+            kError() << "importJava: ignoring excess chars at " << name
                 << " (" << m_source[m_srcIndex] << ")" << endl;
             skipStmt("{");
         }
@@ -412,7 +413,7 @@ bool JavaImport::parseStmt() {
         if (m_scopeIndex)
             m_klass = dynamic_cast<UMLClassifier*>(m_scope[--m_scopeIndex]);
         else
-            kdError() << "importJava: too many }" << endl;
+            kError() << "importJava: too many }" << endl;
         return true;
     }
     // At this point, we expect `keyword' to be a type name
@@ -420,14 +421,14 @@ bool JavaImport::parseStmt() {
     // of an operation.) Up next is the name of the attribute
     // or operation.
     if (! keyword.contains( QRegExp("^\\w") )) {
-        kdError() << "importJava: ignoring " << keyword << endl;
+        kError() << "importJava: ignoring " << keyword << endl;
         return false;
     }
     QString typeName = m_source[m_srcIndex];
     typeName = joinTypename(typeName);
     // At this point we need a class.
     if (m_klass == NULL) {
-        kdError() << "importJava: no class set for " << typeName << endl;
+        kError() << "importJava: no class set for " << typeName << endl;
         return false;
     }
     QString name = advance();
@@ -436,12 +437,12 @@ bool JavaImport::parseStmt() {
         // Constructor.
         nextToken = name;
         name = typeName;
-        typeName = QString::null;
+        typeName = QString();
     } else {
         nextToken = advance();
     }
     if (name.contains( QRegExp("\\W") )) {
-        kdError() << "importJava: expecting name in " << name << endl;
+        kError() << "importJava: expecting name in " << name << endl;
         return false;
     }
     if (nextToken == "(") {
@@ -539,7 +540,7 @@ bool JavaImport::parseStmt() {
     // reset visibility to default
     m_currentAccess = m_defaultCurrentAccess;
     if (m_source[m_srcIndex] != ";") {
-        kdError() << "importJava: ignoring trailing items at " << name << endl;
+        kError() << "importJava: ignoring trailing items at " << name << endl;
         skipStmt();
     }
     return true;
