@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2005-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  copyright (C) 2005-2007                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 #ifndef NATIVEIMPORTBASE_H
@@ -47,7 +47,7 @@ public:
      * Constructor
      * @param singleLineCommentIntro  "//" for IDL and Java, "--" for Ada
      */
-    NativeImportBase(QString singleLineCommentIntro);
+    NativeImportBase(const QString &singleLineCommentIntro);
     virtual ~NativeImportBase();
 
 protected:
@@ -64,12 +64,12 @@ protected:
      * @param end    In languages with a C style multiline comment
      *               this is star-slash.
      */
-    void setMultiLineComment(QString intro, QString end);
+    void setMultiLineComment(const QString &intro, const QString &end);
     /**
      * Set the delimiter strings for an alternative form of
      * multi line comment. See setMultiLineComment().
      */
-    void setMultiLineAltComment(QString intro, QString end);
+    void setMultiLineAltComment(const QString &intro, const QString &end);
 
     /**
      * Import a single file.
@@ -78,7 +78,7 @@ protected:
      *
      * @param file  The file to import.
      */
-    virtual void parseFile(QString filename);
+    virtual void parseFile(const QString& filename);
 
     /**
      * Initialize auxiliary variables.
@@ -110,12 +110,19 @@ protected:
      */
     virtual bool preprocess(QString& line);
 
+    /**
+     * Split the line so that a string is returned as a single element of the list.
+     * When not in a string then split at white space.
+     * The default implementation is suitable for C style strings and char constants.
+     */
+    virtual QStringList split(const QString& line);
+
     /**
      * Analyze the given word and fill `m_source'.
      * A "word" is a whitespace delimited item from the input line.
      * To be provided by the specific importer class.
      */
-    virtual void fillSource(QString word) = 0;
+    virtual void fillSource(const QString& word) = 0;
 
     /**
      * Parse the statement which starts at m_source[m_srcIndex]
@@ -133,6 +140,16 @@ protected:
      */
     void skipStmt(QString until = ";");
 
+    /**
+     * Advance m_srcIndex to the index of the corresponding closing character
+     * of the given opening.  Nested opening/closing pairs are respected.
+     * Valid openers are:    '{'  '['  '('  '<'
+     *
+     * @return  True for success, false for misuse (invalid opener) or
+     *          if no matching closing character is found in m_source.
+     */
+    bool skipToClosing(QChar opener);
+
     /**
      * Advance m_srcIndex until m_source[m_srcIndex] contains a non-comment.
      * Comments encountered during advancement are accumulated in `m_comment'.
@@ -155,7 +172,7 @@ protected:
     uint m_srcIndex;
 
     /**
-     * Stack of scopes.
+     * Stack of scopes for use by the specific importer.
      */
     UMLPackage *m_scope[32];
     /**
@@ -186,8 +203,10 @@ protected:
     bool m_isAbstract;
 
     /**
-     * List of parsed files. The exact syntax of the items
-     * stored here depend on the specific code importer.
+     * List of parsed files. Contains file names without paths.
+     * Before actually parsing a given file, NativeImportBase checks
+     * whether the name is already present in this list in order to
+     * avoid parsing the same file multiple times.
      */
     QStringList m_parsedFiles;
 
