@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *  copyright (C) 2006                                                     *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
@@ -41,7 +41,7 @@ void PascalImport::initVars() {
     NativeImportBase::m_currentAccess = Uml::Visibility::Public;
 }
 
-void PascalImport::fillSource(QString word) {
+void PascalImport::fillSource(const QString& word) {
     QString lexeme;
     const uint len = word.length();
     for (uint i = 0; i < len; i++) {
@@ -51,7 +51,7 @@ void PascalImport::fillSource(QString word) {
         } else {
             if (!lexeme.isEmpty()) {
                 m_source.append(lexeme);
-                lexeme = QString::null;
+                lexeme = QString();
             }
             if (c == ':' && word[i + 1] == '=') {
                 m_source.append(":=");
@@ -87,7 +87,7 @@ void PascalImport::checkModifiers(bool& isVirtual, bool& isAbstract) {
 bool PascalImport::parseStmt() {
     const uint srcLength = m_source.count();
     QString keyword = m_source[m_srcIndex].lower();
-    //kdDebug() << '"' << keyword << '"' << endl;
+    //kDebug() << '"' << keyword << '"' << endl;
     if (keyword == "uses") {
         while (++m_srcIndex < srcLength && m_source[m_srcIndex] != ";") {
             QStringList components = QStringList::split(".", m_source[m_srcIndex]);
@@ -196,7 +196,7 @@ bool PascalImport::parseStmt() {
             m_scopeIndex--;
             m_currentAccess = Uml::Visibility::Public;
         } else {
-            kdError() << "importPascal: too many \"end\"" << endl;
+            kError() << "importPascal: too many \"end\"" << endl;
         }
         skipStmt();
         return true;
@@ -231,13 +231,13 @@ bool PascalImport::parseStmt() {
                 uint parNameCount = 0;
                 do {
                     if (parNameCount >= MAX_PARNAMES) {
-                        kdError() << "MAX_PARNAMES is exceeded at " << name << endl;
+                        kError() << "MAX_PARNAMES is exceeded at " << name << endl;
                         break;
                     }
                     parName[parNameCount++] = advance();
                 } while (advance() == ",");
                 if (m_source[m_srcIndex] != ":") {
-                    kdError() << "importPascal: expecting ':' at " << m_source[m_srcIndex] << endl;
+                    kError() << "importPascal: expecting ':' at " << m_source[m_srcIndex] << endl;
                     skipStmt();
                     break;
                 }
@@ -245,7 +245,7 @@ bool PascalImport::parseStmt() {
                 if (nextToken.lower() == "array") {
                     nextToken = advance().lower();
                     if (nextToken != "of") {
-                        kdError() << "importPascal(" << name << "): expecting 'array OF' at "
+                        kError() << "importPascal(" << name << "): expecting 'array OF' at "
                                   << nextToken << endl;
                         skipStmt();
                         return false;
@@ -263,7 +263,7 @@ bool PascalImport::parseStmt() {
         QString returnType;
         if (keyword == "function") {
             if (advance() != ":") {
-                kdError() << "importPascal: expecting \":\" at function "
+                kError() << "importPascal: expecting \":\" at function "
                         << name << endl;
                 return false;
             }
@@ -287,7 +287,7 @@ bool PascalImport::parseStmt() {
         const QString& name = m_source[m_srcIndex];
         QString nextToken = advance();
         if (nextToken != "=") {
-            kdDebug() << "PascalImport::parseFile(" << name << "): "
+            kDebug() << "PascalImport::parseStmt(" << name << "): "
                 << "expecting '=' at " << nextToken << endl;
             return false;
         }
@@ -325,14 +325,14 @@ bool PascalImport::parseStmt() {
             UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Class,
                             name, m_scope[m_scopeIndex], m_comment);
             m_klass = static_cast<UMLClassifier*>(ns);
-            m_comment = QString::null;
+            m_comment = QString();
             if (m_source[m_srcIndex + 1] == "(") {
                 advance();
                 do {
                     QString base = advance();
                     UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Class, base, NULL);
                     UMLClassifier *parent = static_cast<UMLClassifier*>(ns);
-                    m_comment = QString::null;
+                    m_comment = QString();
                     Import_Utils::createGeneralization(m_klass, parent);
                 } while (advance() == ",");
             }
@@ -359,7 +359,7 @@ bool PascalImport::parseStmt() {
     }
     // At this point we need a class because we're expecting its member attributes.
     if (m_klass == NULL) {
-        kdDebug() << "importPascal: skipping " << m_source[m_srcIndex] << endl;
+        kDebug() << "importPascal: skipping " << m_source[m_srcIndex] << endl;
         skipStmt();
         return true;
     }
@@ -371,7 +371,7 @@ bool PascalImport::parseStmt() {
         name = keyword;
     }
     if (advance() != ":") {
-        kdError() << "PascalImport: expecting \":\" at " << name << " "
+        kError() << "PascalImport: expecting \":\" at " << name << " "
                   << m_source[m_srcIndex] << endl;
         skipStmt();
         return true;
@@ -382,7 +382,7 @@ bool PascalImport::parseStmt() {
         initialValue = advance();
         QString token;
         while ((token = advance()) != ";") {
-            initialValue.append(" " + token);
+            initialValue.append(' ' + token);
         }
     }
     UMLObject *o = Import_Utils::insertAttribute(m_klass, m_currentAccess, name,
