@@ -163,7 +163,7 @@ void CodeEditor::editTextBlock(TextBlock * tBlock, int para) {
                 }
                 else
                 {
-                    kdError()<<" CodeViewerDlg ERROR: UNKNOWN parent for textBlock"<<endl;
+                    kError()<<" CodeViewerDlg ERROR: UNKNOWN parent for textBlock"<<endl;
                 }
 
             }
@@ -181,7 +181,7 @@ bool CodeEditor::StringIsBlank(const QString &str)
 
 void CodeEditor::keyPressEvent ( QKeyEvent * e ) {
 
-    // kdDebug() <<"KEY PRESS EVENT:["<<e->text().latin1()<<"] ascii CODE:"<<e->ascii();
+    // kDebug() <<"KEY PRESS EVENT:["<<e->text().latin1()<<"] ascii CODE:"<<e->ascii();
 
     if((e->ascii() == 8) ) // || (e->ascii() == 127)) // what about delete?
         m_backspacePressed = true;
@@ -411,10 +411,10 @@ void CodeEditor::appendText (CodeClassFieldDeclarationBlock * db ) {
     if(parentObj)
     {
         if(db->getParentClassField()->parentIsAttribute()) {
-            componentName = parentDocName + "::attribute_field(" + parentObj->getName() + ")";
+            componentName = parentDocName + "::attribute_field(" + parentObj->getName() + ')';
         } else {
             UMLRole * role = dynamic_cast<UMLRole*>(parentObj);
-            componentName = parentDocName + "::association_field(" + role->getName() + ")";
+            componentName = parentDocName + "::association_field(" + role->getName() + ')';
         }
         bgcolor = getState().umlObjectColor;
     }
@@ -528,9 +528,9 @@ void CodeEditor::appendText(HierarchicalCodeBlock * hblock)
                 typeStr = "Interface";
             else
                 typeStr = "Class";
-            componentName = parentDocName + "::" + typeStr + "(" + parentObj->getName() + ")";
+            componentName = parentDocName + "::" + typeStr + '(' + parentObj->getName() + ')';
         } else {
-            componentName = parentDocName + "::UNKNOWN(" + parentObj->getName() + ")";
+            componentName = parentDocName + "::UNKNOWN(" + parentObj->getName() + ')';
         }
 
         paperColor = getState().umlObjectColor;
@@ -720,7 +720,7 @@ void CodeEditor::slotCopyTextBlock ( )
         m_textBlockToPaste = CodeGenFactory::newCodeComment(m_parentDoc);
     else
     {
-        kdError()<<" ERROR: CodeEditor can't copy selected block:"<<m_selectedTextBlock<<" of unknown type"<<endl;
+        kError()<<" ERROR: CodeEditor can't copy selected block:"<<m_selectedTextBlock<<" of unknown type"<<endl;
         m_textBlockToPaste = 0;
         return; // error!
     }
@@ -777,9 +777,9 @@ void CodeEditor::init ( CodeViewerDialog * parentDlg, CodeDocument * parentDoc )
     m_parentDlg = parentDlg;
     m_parentDoc = parentDoc;
 
-    setUndoRedoEnabled( FALSE );
+    setUndoRedoEnabled( false );
     setCursor( QCursor( 0 ) );
-    setMouseTracking( TRUE );
+    setMouseTracking( true );
     setReadOnly (true);
     m_isHighlighted = getState().blocksAreHighlighted;
     m_showHiddenBlocks = getState().showHiddenBlocks;
@@ -908,7 +908,7 @@ void CodeEditor::cursorPositionChanged(int para, int pos)
         int minPos = baseIndent.length();
 
         // add indent chars to the current line, if missing
-        if(!m_backspacePressed && !currentParaText.contains(QRegExp("^"+baseIndent)))
+        if(!m_backspacePressed && !currentParaText.contains(QRegExp('^'+baseIndent)))
         {
             insertAt(baseIndent,para,0);
             setCursorPosition(para,pos+minPos);
@@ -952,7 +952,7 @@ void CodeEditor::cursorPositionChanged(int para, int pos)
 
                     // furthermore, IF its nothing but indentation + whitespace
                     // we switch this back to Auto-Generated.
-                    if(cmb && contents.contains(QRegExp("^"+baseIndent+"\\s$")))
+                    if(cmb && contents.contains(QRegExp('^'+baseIndent+"\\s$")))
                     {
                         cmb->setContentType(CodeBlock::AutoGenerated);
                         cmb->syncToParent();
