@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include <qcheckbox.h>
@@ -21,7 +18,10 @@
 
 #include "overwritedialogue.h"
 
-OverwriteDialogue::OverwriteDialogue(QString fileName, QString outputDirectory, bool applyToAllRemaining, QWidget* parent, const char* name):
+OverwriteDialogue::OverwriteDialogue(
+        const QString& fileName,
+        const QString& outputDirectory,
+        bool applyToAllRemaining, QWidget* parent, const char* name) :
 KDialogBase(Plain, i18n("Destination File Already Exists"), Ok|Apply|Cancel, Yes, parent, name) {
 
     QVBoxLayout* layout = new QVBoxLayout( plainPage(), 0, spacingHint() );
