@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef PARMPROPDLG_H
@@ -106,14 +103,19 @@ protected:
     */
     void insertType( const QString& type, int index = -1 );
 
+    /**
+     * Inserts @p type into the stereotype-combobox as well as its completion object.
+     */
+    void insertStereotype( const QString& type, int index = -1 );
+
 
 private:
     QGroupBox * m_pParmGB, * m_pDocGB;
     QButtonGroup *m_pKind;
     QRadioButton * m_pIn, * m_pOut, *m_pInOut;
     QLabel * m_pTypeL, * m_pNameL, * m_pInitialL, * m_pStereoTypeL;
-    KComboBox * m_pTypeCB;
-    QLineEdit * m_pNameLE, * m_pInitialLE, * m_pStereoTypeLE;
+    KComboBox * m_pTypeCB, * m_pStereoTypeCB;
+    QLineEdit * m_pNameLE, * m_pInitialLE;
     QMultiLineEdit * m_pDoc;
     UMLDoc * m_pUmldoc;
     UMLAttribute * m_pAtt;
