@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *  copyright (C) 2002-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
@@ -389,7 +389,7 @@ void SettingsDlg::applyPage( Settings::Page page ) {
         m_pOptionState->generalState.logo = m_GeneralWidgets.logoCB -> isChecked();
         m_pOptionState->generalState.tip = m_GeneralWidgets.tipCB -> isChecked();
         m_pOptionState->generalState.loadlast = m_GeneralWidgets.loadlastCB -> isChecked();
-        m_pOptionState->generalState.diagram  = (Settings::Diagram)(m_GeneralWidgets.diagramKB->currentItem() + 1);
+        m_pOptionState->generalState.diagram  = (Uml::Diagram_Type)(m_GeneralWidgets.diagramKB->currentItem() + 1);
         break;
 
     case Settings::page_font:
