@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -48,6 +45,7 @@
 #include "../dialog_utils.h"
 #include "parmpropdlg.h"
 #include "../stereotype.h"
+#include "../uniqueid.h"
 
 UMLOperationDialog::UMLOperationDialog( QWidget * parent, UMLOperation * pOperation )
         : KDialogBase( Plain, i18n("Operation Properties"), Help | Ok | Cancel , Ok, parent, "_UMLOPERATIONDLG_", true, true) {
@@ -193,10 +191,10 @@ void UMLOperationDialog::setupDialog() {
     }
     
     //fill in parm list box
-    UMLAttributeList * list = m_pOperation -> getParmList();
+    UMLAttributeList list = m_pOperation->getParmList();
     UMLAttribute * pAtt = 0;
-    for( pAtt = list -> first(); pAtt != 0; pAtt = list -> next() )
-        m_pParmsLB -> insertItem( pAtt -> getName() );
+    for (pAtt = list.first(); pAtt; pAtt = list.next())
+        m_pParmsLB->insertItem( pAtt->getName() );
 
     //set scope
     Uml::Visibility scope = m_pOperation -> getVisibility();
@@ -329,7 +327,7 @@ void UMLOperationDialog::slotNewParameter() {
             m_pOperation->addParm( dlg.getTypeName(), name, dlg.getInitialValue(),
                                dlg.getDoc(), dlg.getParmKind() );
              */
-            newAttribute->setID( m_doc->getUniqueID() );
+            newAttribute->setID( UniqueID::gen() );
             newAttribute->setName( name );
             newAttribute->setTypeName( dlg.getTypeName() );
             newAttribute->setInitialValue( dlg.getInitialValue() );
@@ -367,7 +365,7 @@ void UMLOperationDialog::slotParameterProperties() {
     pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     if( !pOldAtt ) {
-        kdDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText() << endl;
+        kDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText() << endl;
         return;
     }//should never occur
     ParmPropDlg dlg(this, m_doc, pOldAtt);
@@ -396,7 +394,7 @@ void UMLOperationDialog::slotParameterProperties() {
                 }
                 if (obj == NULL) {
                     // Nothing found: set type name directly. Bad.
-                    kdDebug() << "UMLOperationDialog::slotParameterProperties: "
+                    kDebug() << "UMLOperationDialog::slotParameterProperties: "
                     << typeName << " not found." << endl;
                     pOldAtt->setTypeName( typeName );  // Bad.
                 }
@@ -414,7 +412,7 @@ void UMLOperationDialog::slotParameterProperties() {
 
 void UMLOperationDialog::slotParameterUp()
 {
-    kdDebug() << k_funcinfo << endl;
+    kDebug() << k_funcinfo << endl;
     UMLAttribute* pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     m_pOperation->moveParmLeft( pOldAtt );
