@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2005                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -19,6 +19,7 @@
 #include "entityattribute.h"
 #include "umldoc.h"
 #include "uml.h"
+#include "uniqueid.h"
 #include "clipboard/idchangelog.h"
 #include "dialogs/umlentityattributedialog.h"
 
@@ -51,9 +52,8 @@ void UMLEntity::init() {
     m_BaseType = Uml::ot_Entity;
 }
 
-UMLObject* UMLEntity::createAttribute(const QString &name /*=null*/) {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    Uml::IDType id = umldoc->getUniqueID();
+UMLAttribute* UMLEntity::createAttribute(const QString &name /*=null*/) {
+    Uml::IDType id = UniqueID::gen();
     QString currentName;
     if (name.isNull())  {
         currentName = uniqChildName(Uml::ot_EntityAttribute);
@@ -89,6 +89,7 @@ UMLObject* UMLEntity::createAttribute(const QString &name /*=null*/) {
 
     addEntityAttribute(newAttribute);
 
+    UMLDoc *umldoc = UMLApp::app()->getDocument();
     umldoc->signalUMLObjectCreated(newAttribute);
     return newAttribute;
 }
@@ -139,12 +140,12 @@ bool UMLEntity::addEntityAttribute(UMLEntityAttribute* attribute, int position)
 
 int UMLEntity::removeEntityAttribute(UMLClassifierListItem* literal) {
     if (!m_List.remove((UMLEntityAttribute*)literal)) {
-        kdDebug() << "can't find att given in list" << endl;
+        kDebug() << "can't find att given in list" << endl;
         return -1;
     }
     emit entityAttributeRemoved(literal);
     emit modified();
-    // If we are deleteing the object, then we don't need to disconnect..this is done auto-magically
+    // If we are deleting the object, then we don't need to disconnect..this is done auto-magically
     // for us by QObject. -b.t.
     // disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
     delete literal;
@@ -201,10 +202,10 @@ bool UMLEntity::load(QDomElement& element) {
             }
             m_List.append(pEntityAttribute);
         } else if (tag == "stereotype") {
-            kdDebug() << "UMLEntity::load(" << m_Name
+            kDebug() << "UMLEntity::load(" << m_Name
             << "): losing old-format stereotype." << endl;
         } else {
-            kdWarning() << "unknown child type in UMLEntity::load" << endl;
+            kWarning() << "unknown child type in UMLEntity::load" << endl;
         }
         node = node.nextSibling();
     }//end while
