@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -62,7 +59,7 @@ UMLObject* UMLEnum::createEnumLiteral() {
     bool goodName = false;
 
     while (ok && !goodName) {
-        ok = newEnumLiteral->showPropertiesDialogue( UMLApp::app() );
+        ok = newEnumLiteral->showPropertiesDialog( UMLApp::app() );
         QString name = newEnumLiteral->getName();
 
         if(name.length() == 0) {
@@ -86,7 +83,7 @@ UMLObject* UMLEnum::createEnumLiteral() {
 UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::IDType id) {
     UMLObject *el = UMLCanvasObject::findChildObject(name);
     if (el != NULL) {
-        kdDebug() << "UMLEnum::addEnumLiteral: " << name
+        kDebug() << "UMLEnum::addEnumLiteral: " << name
                   << " is already present" << endl; 
         return el;
     }
@@ -135,12 +132,12 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position) {
 
 int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal) {
     if (!m_List.remove(literal)) {
-        kdDebug() << "can't find att given in list" << endl;
+        kDebug() << "can't find att given in list" << endl;
         return -1;
     }
     emit enumLiteralRemoved(literal);
     emit modified();
-    // If we are deleteing the object, then we dont need to disconnect..this is done auto-magically
+    // If we are deleting the object, then we don't need to disconnect..this is done auto-magically
     // for us by QObject. -b.t.
     // disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
     delete literal;
@@ -184,10 +181,10 @@ bool UMLEnum::load(QDomElement& element) {
             }
             m_List.append(pEnumLiteral);
         } else if (tag == "stereotype") {
-            kdDebug() << "UMLEnum::load(" << m_Name
+            kDebug() << "UMLEnum::load(" << m_Name
             << "): losing old-format stereotype." << endl;
         } else {
-            kdWarning() << "unknown child type in UMLEnum::load" << endl;
+            kWarning() << "unknown child type in UMLEnum::load" << endl;
         }
         node = node.nextSibling();
     }//end while
