@@ -6,9 +6,10 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
 #include "floatingtextwidget.h"
 
 // system includes
@@ -18,6 +19,7 @@
 #include <qvalidator.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kinputdialog.h>
 
 // local includes
 #include "floatingtextwidgetcontroller.h"
@@ -31,12 +33,11 @@
 #include "model_utils.h"
 #include "object_factory.h"
 #include "messagewidget.h"
-#include "inputdialog.h"
 #include "dialogs/assocpropdlg.h"
 #include "dialogs/selectopdlg.h"
 
 FloatingTextWidget::FloatingTextWidget(UMLView * view, Uml::Text_Role role,
-                                       QString text, Uml::IDType id)
+                                       const QString& text, Uml::IDType id)
   : UMLWidget(view, id, new FloatingTextWidgetController(this))
 {
     init();
@@ -96,10 +97,10 @@ void FloatingTextWidget::slotMenuSelection(int sel) {
 
     case ListPopupMenu::mt_Operation:
         {
-            kdDebug() << "FloatingTextWidget::slotMenuSelection(mt_Operation) is called."
+            kDebug() << "FloatingTextWidget::slotMenuSelection(mt_Operation) is called."
             << endl;
             if (m_pLink == NULL) {
-                kdDebug() << "FloatingTextWidget::slotMenuSelection(mt_Operation): "
+                kDebug() << "FloatingTextWidget::slotMenuSelection(mt_Operation): "
                 << "m_pLink is NULL" << endl;
                 return;
             }
@@ -268,13 +269,13 @@ void FloatingTextWidget::changeTextDlg() {
 
 void FloatingTextWidget::showOpDlg() {
     if (m_pLink == NULL) {
-        kdError() << "FloatingTextWidget::showOpDlg: m_pLink is NULL" << endl;
+        kError() << "FloatingTextWidget::showOpDlg: m_pLink is NULL" << endl;
         return;
     }
     QString seqNum, opText;
     UMLClassifier* c = m_pLink->getSeqNumAndOp(seqNum, opText);
     if (c == NULL) {
-        kdError() << "FloatingTextWidget::showOpDlg: "
+        kError() << "FloatingTextWidget::showOpDlg: "
         << "m_pLink->getSeqNumAndOp() returns a NULL classifier"
         << endl;
         return;
