@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 //qt includes
@@ -24,6 +24,7 @@
 #include "umlview.h"
 #include "umldoc.h"
 #include "uml.h"
+#include "uniqueid.h"
 #include "listpopupmenu.h"
 
 MessageWidget::MessageWidget(UMLView * view, ObjectWidget* a, ObjectWidget* b,
@@ -61,7 +62,6 @@ void MessageWidget::init() {
     m_pOw[Uml::A] = m_pOw[Uml::B] = NULL;
     m_pFText = NULL;
     m_nY = 0;
-    m_inSelection = false;
     setVisible(true);
 }
 
@@ -88,7 +88,7 @@ void MessageWidget::draw(QPainter& p, int offsetX, int offsetY) {
     } else if (m_sequenceMessageType == Uml::sequence_message_creation) {
         drawCreation(p, offsetX, offsetY);
     } else {
-        kdWarning() << "Unknown message type" << endl;
+        kWarning() << "Unknown message type" << endl;
     }
 }
 
@@ -274,7 +274,7 @@ int MessageWidget::onWidget(const QPoint & p) {
 
 void MessageWidget::setTextPosition() {
     if (m_pFText == NULL) {
-        kdDebug() << "MessageWidget::setTextPosition: m_pFText is NULL"
+        kDebug() << "MessageWidget::setTextPosition: m_pFText is NULL"
         << endl;
         return;
     }
@@ -330,7 +330,7 @@ void MessageWidget::setLinkAndTextPos() {
 }
 
 void MessageWidget::moveEvent(QMoveEvent* /*m*/) {
-    //kdDebug() << "MessageWidget::moveEvent: m_pFText is " << m_pFText << endl;
+    //kDebug() << "MessageWidget::moveEvent: m_pFText is " << m_pFText << endl;
     if (!m_pFText) {
         return;
     }
@@ -361,7 +361,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id) {
     const Uml::IDType idA = m_pOw[Uml::A]->getLocalID();
     const Uml::IDType idB = m_pOw[Uml::B]->getLocalID();
     if (idA != id && idB != id) {
-        kdDebug() << "MessageWidget::slotWidgetMoved(" << ID2STR(id)
+        kDebug() << "MessageWidget::slotWidgetMoved(" << ID2STR(id)
             << "): ignoring for idA=" << ID2STR(idA)
             << ", idB=" << ID2STR(idB) << endl;
         return;
@@ -374,7 +374,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id) {
     calculateWidget();
     if( !m_pFText )
         return;
-    if( m_pView -> getSelectCount() > 1 )
+    if (m_pView->getSelectCount(true) > 1)
         return;
     setTextPosition();
 }
@@ -408,7 +408,7 @@ void MessageWidget::activate(IDChangeLog * Log /*= 0*/) {
     m_pView->resetPastePoint();
     UMLWidget::activate(Log);
     if (m_pOw[Uml::A] == NULL || m_pOw[Uml::B] == NULL) {
-        kdDebug() << "MessageWidget::activate: can't make message" << endl;
+        kDebug() << "MessageWidget::activate: can't make message" << endl;
         return;
     }
     if( !m_pFText ) {
@@ -516,7 +516,7 @@ void MessageWidget::calculateDimensions() {
     } else if (m_sequenceMessageType == Uml::sequence_message_creation) {
         calculateDimensionsCreation();
     } else {
-        kdWarning() << "Unknown message type" << endl;
+        kWarning() << "Unknown message type" << endl;
     }
     if (! UMLApp::app()->getDocument()->loading()) {
         adjustAssocs( getX(), getY() );  // adjust assoc lines
@@ -634,11 +634,6 @@ void MessageWidget::cleanup() {
 }
 
 void MessageWidget::setSelected(bool _select) {
-    if( m_inSelection )//used to stop a recursive call
-    {
-        m_inSelection = false;
-        return;
-    }
     UMLWidget::setSelected( _select );
     if( !m_pFText || m_pFText->getDisplayText().isEmpty())
         return;
@@ -647,7 +642,6 @@ void MessageWidget::setSelected(bool _select) {
     if( !m_bSelected && !m_pFText -> getSelected() )
         return;
 
-    m_inSelection = true;
     m_pView -> setSelected( m_pFText, 0 );
     m_pFText -> setSelected( m_bSelected );
 }
@@ -729,25 +723,25 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement) {
 
     UMLWidget *pWA = m_pView -> findWidget( aId );
     if (pWA == NULL) {
-        kdDebug() << "MessageWidget::loadFromXMI: role A object "
+        kDebug() << "MessageWidget::loadFromXMI: role A object "
         << ID2STR(aId) << " not found" << endl;
         return false;
     }
     UMLWidget *pWB = m_pView -> findWidget( bId );
     if (pWB == NULL) {
-        kdDebug() << "MessageWidget::loadFromXMI: role B object "
+        kDebug() << "MessageWidget::loadFromXMI: role B object "
         << ID2STR(bId) << " not found" << endl;
         return false;
     }
     m_pOw[Uml::A] = dynamic_cast<ObjectWidget*>(pWA);
     if (m_pOw[Uml::A] == NULL) {
-        kdDebug() << "MessageWidget::loadFromXMI: role A widget "
+        kDebug() << "MessageWidget::loadFromXMI: role A widget "
         << ID2STR(aId) << " is not an ObjectWidget" << endl;
         return false;
     }
     m_pOw[Uml::B] = dynamic_cast<ObjectWidget*>(pWB);
     if (m_pOw[Uml::B] == NULL) {
-        kdDebug() << "MessageWidget::loadFromXMI: role B widget "
+        kDebug() << "MessageWidget::loadFromXMI: role B widget "
         << ID2STR(bId) << " is not an ObjectWidget" << endl;
         return false;
     }
@@ -777,7 +771,7 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement) {
         }
     } else {
         // no textid stored -> get unique new one
-        textId = UMLApp::app()->getDocument()->getUniqueID();
+        textId = UniqueID::gen();
     }
 
     Uml::Text_Role tr = Uml::tr_Seq_Message;
@@ -797,7 +791,7 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement) {
                 m_pFText = NULL;
             }
         } else {
-            kdError() << "MessageWidget::loadFromXMI: unknown tag "
+            kError() << "MessageWidget::loadFromXMI: unknown tag "
             << tag << endl;
         }
     }
