@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *  copyright (C) 2004-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
@@ -17,9 +17,9 @@
 #include <qstringlist.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kinputdialog.h>
 
 // app includes
-#include "inputdialog.h"
 #include "umlobject.h"
 #include "umlpackagelist.h"
 #include "package.h"
@@ -56,7 +56,7 @@ bool isCloneable(Uml::Widget_Type type) {
     }
 }
 
-UMLObject * findObjectInList(Uml::IDType id, UMLObjectList inList) {
+UMLObject * findObjectInList(Uml::IDType id, const UMLObjectList& inList) {
     for (UMLObjectListIt oit(inList); oit.current(); ++oit) {
         UMLObject *obj = oit.current();
         if (obj->getID() == id)
@@ -100,10 +100,12 @@ UMLObject * findObjectInList(Uml::IDType id, UMLObjectList inList) {
     return NULL;
 }
 
-UMLObject* findUMLObject(UMLObjectList inList, QString name,
+UMLObject* findUMLObject(const UMLObjectList& inList,
+                         const QString& inName,
                          Uml::Object_Type type /* = ot_UMLObject */,
                          UMLObject *currentObj /* = NULL */) {
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
+    QString name = inName;
     QStringList components;
 #ifdef TRY_BUGFIX_120682
     // If we have a pointer or a reference in cpp we need to remove
@@ -145,7 +147,7 @@ UMLObject* findUMLObject(UMLObjectList inList, QString name,
                 }
             }
             if (seenPkgs.findRef(pkg) != -1) {
-                kdError() << "findUMLObject(" << name << "): "
+                kError() << "findUMLObject(" << name << "): "
                     << "breaking out of cycle involving "
                     << pkg->getName() << endl;
                 break;
@@ -163,10 +165,21 @@ UMLObject* findUMLObject(UMLObjectList inList, QString name,
                 Uml::Object_Type foundType = obj->getBaseType();
                 if (nameWithoutFirstPrefix.isEmpty()) {
                     if (type != Uml::ot_UMLObject && type != foundType) {
-                        kdDebug() << "findUMLObject: type mismatch for "
+                        kDebug() << "findUMLObject: type mismatch for "
                             << name << " (seeking type: "
                             << type << ", found type: "
                             << foundType << ")" << endl;
+                        // Class, Interface, and Datatype are all Classifiers
+                        // and are considered equivalent.
+                        // The caller must be prepared to handle possible mismatches.
+                        if ((type == Uml::ot_Class ||
+                             type == Uml::ot_Interface ||
+                             type == Uml::ot_Datatype) &&
+                            (foundType == Uml::ot_Class || 
+                             foundType == Uml::ot_Interface || 
+                             foundType == Uml::ot_Datatype)) {
+                            return obj;
+                        }
                         continue;
                     }
                     return obj;
@@ -176,7 +189,7 @@ UMLObject* findUMLObject(UMLObjectList inList, QString name,
                     foundType != Uml::ot_Class &&
                     foundType != Uml::ot_Interface &&
                     foundType != Uml::ot_Component) {
-                    kdDebug() << "findUMLObject: found \"" << name
+                    kDebug() << "findUMLObject: found \"" << name
                         << "\" is not a package (?)" << endl;
                     continue;
                 }
@@ -198,7 +211,7 @@ UMLObject* findUMLObject(UMLObjectList inList, QString name,
         Uml::Object_Type foundType = obj->getBaseType();
         if (nameWithoutFirstPrefix.isEmpty()) {
             if (type != Uml::ot_UMLObject && type != foundType) {
-                kdDebug() << "findUMLObject: type mismatch for "
+                kDebug() << "findUMLObject: type mismatch for "
                     << name << " (seeking type: "
                     << type << ", found type: "
                     << foundType << ")" << endl;
@@ -211,7 +224,7 @@ UMLObject* findUMLObject(UMLObjectList inList, QString name,
             foundType != Uml::ot_Class &&
             foundType != Uml::ot_Interface &&
             foundType != Uml::ot_Component) {
-            kdDebug() << "findUMLObject: found \"" << name
+            kDebug() << "findUMLObject: found \"" << name
                 << "\" is not a package (?)" << endl;
             continue;
         }
@@ -253,13 +266,13 @@ QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString pre
             currentName = i18n("new_association");
         else {
             currentName = i18n("new_object");
-            kdWarning() << "unknown object type in umldoc::uniqObjectName()" << endl;
+            kWarning() << "unknown object type in umldoc::uniqObjectName()" << endl;
         }
     }
     UMLDoc *doc = UMLApp::app()->getDocument();
     QString name = currentName;
     for (int number = 1; !doc->isUnique(name, parentPkg); number++)  {
-        name = currentName + "_" + QString::number(number);
+        name = currentName + '_' + QString::number(number);
     }
     return name;
 }
@@ -316,8 +329,19 @@ Uml::Model_Type guessContainer(UMLObject *o) {
     Uml::Object_Type ot = o->getBaseType();
     if (ot == Uml::ot_Package && o->getStereotype() == "subsystem")
         return Uml::mt_Component;
-    Uml::Model_Type mt = Uml::mt_Logical;
+    Uml::Model_Type mt = Uml::N_MODELTYPES;
     switch (ot) {
+        case Uml::ot_Package:   // CHECK: packages may appear in other views?
+        case Uml::ot_Interface:
+        case Uml::ot_Datatype:
+        case Uml::ot_Enum:
+        case Uml::ot_Class:
+        case Uml::ot_Attribute:
+        case Uml::ot_Operation:
+        case Uml::ot_EnumLiteral:
+        case Uml::ot_Template:
+            mt = Uml::mt_Logical;
+            break;
         case Uml::ot_Actor:
         case Uml::ot_UseCase:
             mt = Uml::mt_UseCase;
@@ -330,6 +354,7 @@ Uml::Model_Type guessContainer(UMLObject *o) {
             mt = Uml::mt_Deployment;
             break;
         case Uml::ot_Entity:
+        case Uml::ot_EntityAttribute:
             mt = Uml::mt_EntityRelationship;
             break;
         case Uml::ot_Association:
@@ -340,7 +365,7 @@ Uml::Model_Type guessContainer(UMLObject *o) {
                     UMLObject *roleObj = assoc->getObject((Uml::Role_Type)r);
                     if (roleObj == NULL) {
                         // Ouch! we have been called while types are not yet resolved
-                        break;
+                        return Uml::N_MODELTYPES;
                     }
                     UMLPackage *pkg = roleObj->getUMLPackage();
                     if (pkg) {
@@ -454,19 +479,25 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
     m = m.simplifyWhiteSpace();
     if (m.isEmpty())
         return PS_Empty;
-    /**
-     * The search pattern includes everything until the opening parenthesis
-     * because UML also permits non programming-language oriented designs
-     * using narrative names, for example "check water temperature".
-     */
-    QRegExp pat( "^([^\\(]+)" );
-    int pos = pat.search(m);
-    if (pos == -1)
-        return PS_Illegal_MethodName;
-    desc.m_name = pat.cap(1);
+    if (m.contains(QRegExp("operator *()"))) {
+        // C++ special case: two sets of parentheses
+        desc.m_name = "operator()";
+        m.remove(QRegExp("operator *()"));
+    } else {
+        /**
+         * The search pattern includes everything up to the opening parenthesis
+         * because UML also permits non programming-language oriented designs
+         * using narrative names, for example "check water temperature".
+         */
+        QRegExp beginningUpToOpenParenth( "^([^\\(]+)" );
+        int pos = beginningUpToOpenParenth.search(m);
+        if (pos == -1)
+            return PS_Illegal_MethodName;
+        desc.m_name = beginningUpToOpenParenth.cap(1);
+    }
     desc.m_pReturnType = NULL;
-    pat = QRegExp("\\) *:(.*)$");
-    pos = pat.search(m);
+    QRegExp pat = QRegExp("\\) *:(.*)$");
+    int pos = pat.search(m);
     if (pos != -1) {  // return type is optional
         QString retType = pat.cap(1);
         retType = retType.stripWhiteSpace();
@@ -703,7 +734,7 @@ Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt) {
             mt = Uml::mt_EntityRelationship;
             break;
         default:
-            kdError() << "Model_Utils::convert_DT_MT: illegal input value " << dt << endl;
+            kError() << "Model_Utils::convert_DT_MT: illegal input value " << dt << endl;
             mt = Uml::N_MODELTYPES;
             break;
     }
@@ -798,7 +829,7 @@ Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt) {
         break;
 
     default:
-        kdWarning() << "convert_DT_LVT() called on unknown diagram type" << endl;
+        kWarning() << "convert_DT_LVT() called on unknown diagram type" << endl;
     }
     return type;
 }
@@ -852,7 +883,7 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o) {
                     return type;
                 }
             } while ((f = static_cast<UMLFolder*>(f->getUMLPackage())) != NULL);
-            kdError() << "convert_OT_LVT(" << o->getName()
+            kError() << "convert_OT_LVT(" << o->getName()
                 << "): internal error - object is not properly nested in folder"
                 << endl;
         }
@@ -1059,6 +1090,9 @@ Uml::Icon_Type convert_LVT_IT(Uml::ListView_Type lvt) {
         case Uml::lvt_EntityAttribute:
             icon = Uml::it_Private_Attribute;
             break;
+        case Uml::lvt_EnumLiteral:
+            icon = Uml::it_Public_Attribute;
+            break;
         case Uml::lvt_Operation:
             icon = Uml::it_Public_Method;
             break;
@@ -1133,5 +1167,30 @@ Uml::Diagram_Type convert_LVT_DT(Uml::ListView_Type lvt) {
     return dt;
 }
 
+Uml::Model_Type convert_OT_MT(Uml::Object_Type ot) {
+    Uml::Model_Type mt = Uml::N_MODELTYPES;
+    switch (ot) {
+        case Uml::ot_Actor:
+        case Uml::ot_UseCase:
+            mt = Uml::mt_UseCase;
+            break;
+        case Uml::ot_Component:
+        case Uml::ot_Artifact:
+            mt = Uml::mt_Component;
+            break;
+        case Uml::ot_Node:
+            mt = Uml::mt_Deployment;
+            break;
+        case Uml::ot_Entity:
+        case Uml::ot_EntityAttribute:
+            mt = Uml::mt_EntityRelationship;
+            break;
+        default:
+            mt = Uml::mt_Logical;
+            break;
+    }
+    return mt;
+}
+
 }  // namespace Model_Utils
 
