@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -25,11 +22,12 @@
 #include "classifier.h"
 #include "uml.h"
 #include "umldoc.h"
+#include "uniqueid.h"
 #include "dialogs/umloperationdialog.h"
 
-UMLOperation::UMLOperation(const UMLClassifier *parent, QString Name, Uml::IDType id,
-                           Uml::Visibility s, QString rt)
-        : UMLClassifierListItem(parent, Name, id)
+UMLOperation::UMLOperation(const UMLClassifier *parent, const QString& name,
+                           Uml::IDType id, Uml::Visibility s, const QString& rt)
+        : UMLClassifierListItem(parent, name, id)
 {
     if (!rt.isEmpty())
         setTypeName( rt );
@@ -48,11 +46,11 @@ UMLOperation::UMLOperation(const UMLClassifier * parent)
 UMLOperation::~UMLOperation() {
 }
 
-UMLAttribute * UMLOperation::addParm(QString type, QString name, QString initialValue,
-                                     QString doc, Uml::Parameter_Direction kind) {
+UMLAttribute * UMLOperation::addParm(const QString& type, const QString& name,
+                                     const QString& initialValue, const QString& doc,
+                                     Uml::Parameter_Direction kind) {
     // make the new parameter (attribute) public, just to be safe
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLAttribute * a = new UMLAttribute(this, name, umldoc->getUniqueID(), Uml::Visibility::Public, type);
+    UMLAttribute * a = new UMLAttribute(this, name, UniqueID::gen(), Uml::Visibility::Public, type);
     a -> setDoc(doc);
     a -> setInitialValue(initialValue);
     a -> setParmKind(kind);
@@ -62,16 +60,16 @@ UMLAttribute * UMLOperation::addParm(QString type, QString name, QString initial
 
 void UMLOperation::moveParmLeft(UMLAttribute * a) {
     if (a == NULL) {
-        kdDebug() << "UMLOperation::moveParmLeft called on NULL attribute"
+        kDebug() << "UMLOperation::moveParmLeft called on NULL attribute"
         << endl;
         return;
     }
-    kdDebug() << "UMLOperation::moveParmLeft(" << a->getName() << ") called"
+    kDebug() << "UMLOperation::moveParmLeft(" << a->getName() << ") called"
     << endl;
     disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
     int idx;
     if ( (idx=m_List.find( a )) == -1 ) {
-        kdDebug() << "Error move parm left " << a->getName() << endl;
+        kDebug() << "Error move parm left " << a->getName() << endl;
         return;
     }
     if ( idx == 0 )
@@ -82,16 +80,16 @@ void UMLOperation::moveParmLeft(UMLAttribute * a) {
 
 void UMLOperation::moveParmRight(UMLAttribute * a) {
     if (a == NULL) {
-        kdDebug() << "UMLOperation::moveParmRight called on NULL attribute"
+        kDebug() << "UMLOperation::moveParmRight called on NULL attribute"
         << endl;
         return;
     }
-    kdDebug() << "UMLOperation::moveParmRight(" << a->getName() << ") called"
+    kDebug() << "UMLOperation::moveParmRight(" << a->getName() << ") called"
     << endl;
     disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
     int idx;
     if ( (idx=m_List.find( a )) == -1 ) {
-        kdDebug() << "Error move parm right " << a->getName() << endl;
+        kDebug() << "Error move parm right " << a->getName() << endl;
         return;
     }
     int count = m_List.count();
@@ -101,19 +99,20 @@ void UMLOperation::moveParmRight(UMLAttribute * a) {
     m_List.insert( idx+1, a );
 }
 
-void UMLOperation::removeParm(UMLAttribute * a) {
+void UMLOperation::removeParm(UMLAttribute * a, bool emitModifiedSignal /* =true */) {
     if (a == NULL) {
-        kdDebug() << "UMLOperation::removeParm called on NULL attribute"
+        kDebug() << "UMLOperation::removeParm called on NULL attribute"
         << endl;
         return;
     }
-    kdDebug() << "UMLOperation::removeParm(" << a->getName() << ") called"
+    kDebug() << "UMLOperation::removeParm(" << a->getName() << ") called"
     << endl;
     disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
     if(!m_List.remove(a))
-        kdDebug() << "Error removing parm " << a->getName() << endl;
+        kDebug() << "Error removing parm " << a->getName() << endl;
 
-    emit modified();
+    if (emitModifiedSignal)
+        emit modified();
 }
 
 UMLAttribute* UMLOperation::findParm(const QString &name) {
@@ -129,27 +128,31 @@ QString UMLOperation::toString(Uml::Signature_Type sig) {
     QString s = "";
 
     if(sig == Uml::st_ShowSig || sig == Uml::st_NoSig) 
-          s = m_Vis.toString(true) + " ";
+          s = m_Vis.toString(true) + ' ';
     
     s += getName();
-    if (!s.contains("("))
-        s.append("(");
+    Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
+    bool parameterlessOpNeedsParentheses = (pl != Uml::pl_Pascal && pl != Uml::pl_Ada);
 
-    if(sig == Uml::st_NoSig || sig == Uml::st_NoSigNoVis) {
-        if (!s.contains(")"))
-            s.append(")");
+    if (sig == Uml::st_NoSig || sig == Uml::st_NoSigNoVis) {
+        if (parameterlessOpNeedsParentheses)
+            s.append("()");
         return s;
     }
-    UMLAttribute * obj=0;
-    int last = m_List.count(), i = 0;
-    for(obj=m_List.first();obj != 0;obj=m_List.next()) {
-        i++;
-        s.append(obj -> toString(Uml::st_SigNoVis));
-        if(i < last)
-            s.append(", ");
-    }
-    if (!s.contains(")"))
+    int last = m_List.count();
+    if (last) {
+        s.append("(");
+        int i = 0;
+        for (UMLAttribute *param = m_List.first(); param; param = m_List.next()) {
+            i++;
+            s.append(param->toString(Uml::st_SigNoVis));
+            if (i < last)
+                s.append(", ");
+        }
         s.append(")");
+    } else if (parameterlessOpNeedsParentheses) {
+        s.append("()");
+    }
     UMLClassifier *ownParent = static_cast<UMLClassifier*>(parent());
     QString returnType;
     UMLClassifier *retType = UMLClassifierListItem::getType();
@@ -185,7 +188,7 @@ QString UMLOperation::getUniqueParameterName() {
     QString currentName = i18n("new_parameter");
     QString name = currentName;
     for (int number = 1; findParm(name); number++) {
-        name = currentName + "_" + QString::number(number);
+        name = currentName + '_' + QString::number(number);
     }
     return name;
 }
@@ -279,7 +282,7 @@ bool UMLOperation::getConst() const {
     return m_bConst;
 }
 
-bool UMLOperation::showPropertiesDialogue(QWidget* parent) {
+bool UMLOperation::showPropertiesDialog(QWidget* parent) {
     UMLOperationDialog dialog(parent, this);
     return dialog.exec();
 }
@@ -290,13 +293,12 @@ void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
     QDomElement featureElement = qDoc.createElement( "UML:BehavioralFeature.parameter" );
     if (m_pSecondary) {
         QDomElement retElement = qDoc.createElement("UML:Parameter");
-        UMLDoc *pDoc = UMLApp::app()->getDocument();
-        retElement.setAttribute( "xmi.id", ID2STR(pDoc->getUniqueID()) );
+        retElement.setAttribute( "xmi.id", ID2STR(UniqueID::gen()) );
         retElement.setAttribute( "type", ID2STR(m_pSecondary->getID()) );
         retElement.setAttribute( "kind", "return" );
         featureElement.appendChild( retElement );
     } else {
-        kdDebug() << "UMLOperation::saveToXMI: m_SecondaryId is "
+        kDebug() << "UMLOperation::saveToXMI: m_SecondaryId is "
         << m_SecondaryId << endl;
     }
     //save each attribute here, type different
@@ -326,19 +328,7 @@ void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
 }
 
 bool UMLOperation::load( QDomElement & element ) {
-    QString type = element.attribute( "type", "" );
-    if (!type.isEmpty()) {
-        if (type.contains( QRegExp("\\D") )) {
-            m_SecondaryId = type;  // defer type resolution
-        } else {
-            UMLDoc *pDoc = UMLApp::app()->getDocument();
-            m_pSecondary = pDoc->findObjectById( STR2ID(type) );
-            if (m_pSecondary == NULL) {
-                kdError() << "UMLOperation::load: Cannot find UML object"
-                << " for return type " << type << endl;
-            }
-        }
-    }
+    m_SecondaryId = element.attribute( "type", "" );
     QString isQuery = element.attribute( "isQuery", "" );
     if (!isQuery.isEmpty()) {
         // We need this extra test for isEmpty() because load() might have been
@@ -369,7 +359,7 @@ bool UMLOperation::load( QDomElement & element ) {
                     break;
                 }
                 if (kind.isEmpty()) {
-                    // kdDebug() << "UMLOperation::load(" << m_Name << "): "
+                    // kDebug() << "UMLOperation::load(" << m_Name << "): "
                     //  << "cannot find kind, using default \"in\"." << endl;
                     kind = "in";
                 }
@@ -403,9 +393,8 @@ bool UMLOperation::load( QDomElement & element ) {
                         break;
                     }
                     if (m_SecondaryId.isEmpty()) {
-                        kdError() << "UMLOperation::load(" << m_Name << "): "
+                        kError() << "UMLOperation::load(" << m_Name << "): "
                         << "cannot find return type." << endl;
-                        return false;
                     }
                 }
                 // Use deferred xmi.id resolution.
@@ -422,12 +411,6 @@ bool UMLOperation::load( QDomElement & element ) {
                     pAtt->setParmKind(Uml::pd_InOut);
                 else
                     pAtt->setParmKind(Uml::pd_In);
-                Uml::IDType id = pAtt->getID();
-                if (ID2STR(id).contains( QRegExp("\\D") )) {
-                    UMLDoc *pDoc = UMLApp::app()->getDocument();
-                    (void) pDoc->getUniqueID();
-                    // This counts up UMLDoc::m_HighestIDForForeignFile.
-                }
                 m_List.append( pAtt );
             }
         }
