@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef OPERATION_H
@@ -40,8 +37,10 @@ public:
      * @param s         The visibility of the operation.
      * @param rt        The return type of the operation.
      */
-    UMLOperation(const UMLClassifier * parent, QString Name, Uml::IDType id = Uml::id_None,
-                 Uml::Visibility s = Uml::Visibility::Public, QString rt = QString::null);
+    UMLOperation(const UMLClassifier * parent, const QString& name,
+                 Uml::IDType id = Uml::id_None,
+                 Uml::Visibility s = Uml::Visibility::Public,
+                 const QString& rt = QString::null);
 
     /**
      * Constructs an UMLOperation.
@@ -85,7 +84,8 @@ public:
      *                      Default is "in".
      * @return  Pointer to the UMLAttribute created.
      */
-    UMLAttribute * addParm(QString type, QString name, QString initialValue, QString doc,
+    UMLAttribute * addParm(const QString& type, const QString& name,
+                           const QString& initialValue, const QString& doc,
                            Uml::Parameter_Direction kind = Uml::pd_In);
 
     /**
@@ -106,16 +106,19 @@ public:
      * Remove a parameter from the operation.
      *
      * @param a         The parameter to remove.
+     * @param emitModifiedSignal  Whether to emit the "modified" signal
+     *                  which creates an entry in the Undo stack for the
+     *                  removal. Default: true.
      */
-    void removeParm(UMLAttribute *a);
+    void removeParm(UMLAttribute *a, bool emitModifiedSignal = true);
 
     /**
      * Returns a list of parameters.
      *
      * @return A list of the parameters in the operation.
      */
-    UMLAttributeList* getParmList() {
-        return &m_List;
+    UMLAttributeList getParmList() {
+        return m_List;
     }
 
     /**
@@ -160,7 +163,7 @@ public:
     /**
      * Display the properties configuration dialog for the template.
      */
-    bool showPropertiesDialogue(QWidget* parent);
+    bool showPropertiesDialog(QWidget* parent);
 
     /**
      * Returns whether this operation is a constructor.
