@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006                                                     *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2006-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -37,9 +37,10 @@ namespace Import_Rose {
  * Return the given string without surrounding quotation marks.
  * Also remove a possible prefix "Logical View::", it is not modeled in Umbrello.
  */
-QString clean(QString str) {
-    if (str.isNull())
-        return QString::null;
+QString clean(const QString& s) {
+    if (s.isNull())
+        return QString();
+    QString str = s;
     str.remove("\"");
     str.remove(QRegExp("^Logical View::"));
     return str;
@@ -62,7 +63,7 @@ Uml::IDType quid(const PetalNode *node) {
 QString quidu(const PetalNode *node) {
     QString quiduStr = node->findAttribute("quidu").string;
     if (quiduStr.isEmpty())
-        return QString::null;
+        return QString();
     quiduStr.remove("\"");
     return quiduStr;
 }
@@ -72,9 +73,10 @@ QString quidu(const PetalNode *node) {
  * If the given name consists only of letters, digits, underscores, and
  * scope separators, then return Uml::ot_Class, else return Uml::ot_Datatype.
  */
-Uml::Object_Type typeToCreate(QString name) {
-    name.remove(QRegExp("^.*::"));  // don't consider the scope prefix, it may contain spaces
-    Uml::Object_Type t = (name.contains(QRegExp("\\W")) ? Uml::ot_Datatype : Uml::ot_Class);
+Uml::Object_Type typeToCreate(const QString& name) {
+    QString n = name;
+    n.remove(QRegExp("^.*::"));  // don't consider the scope prefix, it may contain spaces
+    Uml::Object_Type t = (n.contains(QRegExp("\\W")) ? Uml::ot_Datatype : Uml::ot_Class);
     return t;
 }
 
@@ -86,7 +88,7 @@ Uml::Object_Type typeToCreate(QString name) {
  */
 void transferVisibility(const PetalNode *from, UMLObject *to) {
     QString vis = from->findAttribute("exportControl").string;
-    if (vis != QString::null) {
+    if (!vis.isEmpty()) {
         Uml::Visibility v = Uml::Visibility::fromString(clean(vis.lower()));
         to->setVisibility(v);
     }
@@ -115,7 +117,8 @@ public:
      */
     virtual UMLObject *createListItem() = 0;
 
-    virtual void setTypeReferences(UMLObject *item, QString quid, QString type) {
+    virtual void setTypeReferences(UMLObject *item,
+                                   const QString& quid, const QString& type) {
         if (!quid.isEmpty()) {
             item->setSecondaryId(quid);
         }
@@ -144,11 +147,11 @@ public:
      *   - invoke insertAtParent() with the new classifier list item as the argument
      * This is the user entry point.
      */
-    void read(const PetalNode *node, QString name) {
+    void read(const PetalNode *node, const QString& name) {
         PetalNode *attributes = node->findAttribute(m_attributeTag).node;
         if (attributes == NULL) {
 #ifdef VERBOSE_DEBUGGING
-            kdDebug() << "read(" << name << "): no " << m_attributeTag << " found"
+            kDebug() << "read(" << name << "): no " << m_attributeTag << " found"
                       << endl;
 #endif
             return;
@@ -158,7 +161,7 @@ public:
             PetalNode *attNode = attributeList[i].second.node;
             QStringList initialArgs = attNode->initialArgs();
             if (attNode->name() != m_elementName) {
-                kdDebug() << "read(" << name << "): expecting " << m_elementName
+                kDebug() << "read(" << name << "): expecting " << m_elementName
                           << ", " << "found " << initialArgs[0] << endl;
                 continue;
             }
@@ -248,7 +251,8 @@ public:
      * Override parent implementation: The secondary data is not for the
      * UMLAssociation itself but for its role B object.
      */
-    void setTypeReferences(UMLObject *item, QString quid, QString type) {
+    void setTypeReferences(UMLObject *item,
+                           const QString& quid, const QString& type) {
         UMLAssociation *assoc = static_cast<UMLAssociation*>(item);
         if (!quid.isEmpty()) {
             assoc->getUMLRole(Uml::B)->setSecondaryId(quid);
@@ -280,7 +284,8 @@ public:
      * Override parent implementation: The secondary data is not for the
      * UMLAssociation itself but for its role B object.
      */
-    void setTypeReferences(UMLObject *item, QString quid, QString type) {
+    void setTypeReferences(UMLObject *item,
+                           const QString& quid, const QString& type) {
         UMLAssociation *assoc = static_cast<UMLAssociation*>(item);
         if (!quid.isEmpty()) {
             assoc->getUMLRole(Uml::B)->setSecondaryId(quid);
@@ -307,7 +312,7 @@ protected:
  */
 bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
     if (node == NULL) {
-        kdError() << "umbrellify: node is NULL" << endl;
+        kError() << "umbrellify: node is NULL" << endl;
         return false;
     }
     QStringList args = node->initialArgs();
@@ -320,7 +325,7 @@ bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
         o->setID(id);
         PetalNode *logical_models = node->findAttribute("logical_models").node;
         if (logical_models == NULL) {
-            kdError() << "umbrellify: cannot find logical_models" << endl;
+            kError() << "umbrellify: cannot find logical_models" << endl;
             return false;
         }
         UMLPackage *localParent = static_cast<UMLPackage*>(o);
@@ -337,7 +342,7 @@ bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
         QString stereotype = clean(node->findAttribute("stereotype").string);
         if (!stereotype.isEmpty()) {
             if (stereotype.lower() == "interface")
-                c->setInterface();
+                c->setBaseType(Uml::ot_Interface);
             else
                 c->setStereotype(stereotype);
         }
@@ -357,7 +362,7 @@ bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
     } else if (objType == "Association") {
         PetalNode *roles = node->findAttribute("roles").node;
         if (node == NULL) {
-            kdError() << "umbrellify: cannot find roles of Association" << endl;
+            kError() << "umbrellify: cannot find roles of Association" << endl;
             return false;
         }
         UMLAssociation *assoc = new UMLAssociation(Uml::at_UniAssociation);
@@ -387,11 +392,11 @@ bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
         for (uint i = 0; i <= 1; i++) {
             PetalNode *roleNode = roleList[i].second.node;
             if (roleNode == NULL) {
-                kdError() << "umbrellify: roleNode of Association is NULL" << endl;
+                kError() << "umbrellify: roleNode of Association is NULL" << endl;
                 return false;
             }
             if (roleNode->name() != "Role") {
-                kdDebug() << "umbrellify(" << name << "): expecting Role, found \""
+                kDebug() << "umbrellify(" << name << "): expecting Role, found \""
                           << roleNode->name() << endl;
                 continue;
             }
@@ -440,7 +445,7 @@ bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
         UMLApp::app()->getDocument()->addAssociation(assoc);
 
     } else {
-        kdDebug() << "umbrellify: object type " << objType
+        kDebug() << "umbrellify: object type " << objType
                   << " is not yet implemented" << endl;
     }
     return true;
@@ -479,9 +484,9 @@ Uml::ListView_Type folderType(UMLListViewItem *parent) {
  *           Given a PetalNode for which the mapping to Umbrello is not yet
  *           implemented umbrellify() is a no-op but also returns true.
  */
-bool umbrellify(PetalNode *node, QString modelsName, UMLListViewItem *parent) {
+bool umbrellify(PetalNode *node, const QString& modelsName, UMLListViewItem *parent) {
     if (node == NULL) {
-        kdError() << "umbrellify: node is NULL" << endl;
+        kError() << "umbrellify: node is NULL" << endl;
         return false;
     }
     QStringList args = node->initialArgs();
@@ -508,7 +513,7 @@ bool umbrellify(PetalNode *node, QString modelsName, UMLListViewItem *parent) {
         item = new UMLListViewItem(parent, name, Uml::lvt_Node, un);
         obj = un;
     } else {
-        kdDebug() << "umbrellify: object type " << objType
+        kDebug() << "umbrellify: object type " << objType
                   << " is not yet implemented" << endl;
         return true;
     }
@@ -533,16 +538,16 @@ bool umbrellify(PetalNode *node, QString modelsName, UMLListViewItem *parent) {
 /**
  * Auxiliary function for UseCase/Component/Deployment view import
  */
-bool importView(PetalNode *root, QString rootName, QString modelsName,
-                UMLListViewItem *lvParent) {
+bool importView(PetalNode *root, const QString& rootName,
+                const QString& modelsName, UMLListViewItem *lvParent) {
     PetalNode *viewRoot = root->findAttribute(rootName).node;
     if (viewRoot == NULL) {
-        kdDebug() << "importView: cannot find " << rootName << endl;
+        kDebug() << "importView: cannot find " << rootName << endl;
         return false;
     }
     PetalNode *models = viewRoot->findAttribute(modelsName).node;
     if (models == NULL) {
-        kdError() << "importView: cannot find " << modelsName
+        kError() << "importView: cannot find " << modelsName
                   << " of " << rootName << endl;
         return false;
     }
@@ -555,31 +560,31 @@ bool importView(PetalNode *root, QString rootName, QString modelsName,
 
 bool petalTree2Uml(PetalNode *root) {
     if (root == NULL) {
-        kdError() << "petalTree2Uml: root is NULL" << endl;
+        kError() << "petalTree2Uml: root is NULL" << endl;
         return false;
     }
     if (root->name() != "Design") {
-        kdError() << "petalTree2Uml: expecting root name Design" << endl;
+        kError() << "petalTree2Uml: expecting root name Design" << endl;
         return false;
     }
     /*************************** import  Logical View ********************************/
     PetalNode *root_category = root->findAttribute("root_category").node;
     if (root_category == NULL) {
-        kdError() << "petalTree2Uml: cannot find root_category" << endl;
+        kError() << "petalTree2Uml: cannot find root_category" << endl;
         return false;
     }
     if (root_category->name() != "Class_Category") {
-        kdError() << "petalTree2Uml: expecting root_category object Class_Category"
+        kError() << "petalTree2Uml: expecting root_category object Class_Category"
                   << endl;
         return false;
     }
     PetalNode *logical_models = root_category->findAttribute("logical_models").node;
     if (logical_models == NULL) {
-        kdError() << "petalTree2Uml: cannot find logical_models" << endl;
+        kError() << "petalTree2Uml: cannot find logical_models" << endl;
         return false;
     }
     UMLDoc *umldoc = UMLApp::app()->getDocument();
-    umldoc->determineNativity("Certainly Not Native At All");
+    umldoc->setCurrentRoot(Uml::mt_Logical);
     Import_Utils::assignUniqueIdOnCreation(false);
     PetalNode::NameValueList atts = logical_models->attributes();
     for (uint i = 0; i < atts.count(); i++) {
@@ -590,15 +595,19 @@ bool petalTree2Uml(PetalNode *root) {
     UMLListView *lv = UMLApp::app()->getListView();
 
     /*************************** import Use Case View ********************************/
+    umldoc->setCurrentRoot(Uml::mt_UseCase);
     importView(root, "root_usecase_package", "logical_models", lv->theUseCaseView());
 
     /*************************** import Component View *******************************/
+    umldoc->setCurrentRoot(Uml::mt_Component);
     importView(root, "root_subsystem", "physical_models", lv->theComponentView());
 
     /*************************** import Deployment View ******************************/
+    umldoc->setCurrentRoot(Uml::mt_Deployment);
     importView(root, "process_structure", "ProcsNDevs", lv->theDeploymentView());
 
     /***************************       wrap up        ********************************/
+    umldoc->setCurrentRoot(Uml::mt_Logical);
     Import_Utils::assignUniqueIdOnCreation(true);
     umldoc->resolveTypes();
     return true;
