@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -18,12 +18,12 @@
 // kde includes
 #include <klocale.h>
 #include <kdebug.h>
+#include <kinputdialog.h>
 
 // app includes
 #include "uml.h"
 #include "umldoc.h"
 #include "docwindow.h"
-#include "inputdialog.h"
 #include "umlwidget.h"
 #include "umlview.h"
 #include "dialogs/statedialog.h"
@@ -103,7 +103,7 @@ void StateWidget::draw(QPainter & p, int offsetX, int offsetY) {
         p.drawEllipse( offsetX + 3, offsetY + 3, w - 6, h - 6 );
         break;
     default:
-        kdWarning() << "Unknown state type:" << m_StateType << endl;
+        kWarning() << "Unknown state type:" << m_StateType << endl;
         break;
     }
     if(m_bSelected)
