@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLLISTVIEW_H
@@ -45,51 +45,6 @@ class UMLListView : public KListView {
     Q_OBJECT
 public:
 
-    enum Icon_Type      {
-        it_Home = 0,
-        it_Folder_Cyan,
-        it_Folder_Cyan_Open,
-        it_Folder_Green,
-        it_Folder_Green_Open,
-        it_Folder_Grey,
-        it_Folder_Grey_Open,
-        it_Folder_Red,
-        it_Folder_Red_Open,
-        it_Folder_Violet,
-        it_Folder_Violet_Open,
-        it_Folder_Orange,
-        it_Folder_Orange_Open,
-        it_Diagram, //change to have different one for each type of diagram
-        it_Class,
-        it_Template,
-        it_Package,
-        it_Subsystem,
-        it_Component,
-        it_Node,
-        it_Artifact,
-        it_Interface,
-        it_Datatype,
-        it_Enum,
-        it_Entity,
-        it_Actor,
-        it_UseCase,
-        it_Public_Method,
-        it_Private_Method,
-        it_Protected_Method,
-        it_Public_Attribute,
-        it_Private_Attribute,
-        it_Protected_Attribute,
-        it_Diagram_Activity,
-        it_Diagram_Class,
-        it_Diagram_Collaboration,
-        it_Diagram_Component,
-        it_Diagram_Deployment,
-        it_Diagram_EntityRelationship,
-        it_Diagram_Sequence,
-        it_Diagram_State,
-        it_Diagram_Usecase
-    };
-
     /**
      * Constructs the tree view.
      *
@@ -156,6 +111,20 @@ public:
     UMLListViewItem* createItem(UMLListViewItem& Data, IDChangeLog& IDChanges,
                                 UMLListViewItem* parent = 0);
 
+    /**
+     * Find the parent folder for a diagram.
+     * If the currently selected item in the list view is a folder
+     * then that folder is returned as the parent.
+     *
+     * @param dt   The Diagram_Type of the diagram.
+     *             The type will only be used if there is no currently
+     *             selected item, or if the current item is not a folder.
+     *             In that case the root folder which is suitable for the
+     *             Diagram_Type is returned.
+     * @return  Pointer to the parent UMLListViewItem for the diagram.
+     */
+    UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
+
     /**
      * Determine the parent ListViewItem given an UMLObject.
      *
@@ -189,7 +158,7 @@ public:
     /**
      * Returns the correct pixmap for the given type.
      */
-    QPixmap & getPixmap( Icon_Type type );
+    QPixmap & getPixmap( Uml::Icon_Type type );
 
     /**
      * Returns the document pointer.  Called by the UMLListViewItem class.
@@ -203,7 +172,7 @@ public:
      * Method will take care of signalling anyone needed on creation of new item.
      * e.g. UMLDoc if an UMLObject is created.
      */
-    void addNewItem( QListViewItem * parent, Uml::ListView_Type type );
+    void addNewItem(UMLListViewItem * parent, Uml::ListView_Type type);
 
     /**
      * Find an UMLObject in the listview.
@@ -211,7 +180,14 @@ public:
      * @param p         Pointer to the object to find in the list view.
      * @return  Pointer to the UMLObject found or NULL if not found.
      */
-    UMLListViewItem * findUMLObject(UMLObject *p) const;
+    UMLListViewItem * findUMLObject(const UMLObject *p) const;
+
+    /**
+     * Searches through the tree for the item which represents the diagram given
+     * @param the diagram to search for
+     * @return the item which represents the diagram
+     */
+    UMLListViewItem * findView(UMLView *v);
 
     /**
      * Searches through the tree for the item with the given ID.
@@ -227,30 +203,10 @@ public:
      */
     UMLListViewItem *rootView(Uml::ListView_Type type);
 
-    /**
-     * Returns true if the listview type also has a widget representation in diagrams.
-     */
-    static bool typeIsCanvasWidget(Uml::ListView_Type type);
-
-    /**
-     * Returns true if the listview type is a logical, usecase or component folder.
-     */
-    static bool typeIsFolder(Uml::ListView_Type type);
-
-    /**
-     * Returns true if the listview type is a diagram.
-     */
-    static bool typeIsDiagram(Uml::ListView_Type type);
-
-    /**
-     * Returns true if the listview type is an attribute, operation, or template.
-     */
-    static bool typeIsClassifierList(Uml::ListView_Type type);
-
     /**
      * Changes the icon for the given UMLObject to the given icon.
      */
-    void changeIconOf(UMLObject *o, Icon_Type to);
+    void changeIconOf(UMLObject *o, Uml::Icon_Type to);
 
     /**
      * Creates a UMLObject out of the given list view item.
@@ -301,11 +257,6 @@ public:
      */
     bool startedCopy() const;
 
-    /**
-     * Converts an object type enum to the equivalent list view type
-     */
-    static Uml::ListView_Type convert_OT_LVT(Uml::Object_Type ot);
-
     /**
      * Moves an object given is unique ID and listview type to an
      * other listview parent item.
@@ -322,25 +273,32 @@ public:
     void closeDatatypesFolder();
 
     UMLListViewItem *theRootView() { return m_rv; }
-    UMLListViewItem *theLogicalView() { return m_lv; }
-    UMLListViewItem *theUseCaseView() { return m_ucv; }
-    UMLListViewItem *theComponentView() { return m_cmpv; }
-    UMLListViewItem *theDeploymentView() { return m_dplv; }
+    UMLListViewItem *theLogicalView() { return m_lv[Uml::mt_Logical]; }
+    UMLListViewItem *theUseCaseView() { return m_lv[Uml::mt_UseCase]; }
+    UMLListViewItem *theComponentView() { return m_lv[Uml::mt_Component]; }
+    UMLListViewItem *theDeploymentView() { return m_lv[Uml::mt_Deployment]; }
+    UMLListViewItem *theDatatypeFolder() { return m_datatypeFolder; }
 
-    void saveToXMI( QDomDocument & qDoc, QDomElement & qElement,
-                    bool saveSubmodelFiles = false );
+    /**
+     * Determines the root listview type of the given UMLListViewItem.
+     * Starts at the given item, compares it against each of the
+     * predefined root views (Root, Logical, UseCase, Component,
+     * Deployment, EntityRelationship.) Returns the ListView_Type
+     * of the matching root view; if no match then continues the
+     * search using the item's parent, then grandparent, and so forth.
+     * Returns Uml::lvt_Unknown if no match at all is found.
+     */
+    Uml::ListView_Type rootViewType(UMLListViewItem *item);
+
+    void saveToXMI( QDomDocument & qDoc, QDomElement & qElement);
 
     bool loadFromXMI( QDomElement & element );
 
     bool loadChildrenFromXMI( UMLListViewItem * parent, QDomElement & element );
 
 protected:
-    UMLListViewItem* m_rv;    // root view
-    UMLListViewItem* m_ucv;   // use case view item
-    UMLListViewItem* m_lv;    // logical view item
-    UMLListViewItem* m_cmpv;  // component view item
-    UMLListViewItem* m_dplv;  // deployment view item
-    UMLListViewItem* m_entityRelationshipModel;//entity relationship view item
+    UMLListViewItem* m_rv;    // root view (home)
+    UMLListViewItem* m_lv[Uml::N_MODELTYPES];    // predefined list view roots
     UMLListViewItem* m_datatypeFolder;
     ListPopupMenu * m_pMenu;
     QString oldText, message;
@@ -352,51 +310,7 @@ protected:
      */
     bool m_bCreatingChildObject;
 
-    struct Pixmaps {
-        QPixmap Home;
-        QPixmap Folder_Cyan;
-        QPixmap Folder_Cyan_Open;
-        QPixmap Folder_Green;
-        QPixmap Folder_Green_Open;
-        QPixmap Folder_Grey;
-        QPixmap Folder_Grey_Open;
-        QPixmap Folder_Orange;
-        QPixmap Folder_Orange_Open;
-        QPixmap Folder_Red;
-        QPixmap Folder_Red_Open;
-        QPixmap Folder_Violet;
-        QPixmap Folder_Violet_Open;
-        QPixmap Diagram; //change to have different one for each type of diagram
-        QPixmap Class;
-        QPixmap Template;
-        QPixmap Package;
-        QPixmap Subsystem;
-        QPixmap Component;
-        QPixmap Node;
-        QPixmap Artifact;
-        QPixmap Interface;
-        QPixmap Datatype;
-        QPixmap Enum;
-        QPixmap Entity;
-        QPixmap Actor;
-        QPixmap UseCase;
-        QPixmap Public_Method;
-        QPixmap Private_Method;
-        QPixmap Protected_Method;
-        QPixmap Public_Attribute;
-        QPixmap Private_Attribute;
-        QPixmap Protected_Attribute;
-        QPixmap Diagram_Activity;
-        QPixmap Diagram_Class;
-        QPixmap Diagram_Collaboration;
-        QPixmap Diagram_Component;
-        QPixmap Diagram_Deployment;
-        QPixmap Diagram_EntityRelationship;
-        QPixmap Diagram_Sequence;
-        QPixmap Diagram_State;
-        QPixmap Diagram_Usecase;
-    }
-    m_Pixmaps;
+    QPixmap m_Pixmaps[Uml::N_ICONTYPES];
 
     bool eventFilter(QObject *o, QEvent *e);
     void contentsMouseReleaseEvent(QMouseEvent * me);
@@ -418,25 +332,9 @@ protected:
     UMLListViewItem * findUMLObjectInFolder(UMLListViewItem *item, UMLObject *o);
 
     /**
-     * Searches through the tree for the item which represents the diagram given
-     * @param the diagram to search for
-     * @return the item which represents the diagram
+     * Return true if the given list view type can be expanded/collapsed.
      */
-    UMLListViewItem * findView(UMLView *v);
-
-    /**
-     * Utility: Converts a diagram type enum to the equivalent list view type
-     */
-    static Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt);
-
-    /**
-     * Converts a list view type enum to the equivalent object type.
-     *
-     * @param lvt               The ListView_Type to convert.
-     * @return  The converted Object_Type if the listview type
-     *          has a Object_Type representation, else 0.
-     */
-    static Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt);
+    static bool isExpandable(Uml::ListView_Type lvt);
 
     /**
      *  Loads the pixmaps to use in the list items.
@@ -464,6 +362,13 @@ protected:
      */
     void childObjectAdded(UMLClassifierListItem* child, UMLClassifier* parent);
 
+    /**
+     * Auxiliary method for moveObject(): Adds the model object at the proper
+     * new container (package if nested, UMLDoc if at global level), and
+     * updates the containment relationships in the model.
+     */
+    void addAtContainer(UMLListViewItem *item, UMLListViewItem *parent);
+
 public slots:
 
     /**
@@ -555,13 +460,6 @@ public slots:
      */
     void slotCutSuccessful();
 
-signals:
-
-    /**
-     * change the current view
-     */
-    void diagramSelected(Uml::IDType);
-
 private:
     /**
      * Searches the tree for a diagram (view).
