@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // system includes
@@ -54,7 +54,7 @@ UMLListViewItem::UMLListViewItem(UMLListView * parent)
         : QListViewItem(parent) {
     init(parent);
     if (parent == NULL)
-        kdDebug() << "UMLListViewItem constructor called with a NULL listview parent" << endl;
+        kDebug() << "UMLListViewItem constructor called with a NULL listview parent" << endl;
 }
 
 UMLListViewItem::UMLListViewItem(UMLListViewItem * parent)
@@ -132,7 +132,7 @@ void UMLListViewItem::init(UMLListView * parent) {
     m_nId = Uml::id_None;
     m_nChildren = 0;
     if (s_pListView == NULL && parent != NULL) {
-        kdDebug() << "UMLListViewItem::init: s_pListView still NULL, setting it now "
+        kDebug() << "UMLListViewItem::init: s_pListView still NULL, setting it now "
                   << endl;
         s_pListView = parent;
     }
@@ -149,7 +149,7 @@ void UMLListViewItem::addClassifierListItem(UMLClassifierListItem *child, UMLLis
 void UMLListViewItem::deleteChildItem(UMLClassifierListItem *child) {
     UMLListViewItem *childItem = findChildObject(child);
     if (childItem == NULL) {
-        kdError() << "UMLListViewItem::deleteChildItem(" << child->getName()
+        kError() << "UMLListViewItem::deleteChildItem(" << child->getName()
                   << "): child listview item not found" << endl;
         return;
     }
@@ -167,7 +167,7 @@ void UMLListViewItem::setID(Uml::IDType id) {
     if (m_pObject) {
         Uml::IDType oid = m_pObject->getID();
         if (id != Uml::id_None && oid != id)
-            kdDebug() << "UMLListViewItem::setID: new id " << ID2STR(id)
+            kDebug() << "UMLListViewItem::setID: new id " << ID2STR(id)
                 << " does not agree with object id " << ID2STR(oid) << endl;
     }
     m_nId = id;
@@ -176,7 +176,7 @@ void UMLListViewItem::setID(Uml::IDType id) {
 bool UMLListViewItem::isOwnParent(Uml::IDType listViewItemID) {
     QListViewItem *lvi = (QListViewItem*)s_pListView->findItem(listViewItemID);
     if (lvi == NULL) {
-        kdError() << "UMLListViewItem::isOwnParent: ListView->findItem("
+        kError() << "UMLListViewItem::isOwnParent: ListView->findItem("
             << ID2STR(listViewItemID) << ") returns NULL" << endl;
         return true;
     }
@@ -335,20 +335,21 @@ void UMLListViewItem::okRename( int col ) {
                 // TODO: Check that no operation with the exact same profile exists.
                 op->setName( od.m_name );
                 op->setType( od.m_pReturnType );
-                UMLAttributeList* parmList = op->getParmList();
-                unsigned i = 0;
-                if (parmList->count() > od.m_args.count()) {
-                    for (i = od.m_args.count(); i < parmList->count(); i++) {
-                        parmList->remove(i);
+                UMLAttributeList parmList = op->getParmList();
+                const unsigned newParmListCount = parmList.count();
+                if (newParmListCount > od.m_args.count()) {
+                    // Remove parameters at end of of list that no longer exist.
+                    for (unsigned i = od.m_args.count(); i < newParmListCount; i++) {
+                        UMLAttribute *a = parmList.at(i);
+                        op->removeParm(a, false);
                     }
-                    i = 0;
                 }
-                for (Model_Utils::NameAndType_ListIt lit = od.m_args.begin();
-                        lit != od.m_args.end(); ++lit, ++i) {
+                Model_Utils::NameAndType_ListIt lit = od.m_args.begin();
+                for (unsigned i = 0; lit != od.m_args.end(); ++lit, ++i) {
                     const Model_Utils::NameAndType& nm_tp = *lit;
                     UMLAttribute *a;
-                    if (i < parmList->count()) {
-                        a = parmList->at(i);
+                    if (i < newParmListCount) {
+                        a = parmList.at(i);
                     } else {
                         a = new UMLAttribute(op);
                         a->setID( UniqueID::gen() );
@@ -357,7 +358,7 @@ void UMLListViewItem::okRename( int col ) {
                     a->setType(nm_tp.m_type);
                     a->setParmKind(nm_tp.m_direction);
                     a->setInitialValue(nm_tp.m_initialValue);
-                    if (i >= parmList->count()) {
+                    if (i >= newParmListCount) {
                         op->addParm(a);
                     }
                 }
@@ -503,14 +504,14 @@ int UMLListViewItem::compare(QListViewItem *other, int col, bool ascending) cons
     if (m_pObject == NULL) {
         retval = (subItem ? 1 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (m_pObject==NULL)" << endl;
+        kDebug() << dbgPfx << retval << " because (m_pObject==NULL)" << endl;
 #endif
         return retval;
     }
     if (otherObj == NULL) {
         retval = (subItem ? -1 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (otherObj==NULL)" << endl;
+        kDebug() << dbgPfx << retval << " because (otherObj==NULL)" << endl;
 #endif
         return retval;
     }
@@ -519,21 +520,21 @@ int UMLListViewItem::compare(QListViewItem *other, int col, bool ascending) cons
     if (ourParent == NULL) {
         retval = (subItem ? 1 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (ourParent==NULL)" << endl;
+        kDebug() << dbgPfx << retval << " because (ourParent==NULL)" << endl;
 #endif
         return retval;
     }
     if (otherParent == NULL) {
         retval = (subItem ? -1 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (otherParent==NULL)" << endl;
+        kDebug() << dbgPfx << retval << " because (otherParent==NULL)" << endl;
 #endif
         return retval;
     }
     if (ourParent != otherParent) {
         retval = (subItem ? 0 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (ourParent != otherParent)" << endl;
+        kDebug() << dbgPfx << retval << " because (ourParent != otherParent)" << endl;
 #endif
         return retval;
     }
@@ -542,14 +543,14 @@ int UMLListViewItem::compare(QListViewItem *other, int col, bool ascending) cons
     if (thisUmlItem == NULL) {
         retval = (subItem ? 1 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (thisUmlItem==NULL)" << endl;
+        kDebug() << dbgPfx << retval << " because (thisUmlItem==NULL)" << endl;
 #endif
         return retval;
     }
     if (otherUmlItem == NULL) {
         retval = (subItem ? -1 : alphaOrder);
 #ifdef DEBUG_LVITEM_INSERTION_ORDER
-        kdDebug() << dbgPfx << retval << " because (otherUmlItem==NULL)" << endl;
+        kDebug() << dbgPfx << retval << " because (otherUmlItem==NULL)" << endl;
 #endif
         return retval;
     }
@@ -558,12 +559,12 @@ int UMLListViewItem::compare(QListViewItem *other, int col, bool ascending) cons
     int otherIndex = items.findRef(otherUmlItem);
     if (myIndex < 0) {
         retval = (subItem ? -1 : alphaOrder);
-        kdError() << dbgPfx << retval << " because (myIndex < 0)" << endl;
+        kError() << dbgPfx << retval << " because (myIndex < 0)" << endl;
         return retval;
     }
     if (otherIndex < 0) {
         retval = (subItem ? 1 : alphaOrder);
-        kdError() << dbgPfx << retval << " because (otherIndex < 0)" << endl;
+        kError() << dbgPfx << retval << " because (otherIndex < 0)" << endl;
         return retval;
     }
     return (myIndex < otherIndex ? -1 : myIndex > otherIndex ? 1 : 0);
@@ -624,7 +625,7 @@ void UMLListViewItem::saveToXMI( QDomDocument & qDoc, QDomElement & qElement) {
     QDomElement itemElement = qDoc.createElement( "listitem" );
     Uml::IDType id = getID();
     QString idStr = ID2STR(id);
-    //kdDebug() << "UMLListViewItem::saveToXMI: id = " << idStr
+    //kDebug() << "UMLListViewItem::saveToXMI: id = " << idStr
     //    << ", type = " << m_Type << endl;
     if (id != Uml::id_None)
         itemElement.setAttribute( "id", idStr );
@@ -633,16 +634,16 @@ void UMLListViewItem::saveToXMI( QDomDocument & qDoc, QDomElement & qElement) {
     UMLFolder *extFolder = NULL;
     if (m_pObject == NULL) {
         if (! Model_Utils::typeIsDiagram(m_Type) && m_Type != Uml::lvt_View)
-            kdError() << "UMLListViewItem::saveToXMI(" << m_Label
+            kError() << "UMLListViewItem::saveToXMI(" << m_Label
                 << "): m_pObject is NULL" << endl;
         itemElement.setAttribute( "label", m_Label );
     } else if (m_pObject->getID() == Uml::id_None) {
         if (m_Label.isEmpty()) {
-            kdDebug() << "UMLListViewItem::saveToXMI(): Skipping empty item"
+            kDebug() << "UMLListViewItem::saveToXMI(): Skipping empty item"
                 << endl;
             return;
         }
-        kdDebug() << "UMLListViewItem::saveToXMI(): saving local label "
+        kDebug() << "UMLListViewItem::saveToXMI(): saving local label "
             << m_Label << " because umlobject ID is not set" << endl;
         itemElement.setAttribute( "label", m_Label );
     } else if (m_pObject->getBaseType() == Uml::ot_Folder) {
@@ -671,7 +672,7 @@ bool UMLListViewItem::loadFromXMI(QDomElement& qElement) {
     if (!label.isEmpty())
         setText( label );
     else if (id == "-1") {
-        kdError() << "UMLListViewItem::loadFromXMI: Item of type "
+        kError() << "UMLListViewItem::loadFromXMI: Item of type "
             << type << " has neither ID nor label" << endl;
         return false;
     }
