@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLNAMESPACE_H
@@ -337,11 +337,15 @@ const IDType id_Reserved = "0";
 # define STR2ID(id)  id.ascii()
 # define ID2STR(id)  QString(id.c_str())
 
+// KDE4 compatibility
+# define kDebug   kdDebug
+# define kWarning kdWarning
+# define kError   kdError
 
 /**
  * Function for comparing tags in XMI files.
  */
-bool tagEq (QString tag, QString pattern);
+bool tagEq (const QString& tag, const QString& pattern);
 
 }  // end namespace Uml
 
