@@ -5,19 +5,24 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "umlobject.h"
+// qt/kde includes
 #include <qregexp.h>
 #include <kdebug.h>
 #include <kapplication.h>
-#include "umlobject.h"
+// app includes
+#include "uniqueid.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umllistviewitem.h"
 #include "package.h"
+#include "folder.h"
 #include "stereotype.h"
 #include "object_factory.h"
 #include "model_utils.h"
@@ -29,17 +34,17 @@ UMLObject::UMLObject(const UMLObject * parent, const QString &name, Uml::IDType
         : QObject(const_cast<UMLObject*>(parent), "UMLObject" ) {
     init();
     if (id == Uml::id_None)
-        m_nId = UMLApp::app()->getDocument()->getUniqueID();
+        m_nId = UniqueID::gen();
     else
         m_nId = id;
     m_Name = name;
 }
 
 UMLObject::UMLObject(const QString &name, Uml::IDType id)
-        :  QObject(UMLApp::app()->getDocument(), "UMLObject") {
+        :  QObject(UMLApp::app()->getDocument()) {
     init();
     if (id == Uml::id_None)
-        m_nId = UMLApp::app()->getDocument()->getUniqueID();
+        m_nId = UniqueID::gen();
     else
         m_nId = id;
     m_Name = name;
@@ -82,35 +87,6 @@ bool UMLObject::showProperties(int page, bool assoc) {
     return modified;
 }
 
-bool UMLObject::isSavedInSeparateFile() {
-    if (Settings::getOptionState().generalState.tabdiagrams) {
-        // Umbrello currently does not support external folders
-        // when tabbed diagrams are enabled.
-        return false;
-    }
-    const QString msgPrefix("UMLObject::isSavedInSeparateFile(" + m_Name + "): ");
-    UMLListView *listView = UMLApp::app()->getListView();
-    UMLListViewItem *lvItem = listView->findUMLObject(this);
-    if (lvItem == NULL) {
-        kdError() << msgPrefix
-        << "listView->findUMLObject(this) returns false"
-        << endl;
-        return false;
-    }
-    UMLListViewItem *parentItem = dynamic_cast<UMLListViewItem*>( lvItem->parent() );
-    if (parentItem == NULL) {
-        kdError() << msgPrefix
-        << "parent item in listview is not a UMLListViewItem (?)"
-        << endl;
-        return false;
-    }
-    const Uml::ListView_Type lvt = parentItem->getType();
-    if (! UMLListView::typeIsFolder(lvt))
-        return false;
-    QString folderFile = parentItem->getFolderFile();
-    return !folderFile.isEmpty();
-}
-
 bool UMLObject::acceptAssociationType(Uml::Association_Type)
 {// A UMLObject accepts nothing. This should be reimplemented by the subclasses
     return false;
@@ -130,13 +106,23 @@ QString UMLObject::getName() const {
     return m_Name;
 }
 
-QString UMLObject::getFullyQualifiedName(QString separator) const {
+QString UMLObject::getFullyQualifiedName(QString separator,
+                                         bool includeRoot /* = false */) const {
     QString fqn;
     if (m_pUMLPackage) {
-        if (separator.isEmpty())
-            separator = UMLApp::app()->activeLanguageScopeSeparator();
-        fqn = m_pUMLPackage->getFullyQualifiedName(separator);
-        fqn.append(separator);
+        bool skipPackage = false;
+        if (!includeRoot) {
+            UMLDoc *umldoc = UMLApp::app()->getDocument();
+            if (umldoc->rootFolderType(m_pUMLPackage) != Uml::N_MODELTYPES ||
+                m_pUMLPackage == umldoc->getDatatypeFolder())
+                skipPackage = true;
+        }
+        if (!skipPackage) {
+            if (separator.isEmpty())
+                separator = UMLApp::app()->activeLanguageScopeSeparator();
+            fqn = m_pUMLPackage->getFullyQualifiedName(separator, includeRoot);
+            fqn.append(separator);
+        }
     }
     fqn.append(m_Name);
     return fqn;
@@ -198,8 +184,6 @@ bool UMLObject::operator==(UMLObject & rhs ) {
 
 void UMLObject::copyInto(UMLObject *rhs) const
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-
     // Data members with copy constructor
     rhs->m_Doc = m_Doc;
     rhs->m_pStereotype = m_pStereotype;
@@ -210,14 +194,14 @@ void UMLObject::copyInto(UMLObject *rhs) const
     rhs->m_pUMLPackage = m_pUMLPackage;
 
     // We don't want the same name existing twice.
-    rhs->m_Name = Model_Utils::uniqObjectName(m_BaseType, m_Name, m_pUMLPackage);
+    rhs->m_Name = Model_Utils::uniqObjectName(m_BaseType, m_pUMLPackage, m_Name);
 
     // Create a new ID.
-    rhs->m_nId = umldoc->getUniqueID();
+    rhs->m_nId = UniqueID::gen();
 
     // Hope that the parent from QObject is okay.
     if (rhs->parent() != parent())
-        kdDebug() << "copyInto has a wrong parent" << endl;
+        kDebug() << "copyInto has a wrong parent" << endl;
 }
 
 
@@ -253,7 +237,7 @@ void UMLObject::emitModified()
 
 void UMLObject::setDoc(const QString &d) {
     m_Doc = d;
-    emit modified();
+    //emit modified();  No, this is done centrally at DocWindow::updateDocumentation()
 }
 
 Uml::Object_Type UMLObject::getBaseType() const {
@@ -296,6 +280,7 @@ void UMLObject::setUMLStereotype(UMLStereotype *stereo) {
         }
     }
     m_pStereotype = stereo;
+    // TODO: don't emit modified() if predefined folder
     emit modified();
 }
 
@@ -313,16 +298,20 @@ void UMLObject::setPackage(const QString &_name) {
     UMLObject *pkgObj = NULL;
     if (!_name.isEmpty()) {
         UMLDoc* umldoc = UMLApp::app()->getDocument();
-        if (umldoc == NULL) {
-            kdError() << "UMLObject::setPackage: cannot set package name on "
-            << m_Name << endl;
-            return;
-        }
-        pkgObj = umldoc->findUMLObject(_name, Uml::ot_Package);
+        pkgObj = umldoc->findUMLObject(_name);
         if (pkgObj == NULL) {
-            kdDebug() << "UMLObject::setPackage: creating UMLPackage "
-            << _name << " for " << m_Name << endl;
+            kDebug() << "UMLObject::setPackage: creating UMLPackage "
+                << _name << " for " << m_Name << endl;
             pkgObj = Import_Utils::createUMLObject(Uml::ot_Package, _name);
+        } else {
+            const Uml::Object_Type ot = pkgObj->getBaseType();
+            if (ot != Uml::ot_Package && ot != Uml::ot_Folder && ot != Uml::ot_Component) {
+                kError() << "UMLObject::setPackage(" << m_Name << "): "
+                    << "existing " << _name << " is not a container" << endl;
+                // This should not happen - if it does, there may be further problems.
+                // A container name should not overlap with another name in the same scope.
+                pkgObj = Import_Utils::createUMLObject(Uml::ot_Package, _name);
+            }
         }
     }
     setUMLPackage( static_cast<UMLPackage *>(pkgObj) );
@@ -337,7 +326,7 @@ const UMLStereotype * UMLObject::getUMLStereotype() {
     return m_pStereotype;
 }
 
-QString UMLObject::getStereotype(bool includeAdornments /* = false */) {
+QString UMLObject::getStereotype(bool includeAdornments /* = false */) const {
     if (m_pStereotype == NULL)
         return "";
     QString name = m_pStereotype->getName();
@@ -346,31 +335,25 @@ QString UMLObject::getStereotype(bool includeAdornments /* = false */) {
     return name;
 }
 
-QString UMLObject::getPackage(QString separator) {
-    if (m_pUMLPackage == NULL)
-        return "";
-    UMLPackageList pkgList;
-    QStringList pkgNames;
-    UMLPackage* pkg = m_pUMLPackage;
-    while (1) {
-        pkgList.prepend(pkg);
-        pkgNames.prepend(pkg->getName());
-        if ((pkg = pkg->getUMLPackage()) == NULL ||
-            pkgList.containsRef(pkg))
-            break;
-    }
+QString UMLObject::getPackage(QString separator, bool includeRoot) {
     if (separator.isEmpty())
         separator = UMLApp::app()->activeLanguageScopeSeparator();
-    return pkgNames.join(separator);
+    QString fqn = getFullyQualifiedName(separator, includeRoot);
+    if (!fqn.contains(separator))
+        return "";
+    QString scope = fqn.left(fqn.length() - separator.length() - m_Name.length());
+    return scope;
 }
 
-UMLPackageList UMLObject::getPackages() const {
+UMLPackageList UMLObject::getPackages(bool includeRoot) const {
     UMLPackageList pkgList;
     UMLPackage* pkg = m_pUMLPackage;
     while (pkg != NULL) {
         pkgList.prepend(pkg);
         pkg = pkg->getUMLPackage();
     }
+    if (!includeRoot)
+        pkgList.removeFirst();
     return pkgList;
 }
 
@@ -382,7 +365,7 @@ QString UMLObject::getSecondaryId() const {
     return m_SecondaryId;
 }
 
-void UMLObject::setSecondaryId(QString id) {
+void UMLObject::setSecondaryId(const QString& id) {
     m_SecondaryId = id;
 }
 
@@ -390,7 +373,7 @@ QString UMLObject::getSecondaryFallback() const {
     return m_SecondaryFallback;
 }
 
-void UMLObject::setSecondaryFallback(QString id) {
+void UMLObject::setSecondaryFallback(const QString& id) {
     m_SecondaryFallback = id;
 }
 
@@ -411,7 +394,7 @@ bool UMLObject::resolveRef() {
         return true;
     }
 #ifdef VERBOSE_DEBUGGING
-    kdDebug() << "UMLObject::resolveRef(" << m_Name << "): m_SecondaryId is "
+    kDebug() << "UMLObject::resolveRef(" << m_Name << "): m_SecondaryId is "
               << m_SecondaryId << endl;
 #endif
     UMLDoc *pDoc = UMLApp::app()->getDocument();
@@ -430,21 +413,19 @@ bool UMLObject::resolveRef() {
             return true;
         }
     }
-    if (!pDoc->isNativeXMIFile() || !m_SecondaryId.contains(QRegExp("\\D"))) {
-        if (m_SecondaryFallback.isEmpty()) {
-            kdError() << "UMLObject::resolveRef(" << m_Name
-                      << "): cannot find type with id "
-                      << m_SecondaryId << endl;
-            return false;
-        }
-#ifdef VERBOSE_DEBUGGING
-        kdDebug() << "UMLObject::resolveRef(" << m_Name 
-                  << "): could not resolve secondary ID " << m_SecondaryId
-                  << ", using secondary fallback " << m_SecondaryFallback
-                  << endl;
-#endif
-        m_SecondaryId = m_SecondaryFallback;
+    if (m_SecondaryFallback.isEmpty()) {
+        kError() << "UMLObject::resolveRef(" << m_Name
+                  << "): cannot find type with id "
+                  << m_SecondaryId << endl;
+        return false;
     }
+#ifdef VERBOSE_DEBUGGING
+    kDebug() << "UMLObject::resolveRef(" << m_Name 
+              << "): could not resolve secondary ID " << m_SecondaryId
+              << ", using secondary fallback " << m_SecondaryFallback
+              << endl;
+#endif
+    m_SecondaryId = m_SecondaryFallback;
     // Assume we're dealing with the older Umbrello format where
     // the type name was saved in the "type" attribute rather
     // than the xmi.id of the model object of the attribute type.
@@ -464,20 +445,20 @@ bool UMLObject::resolveRef() {
             if (Import_Utils::newUMLObjectWasCreated()) {
                 maybeSignalObjectCreated();
                 kapp->processEvents();
-                kdDebug() << "UMLObject::resolveRef: Import_Utils::createUMLObject() "
+                kDebug() << "UMLObject::resolveRef: Import_Utils::createUMLObject() "
                           << "created a new type for " << m_SecondaryId << endl;
             } else {
-                kdDebug() << "UMLObject::resolveRef: Import_Utils::createUMLObject() "
+                kDebug() << "UMLObject::resolveRef: Import_Utils::createUMLObject() "
                           << "returned an existing type for " << m_SecondaryId << endl;
             }
             m_SecondaryId = "";
             return true;
         }
-        kdError() << "UMLObject::resolveRef: Import_Utils::createUMLObject() "
+        kError() << "UMLObject::resolveRef: Import_Utils::createUMLObject() "
                   << "failed to create a new type for " << m_SecondaryId << endl;
         return false;
     }
-    kdDebug() << "UMLObject::resolveRef: Creating new type for "
+    kDebug() << "UMLObject::resolveRef: Creating new type for "
     << m_SecondaryId << endl;
     // This is very C++ specific - we rely on  some '*' or
     // '&' to decide it's a ref type. Plus, we don't recognize
@@ -556,7 +537,7 @@ bool UMLObject::load( QDomElement& ) {
 bool UMLObject::loadFromXMI( QDomElement & element) {
     UMLDoc* umldoc = UMLApp::app()->getDocument();
     if (umldoc == NULL) {
-        kdError() << "UMLObject::loadFromXMI: umldoc is NULL" << endl;
+        kError() << "UMLObject::loadFromXMI: umldoc is NULL" << endl;
         return false;
     }
     // Read the name first so that if we encounter a problem, the error
@@ -567,9 +548,9 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
         if (m_BaseType == Uml::ot_Role) {
             // Before version 1.4, Umbrello did not save the xmi.id
             // of UMLRole objects.
-            m_nId = umldoc->getUniqueID();
+            m_nId = UniqueID::gen();
         } else {
-            kdError() << "UMLObject::loadFromXMI(" << m_Name
+            kError() << "UMLObject::loadFromXMI(" << m_Name
             << "): nonexistent or illegal xmi.id" << endl;
             return false;
         }
@@ -594,7 +575,7 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
             if (nScope >= Uml::Visibility::Public && nScope <= Uml::Visibility::Protected)
               m_Vis = (Uml::Visibility::Value)nScope;
             else
-                kdError() << "UMLObject::loadFromXMI(" << m_Name
+                kError() << "UMLObject::loadFromXMI(" << m_Name
                 << "): illegal scope" << endl;  // soft error
         }
     } else {
@@ -610,20 +591,15 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
     }
 
     QString stereo = element.attribute( "stereotype", "" );
-    if (!stereo.isEmpty() && stereo != "-1") {
-        if (stereo.contains(QRegExp("\\D"))) {
-            // Old versions saved the stereotype name instead of the xmi.id.
-            setStereotype( stereo );
-        } else {
-            Uml::IDType stereoID = STR2ID(stereo);
-            m_pStereotype = umldoc->findStereotypeById(stereoID);
-            if (m_pStereotype)
-                m_pStereotype->incrRefCount();
-            else
-                kdError() << "UMLObject::loadFromXMI(" << m_Name << "): "
+    if (!stereo.isEmpty()) {
+        Uml::IDType stereoID = STR2ID(stereo);
+        m_pStereotype = umldoc->findStereotypeById(stereoID);
+        if (m_pStereotype)
+            m_pStereotype->incrRefCount();
+        else
+            kError() << "UMLObject::loadFromXMI(" << m_Name << "): "
                 << "UMLStereotype " << ID2STR(stereoID)
                 << " not found" << endl;
-        }
     }
 
     if( element.hasAttribute("abstract") ) {     // for bkwd compat.
@@ -642,38 +618,6 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
         m_bStatic = (ownerScope == "classifier");
     }
 
-    /**** Handle XMI_FLAT_PACKAGES and old files *************************/
-    QString pkg = element.attribute( "packageid", "-1" );
-    // Some interim versions used "packageid" so test for it.
-    Uml::IDType pkgId = Uml::id_None;
-    if (pkg != "-1") {
-        pkgId = STR2ID(pkg);
-    } else {
-        pkg = element.attribute( "package", "" );
-        if (! pkg.isEmpty()) {
-            if (pkg.contains(QRegExp("\\D")))
-                // Old versions saved the package name instead of the xmi.id.
-                setPackage( pkg );
-            else
-                pkgId = STR2ID(pkg);
-        }
-    }
-    if (pkgId != Uml::id_None) {
-        UMLObject *pkgObj = umldoc->findObjectById( pkgId );
-        if (pkgObj != NULL) {
-            m_pUMLPackage = dynamic_cast<UMLPackage *>(pkgObj);
-            if (m_pUMLPackage == NULL)  // soft error
-                kdError() << "UMLObject::loadFromXMI(" << m_Name
-                << "): object of packageid "
-                << ID2STR(pkgId) << " is not a package" << endl;
-        } else {  // soft error
-            kdError() << "UMLObject::loadFromXMI(" << m_Name
-            << "): cannot resolve packageid "
-            << ID2STR(pkgId) << endl;
-        }
-    }
-    /**** End of XMI_FLAT_PACKAGES and old files handling ****************/
-
     // If the node has child nodes, check whether attributes can be
     // extracted from them.
     if (element.hasChildNodes()) {
@@ -738,32 +682,32 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
         }
     }
 
-    // Operations, attributes, enum literals, stereotypes, associations,
+    // Operations, attributes, enum literals, templates, stereotypes,
     // and association role objects get added and signaled elsewhere.
     if (m_BaseType != Uml::ot_Operation && m_BaseType != Uml::ot_Attribute &&
             m_BaseType != Uml::ot_EnumLiteral && m_BaseType != Uml::ot_EntityAttribute &&
-            m_BaseType != Uml::ot_Stereotype &&
-            m_BaseType != Uml::ot_Association && m_BaseType != Uml::ot_Role) {
+            m_BaseType != Uml::ot_Template && m_BaseType != Uml::ot_Stereotype &&
+            m_BaseType != Uml::ot_Role) {
         if (m_bInPaste) {
             m_pUMLPackage = NULL;  // forget any old parent
             UMLListView *listView = UMLApp::app()->getListView();
             UMLListViewItem *parentItem = (UMLListViewItem*)listView->currentItem();
             if (parentItem) {
                 Uml::ListView_Type lvt = parentItem->getType();
-                if (lvt == Uml::lvt_Package ||
+                if (Model_Utils::typeIsContainer(lvt) ||
                         lvt == Uml::lvt_Class ||
                         lvt == Uml::lvt_Interface) {
                     UMLObject *o = parentItem->getUMLObject();
                     m_pUMLPackage = static_cast<UMLPackage*>( o );
                 }
             }
-        }
-
-        if (m_pUMLPackage)
+        } else if (m_pUMLPackage) {
             m_pUMLPackage->addObject(this);
-        else
-            umldoc->addUMLObject(this);
-        //kapp->processEvents();
+        } else if (umldoc->rootFolderType(this) == Uml::N_MODELTYPES) {
+            // m_pUMLPackage is not set on the root folders.
+            kDebug() << "UMLObject::loadFromXMI(" << m_Name << "): m_pUMLPackage is not set"
+                << endl;
+        }
     }
     return load(element);
 }
