@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header file
@@ -22,6 +22,7 @@
 #include "umlwidgetcontroller.h"
 #include "umlobject.h"
 #include "classifier.h"
+#include "uniqueid.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlview.h"
@@ -68,7 +69,7 @@ UMLWidget::UMLWidget(UMLView * view, Uml::IDType id /* = Uml::id_None */, UMLWid
     }
     init();
     if (id == Uml::id_None)
-        m_nId = m_pDoc->getUniqueID();
+        m_nId = UniqueID::gen();
     else
         m_nId = id;
 }
@@ -169,7 +170,7 @@ bool UMLWidget::operator==(const UMLWidget& other) {
 void UMLWidget::setID(Uml::IDType id) {
     if (m_Type != wt_Text && m_pObject && m_pObject->getBaseType() == ot_Association) {
         if (m_pObject->getID() != Uml::id_None)
-            kdWarning() << "UMLWidget::setID(): changing old UMLObject "
+            kWarning() << "UMLWidget::setID(): changing old UMLObject "
             << ID2STR(m_pObject->getID()) << " to "
             << ID2STR(id) << endl;
         m_pObject->setID( id );
@@ -229,7 +230,7 @@ void UMLWidget::init() {
         m_FillColour = optionState.uiState.fillColor;
         m_Font       = optionState.uiState.font;
     } else {
-        kdError() << "UMLWidget::init: SERIOUS PROBLEM - m_pView is NULL" << endl;
+        kError() << "UMLWidget::init: SERIOUS PROBLEM - m_pView is NULL" << endl;
         m_bUseFillColour = false;
         m_bUsesDiagramFillColour = false;
         m_bUsesDiagramUseFillColour = false;
@@ -288,7 +289,7 @@ void UMLWidget::slotMenuSelection(int sel) {
         } else if (wt == wt_Object) {
             m_pObject->showProperties();
         } else {
-            kdWarning() << "making properties dialog for unknown widget type" << endl;
+            kWarning() << "making properties dialog for unknown widget type" << endl;
         }
         // adjustAssocs( getX(), getY() );//adjust assoc lines
         break;
@@ -608,30 +609,17 @@ void UMLWidget::startPopupMenu( const QPoint &At) {
     slotRemovePopupMenu();
 
     //if in a multi- selection to a specific m_pMenu for that
-    int count = m_pView -> getSelectCount();
+    // NEW: ask UMLView to count ONLY the widgets and not their floatingtextwidgets
+    int count = m_pView->getSelectCount(true);
     //a MessageWidget when selected will select its text widget and vice versa
     //so take that into account for popup menu.
 
     // determine multi state
-    bool multi = false;
+    bool multi = (m_bSelected && count > 1);
 
     // if multiple selected items have the same type
     bool unique = false;
 
-    if( m_bSelected )
-        if( m_pView -> getType() == dt_Sequence ) {
-            if( getBaseType() == wt_Message && count == 2 ) {
-                multi = false;
-            } else if( getBaseType() == wt_Text &&
-                       ((FloatingTextWidget*)this) -> getRole() == tr_Seq_Message && count == 2 ) {
-                multi = false;
-            } else if( count > 1 ) {
-                multi = true;
-            }
-        } else if( count > 1 ) {
-            multi = true;
-        }
-
     // if multiple items are selected, we have to check if they all have the same
     // base type
     if (multi == true)
@@ -711,12 +699,12 @@ void UMLWidget::setSelected(bool _select) {
 
     const QPoint pos(getX(), getY());
     UMLWidget *bkgnd = m_pView->testOnWidget(pos);
-    if (bkgnd) {
-        kdDebug() << "UMLWidget::setSelected: setting Z to "
-            << bkgnd->getZ() + 1 << endl;
+    if (bkgnd && bkgnd != this && _select) {
+        kDebug() << "UMLWidget::setSelected: setting Z to "
+            << bkgnd->getZ() + 1 << ", SelectState: " << _select << endl;
         setZ( bkgnd->getZ() + 1 );
     } else {
-        setZ( 0 );
+        setZ( m_origZ );
     }
 
     update();
@@ -961,12 +949,13 @@ void UMLWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
     qElement.setAttribute( "y", getY() );
     qElement.setAttribute( "width", getWidth() );
     qElement.setAttribute( "height", getHeight() );
-    qElement.setAttribute( "usesdiagramfillcolour", m_bUsesDiagramFillColour );
-    qElement.setAttribute( "usesdiagramusefillcolour", m_bUsesDiagramUseFillColour );
+    // for consistency the following attributes now use american spelling for "color"
+    qElement.setAttribute( "usesdiagramfillcolor", m_bUsesDiagramFillColour );
+    qElement.setAttribute( "usesdiagramusefillcolor", m_bUsesDiagramUseFillColour );
     if (m_bUsesDiagramFillColour) {
-        qElement.setAttribute( "fillcolour", "none" );
+        qElement.setAttribute( "fillcolor", "none" );
     } else {
-        qElement.setAttribute( "fillcolour", m_FillColour.name() );
+        qElement.setAttribute( "fillcolor", m_FillColour.name() );
     }
     qElement.setAttribute("isinstance", m_bIsInstance);
     if (!m_instanceName.isEmpty())
@@ -984,9 +973,17 @@ bool UMLWidget::loadFromXMI( QDomElement & qElement ) {
     QString y = qElement.attribute( "y", "0" );
     QString h = qElement.attribute( "height", "0" );
     QString w = qElement.attribute( "width", "0" );
+    /*
+      For the next three *color attributes, there was a mixup of american and english spelling for "color".
+      So first we need to keep backward compatibility and try to retrieve the *colour attribute.
+      Next we overwrite this value if we find a *color, otherwise the former *colour is kept.
+    */
     QString fillColour = qElement.attribute( "fillcolour", "none" );
+    fillColour = qElement.attribute( "fillcolor", fillColour );
     QString usesDiagramFillColour = qElement.attribute( "usesdiagramfillcolour", "1" );
+    usesDiagramFillColour = qElement.attribute( "usesdiagramfillcolor", usesDiagramFillColour );
     QString usesDiagramUseFillColour = qElement.attribute( "usesdiagramusefillcolour", "1" );
+    usesDiagramUseFillColour = qElement.attribute( "usesdiagramusefillcolor", usesDiagramUseFillColour );
 
     m_nId = STR2ID(id);
 
@@ -995,7 +992,7 @@ bool UMLWidget::loadFromXMI( QDomElement & qElement ) {
         m_Font.fromString(font);
         //setFont(newFont);
     } else {
-        kdWarning() << "Using default font " << m_Font.toString()
+        kWarning() << "Using default font " << m_Font.toString()
         << " for widget with xmi.id " << ID2STR(m_nId) << endl;
         //setFont( m_Font );
     }
