@@ -1,8 +1,3 @@
- /*
-  *  copyright (C) 2002-2004
-  *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
-  */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef USECASEWIDGET_H
@@ -41,37 +38,37 @@ class UMLUseCase;
 class UseCaseWidget : public UMLWidget {
 public:
 
-	/**
-	 *	Creates a UseCase widget.
-	 *
-	 *	@param	view		The parent of the widget.
-	 *	@param	o		The UMLObject to represent.
-	 */
-	UseCaseWidget(UMLView * view, UMLUseCase *o);
+    /**
+     *  Creates a UseCase widget.
+     *
+     *  @param  view            The parent of the widget.
+     *  @param  o               The UMLObject to represent.
+     */
+    UseCaseWidget(UMLView * view, UMLUseCase *o);
 
 
-	/**
-	 *	destructor
-	 */
-	virtual ~UseCaseWidget();
+    /**
+     *  destructor
+     */
+    virtual ~UseCaseWidget();
 
-	/**
-	*	Overrides the standard paint event.
-	*/
-	void draw(QPainter & p, int offsetX, int offsetY);
+    /**
+    *   Overrides the standard paint event.
+    */
+    void draw(QPainter & p, int offsetX, int offsetY);
 
-	/**
-	*	Saves this UseCase to file.
-	*/
-	void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+    /**
+    *   Saves this UseCase to file.
+    */
+    void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
-	// For loading we can use the loadFromXMI() inherited from UMLWidget.
+    // For loading we can use the loadFromXMI() inherited from UMLWidget.
 
 protected:
-	/**
-	 *	Calculates the size of the widget.
-	 */
-	void calculateSize();
+    /**
+     * Overrides method from UMLWidget
+     */
+    QSize calculateSize();
 };
 
 #endif
